@@ -15,6 +15,7 @@
 
 namespace SKELETON
 {
+    class Admin;
     class PopupWin;
 }
 
@@ -23,16 +24,23 @@ namespace DBTREE
     class ArticleBase;
 }
 
+namespace XML
+{
+    class Dom;
+}
+
 namespace ARTICLE
 {
     class DrawAreaBase;
-    class ArticleToolBar;
 
     class ArticleViewBase : public SKELETON::View
     {
         // viewに表示するdatファイルのURL ( SKELETON::View::m_url はview自身のURLなのに注意すること )
         std::string m_url_article; 
 
+        // ツールバーの板ボタンに表示する文字列
+        std::string m_label_board; 
+
         // 高速化のため直接アクセス
         JDLIB::RefPtr_Lock< DBTREE::ArticleBase > m_article; 
 
@@ -51,7 +59,7 @@ namespace ARTICLE
 
         // 検索用
         bool m_search_invert; // 逆方向検索モード
-        std::string m_query;  // 前回の検索で使ったクエリー
+        std::string m_pre_query;  // 前回の検索で使ったクエリー
 
         // ポップアップメニュー表示のときにactivate_act_before_popupmenu()で使う変数
         bool m_enable_menuslot;
@@ -62,6 +70,15 @@ namespace ARTICLE
         // 抽出ビューで荒らし報告用のURLを表示する
         bool m_show_url4report;
 
+        // URLをステータスバーに表示しているかどうか
+        bool m_url_show_status;
+
+        // 実況モードが可能か
+        bool m_enable_live;
+
+        // ライブモードか
+        bool m_live;
+
     public:
 
         ArticleViewBase( const std::string& url );
@@ -69,14 +86,21 @@ namespace ARTICLE
 
         const std::string& url_article() const { return m_url_article; }
         virtual const std::string url_for_copy();
+        const std::string& get_label_board(){ return m_label_board; }
 
         // SKELETON::View の関数のオーバロード
         virtual const int width_client();
         virtual const int height_client();
         virtual const int get_icon( const std::string& iconname );
-        virtual bool set_command( const std::string& command, const std::string& arg = std::string() );
+        virtual const bool set_command( const std::string& command,
+                                        const std::string& arg1 = std::string(),
+                                        const std::string& arg2 = std::string()
+            );
 
         virtual void clock_in();
+        void clock_in_smooth_scroll();
+
+        virtual void write();
         virtual void reload();
         virtual void stop();
         virtual void redraw_view();
@@ -84,20 +108,39 @@ namespace ARTICLE
         virtual void focus_out();
         virtual void close_view();
         virtual void delete_view();
-        virtual void operate_view( const int& control );
+        virtual void set_favorite();
+        virtual const bool operate_view( const int control );
         virtual void goto_top();
         virtual void goto_bottom();
         virtual void goto_num( int num );
-        virtual void toggle_toolbar();
         virtual void show_preference();
 
+        // 進む、戻る
+        virtual void back_viewhistory( const int count );
+        virtual void forward_viewhistory( const int count );
+ 
+        // 検索
+        virtual void exec_search();
+        virtual void up_search();
+        virtual void down_search();
+        virtual void operate_search( const std::string& controlid );
+        void clear_highlight();  // ハイライト解除
+
         // 記事削除 & 再オープン
         void delete_open_view();
 
+        // 実況モードが可能か
+        const bool get_enable_live();
+
+        // 実況モードか
+        const bool get_live() const { return m_live; }
+
     protected:
 
+        // Viewが所属するAdminクラス
+        virtual SKELETON::Admin* get_admin();
+
         DrawAreaBase* drawarea();
-        ArticleToolBar* get_articletoolbar();
         JDLIB::RefPtr_Lock< DBTREE::ArticleBase >& get_article();
 
         // ポップアップメニューを表示する前にメニューのアクティブ状態を切り替える
@@ -131,12 +174,22 @@ namespace ARTICLE
         // ブックマークを抽出して表示
         void show_bm();
 
+        // 書き込みを抽出して表示
+        void show_post();
+
+        // 書き込みログを表示
+        void show_postlog( const int num );
+
         // URLを含むレスを抽出して表示
         void show_res_with_url();
 
         // num 番のレスを参照してるレスを抽出して表示
         void show_refer( int num );
 
+        // 前回の検索で使ったクエリー
+        void set_pre_query( const std::string& query ){  m_pre_query = query; }
+        const std::string& get_pre_query() const{ return m_pre_query; }
+
         // キーワードで抽出して表示
         // mode_or = true の時は or 検索
         // show_option = true の時は URL 表示などのオプションが表示される
@@ -154,29 +207,28 @@ namespace ARTICLE
         // リストで指定したレスを表示(連結情報付き)
         void append_res( std::list< int >& list_resnum, std::list< bool >& list_joint );
 
-        // ツールバーのボタンを押したときのスロット
-        void slot_push_close_search();
-        void slot_push_reload();
-        virtual void slot_push_write();
-        void slot_push_delete();
-        void slot_push_open_board();
+        // 画像プロパティ表示
         void slot_preferences_image();
-        void slot_push_open_search();
-        void slot_push_up_search();
-        void slot_push_down_search();
-        void slot_push_drawout_and();
-        void slot_push_drawout_or();
-        void slot_push_claar_hl();
 
         void slot_copy_selection_str();
         void slot_select_all();
 
+        // 実況用
+        void set_enable_live( const bool enable ){ m_enable_live = enable; }
+        void set_live( const bool live );
+        virtual void live_start(){}
+        virtual void live_stop(){}
+
     private:
 
         virtual DrawAreaBase* create_drawarea();        
 
-        virtual void pack_widget();
         void setup_action();
+        const std::string create_usrcmd_menu();
+        const std::string create_usrcmd_menu( XML::Dom* dom, int& dirno, int& cmdno );
+
+        virtual void exec_reload();
+        void exec_delete();
 
         // 荒らし報告用のURLリストをHTML形式で取得
         std::string get_html_url4report( std::list< int >& list_resnum );
@@ -185,7 +237,7 @@ namespace ARTICLE
         virtual bool slot_button_press( std::string url, int res_number, GdkEventButton* event );
         bool slot_button_release( std::string url, int res_number, GdkEventButton* event );
         bool slot_motion_notify( GdkEventMotion* event );
-        bool slot_key_press( GdkEventKey* event );
+        const bool slot_key_press( GdkEventKey* event );
         bool slot_key_release( GdkEventKey* event );
         bool slot_scroll_event( GdkEventScroll* event );
         bool slot_leave_notify( GdkEventCrossing* ev );
@@ -215,19 +267,20 @@ namespace ARTICLE
         void slot_drawout_selection_str();
         void slot_search_cacheall();
         void slot_search_cachelocal();
+        void slot_search_next();
         void slot_search_web();
         void slot_search_title();
         void slot_usrcmd( int num );
         void slot_copy_res( bool ref );
-        void slot_favorite();
-        virtual void slot_drawout_res();
-        virtual void slot_drawout_around();
-        virtual void slot_drawout_tmp();
-        virtual void slot_drawout_name();
-        virtual void slot_drawout_id();
-        virtual void slot_drawout_bm();
-        virtual void slot_drawout_refer();
-        virtual void slot_drawout_url();
+        void slot_drawout_res();
+        void slot_drawout_around();
+        void slot_drawout_tmp();
+        void slot_drawout_name();
+        void slot_drawout_id();
+        void slot_drawout_bm();
+        void slot_drawout_post();
+        void slot_drawout_refer();
+        void slot_drawout_url();
         void slot_abone_res();
         void slot_abone_id();
         void slot_abone_name();
@@ -242,6 +295,7 @@ namespace ARTICLE
         void slot_next_bm();
         void slot_jump();
         void slot_save_dat();
+        void slot_copy_article_info();
 
         // リンクの処理
         virtual void slot_on_url( std::string url, int res_number );
@@ -256,10 +310,11 @@ namespace ARTICLE
         void slot_saveimage();
         void slot_abone_img();
 
-        // 検索
-        virtual void open_searchbar( bool invert );
-        virtual void slot_active_search();
-        virtual void slot_entry_operate( int controlid );
+        // 検索バーを開く
+        void open_searchbar( bool invert );
+
+        // p2経由で書き込み(p2ログインを実装するまでの暫定仕様)
+        const bool write_p2( const int number );
     };
 
 }
