@@ -13,7 +13,8 @@
 
 #include "jdlib/misctime.h"
 
-#include "controlid.h"
+#include "control/controlid.h"
+
 #include "command.h"
 
 #include <sys/time.h>
@@ -24,10 +25,12 @@ using namespace ARTICLE;
 ArticleViewPreview::ArticleViewPreview( const std::string& url )
     : ArticleViewBase( url )
 {
+    m_url_messageview = url;
+
     struct timeval tv;
     struct timezone tz;
     gettimeofday( &tv, &tz );
-    set_url( url_article() + MISC::timevaltostr( tv ) + ARTICLE_SIGN + "_PREV_" );
+    set_url( url_article() + MISC::timevaltostr( tv ) + ARTICLE_SIGN + "_PREV_", false );
 
 #ifdef _DEBUG
     std::cout << "ArticleViewPreview::ArticleViewPreview " << get_url() << std::endl;
@@ -53,27 +56,15 @@ ArticleViewPreview::~ArticleViewPreview()
 }
 
 
-
-//
-// ウィジットのパッキング
-//
-// ArticleViewBase::pack_widget()をオーパロードしてツールバーをパックしない
-//
-void ArticleViewPreview::pack_widget()
-{
-    pack_start( *drawarea() );
-}
-
-
 //
 // viewの操作
 //
-void ArticleViewPreview::operate_view( const int& control )
+const bool ArticleViewPreview::operate_view( const int control )
 {
-    if( control == CONTROL::None ) return;
+    if( control == CONTROL::None ) return false;
 
     // スクロール系操作
-    if( drawarea()->set_scroll( control ) ) return;
+    if( drawarea()->set_scroll( control ) ) return true;
 
     switch( control ){
 
@@ -95,7 +86,7 @@ void ArticleViewPreview::operate_view( const int& control )
 
             // 書き込み実行
         case CONTROL::ExecWrite:
-            MESSAGE::get_admin()->set_command( "exec_Write" );
+            MESSAGE::get_admin()->set_command( "toolbar_write", m_url_messageview );
             break;
 
         case CONTROL::TabLeft:
@@ -107,9 +98,14 @@ void ArticleViewPreview::operate_view( const int& control )
         break;
 
         case CONTROL::FocusWrite:
-            MESSAGE::get_admin()->set_command( "focus_write" );
+            MESSAGE::get_admin()->set_command( "focus_button_write" );
         break;
+
+        default:
+            return false;
     }
+
+    return true;
 }
 
 
