@@ -5,7 +5,6 @@
 
 #include "bbslistview.h"
 #include "bbslistadmin.h"
-#include "toolbar.h"
 
 #include "skeleton/msgdiag.h"
 
@@ -46,7 +45,7 @@ BBSListViewMain::~BBSListViewMain()
 
 
 // xml保存
-void BBSListViewMain::save_xml( bool backup )
+void BBSListViewMain::save_xml( const bool backup )
 {
     std::string file = CACHE::path_xml_listmain();
     if( backup ) file = CACHE::path_xml_listmain_bkup();
@@ -137,13 +136,13 @@ void BBSListViewMain::delete_view()
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
     for( ; it != list_it.end(); ++it ){
         if( ! is_etcboard( *it ) ){
-            SKELETON::MsgDiag mdiag( NULL, "通常の板は削除出来ません", false, Gtk::MESSAGE_ERROR );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "通常の板は削除出来ません", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             return;
         }
     }
 
-    SKELETON::MsgDiag mdiag( NULL, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    SKELETON::MsgDiag mdiag( get_parent_win(), "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
     if( mdiag.run() != Gtk::RESPONSE_YES ) return;
 
     delete_view_impl();
@@ -174,7 +173,8 @@ void BBSListViewMain::delete_view_impl()
         }
     }
 
-    get_treeview().delete_selected_rows();
+    const bool force = true; // 強制的に削除
+    get_treeview().delete_selected_rows( force );
 
     // etc.txt保存
     DBTREE::save_etc();
