@@ -8,33 +8,37 @@
 #define _BBSLISTVIEWBASE_H
 
 #include "skeleton/view.h"
-#include "skeleton/treeview.h"
+#include "skeleton/edittreeview.h"
 
-#include "jdlib/constptr.h"
 #include "xml/document.h"
 
 #include "columns.h"
 
 #include <gtkmm.h>
 
+namespace SKELETON
+{
+    class Admin;
+};
+
+
+#define SUBDIR_ETCLIST "外部板"
+
 
 namespace BBSLIST
 {
-    class BBSListToolBar;
+    class EditListWin;
 
     class BBSListViewBase : public SKELETON::View
     {
-      private:
-
         Glib::RefPtr< Gtk::TreeStore > m_treestore;
-        SKELETON::JDTreeView m_treeview;
+        SKELETON::EditTreeView m_treeview;
 
         bool m_ready_tree; // ツリーがセットされているならtrue
 
         BBSLIST::TreeColumns m_columns;
 
         Gtk::ScrolledWindow m_scrwin;
-        JDLIB::ConstPtr< Gtk::CellRendererText > m_ren_text;
 
         // ダブルクリック状態
         bool m_dblclick;
@@ -46,74 +50,102 @@ namespace BBSLIST
         // clock_in()の説明を参照
         int m_jump_y;
 
-        // D&D 用
-        int m_dnd_counter;
-        Gtk::TreePath m_drag_path_uline;;
-
         // サーチで使う変数
         bool m_search_invert;
         std::string m_pre_query;
 
-        // fucus_viewを一回キャンセルする
-        // ポップアップメニューが消えたときにfocus_viewが呼び出されるが
-        // 名前の変更など都合の悪いときはキャンセルする
-        bool m_cancel_focus;
-
-        // あるフォルダを開いたときに他のフォルダを閉じる
-        bool m_expand_collapse;
+        bool m_open_only_onedir; // あるフォルダを開いたときに他のフォルダを閉じる
         bool m_cancel_expand; // signal_row_expanded() をキャンセルする
         bool m_expanding; // 行を開いている最中にtrueにしてsignal_row_collapsed()をキャンセルする
 
+        EditListWin* m_editlistwin;
+
       protected:
 
+        // Viewが所属するAdminクラス
+        virtual SKELETON::Admin* get_admin();
+
+        // treeviewのD&Dによる編集を可能にする
+        void set_editable( const bool editable );
+
+        void set_search_invert( const bool invert ){ m_search_invert = invert; }
+
         // DOM共有オブジェクト
         XML::Document m_document;
 
         Glib::RefPtr< Gtk::TreeStore >& get_treestore() { return m_treestore; }
-        SKELETON::JDTreeView& get_treeview() { return  m_treeview; }
-        BBSListToolBar* get_bbslisttoolbar();
+        SKELETON::EditTreeView& get_treeview() { return  m_treeview; }
         const bool& get_ready_tree() const{ return m_ready_tree; }
-        void set_expand_collapse( bool set ){ m_expand_collapse = set; }
+        void set_open_only_onedir( const bool set ){ m_open_only_onedir = set; }
 
         virtual void activate_act_before_popupmenu( const std::string& url );
 
-        void append_from_buffer( Gtk::TreeModel::Path path, bool after, bool scroll );
-        void delete_selected_rows();
-
         // tree <-> XML( DOM )変換
         void tree2xml( const std::string& root_name );
         void xml2tree( const std::string& root_name, const std::string& xml = std::string() );
 
+        // 外部板のディレクトリか
+        bool is_etcdir( Gtk::TreePath path );
+
+        // 外部板か
+        bool is_etcboard( Gtk::TreeModel::iterator& it );
+        bool is_etcboard( Gtk::TreePath path );
+
         // 移転があったときに行に含まれるURLを変更する
         void update_urls();
 
         // アイコン表示の切り替え
         void toggle_icon( const std::string& url );
 
+        // スレの url と 名前を変更
+        void replace_thread( const std::string& url, const std::string& url_new );
+
         // path からその行のタイプを取得
         int path2type( const Gtk::TreePath& path );
+
         // row からタイプを取得
         int row2type( const Gtk::TreeModel::Row& row );
 
-        // お気に入りにアイテム追加
-        // あらかじめ共有バッファに追加するデータをセットしておくこと
-        void append_item();
+        // path からその行の名前を取得
+        Glib::ustring path2name( const Gtk::TreePath& path );
+
+        // path からその行のURLを取得
+        Glib::ustring path2rawurl( const Gtk::TreePath& path );
+        Glib::ustring path2url( const Gtk::TreePath& path ); // 移転をチェックするバージョン
+
+        // アイテム削除
+        void remove_item( const std::string& url );
+
+        // ツリーの編集ウィンドウを開く
+        void edit_tree();
 
         // xml保存
-        virtual void save_xml( bool backup ){}
+        virtual void save_xml( const bool backup ) = 0;
 
         // remove_dir != empty()の時はその名前のディレクトリを削除する
         void save_xml_impl( const std::string& file, const std::string& root, const std::string& remove_dir );
 
+        // idからポップアップメニュー取得
+        Gtk::Menu* id2popupmenu( const std::string& id );
+
       public:
 
         BBSListViewBase( const std::string& url, const std::string& arg1 = std::string() , const std::string& arg2 = std::string() );
         virtual ~BBSListViewBase();
 
+        //
         // SKELETON::View の関数のオーバロード
+        //
+
+        // 親ウィンドウをセット
+        virtual void set_parent_win( Gtk::Window* parent_win );
+
         virtual const std::string url_for_copy(){ return std::string(); }
 
-        virtual bool set_command( const std::string& command, const std::string& arg = std::string() );
+        virtual const bool set_command( const std::string& command,
+                                        const std::string& arg1 = std::string(),
+                                        const std::string& arg2 = std::string()
+            );
 
         virtual void shutdown();
 
@@ -122,24 +154,39 @@ namespace BBSLIST
         virtual void focus_view();
         virtual void focus_out();
         virtual void close_view();
-        virtual void update_item( const std::string& );
-        virtual void operate_view( const int& control );
+        virtual void delete_view();
+        virtual void update_item( const std::string& url, const std::string& id );
+        virtual const bool operate_view( const int control );
         virtual void goto_top();
         virtual void goto_bottom();
-        virtual void toggle_toolbar();
+
+        // 検索
+        virtual void exec_search();
+        virtual void up_search();
+        virtual void down_search();
+        virtual void operate_search( const std::string& controlid );
+
+        // 挿入先ダイアログを表示してアイテム追加
+        // あらかじめ共有バッファに追加するデータをセットしておくこと
+        void append_item();
 
         // selectdialogで使う
         Gtk::TreePath get_current_path() { return m_treeview.get_current_path(); }
         void copy_treestore( Glib::RefPtr< Gtk::TreeStore >& store );
 
+        // undo, redo
+        void undo();
+        void redo();
+
       private:
 
+        void set_fgcolor_of_comment( const Gtk::TreeModel::Children& children );
+
         void row_up();
         void row_down();
         void page_up();
         void page_down();
         void expand_all_dir( Gtk::TreeModel::Path path );
-        void select_all_dir( Gtk::TreeModel::Path path );
         void check_update_dir( Gtk::TreeModel::Path path );
         void check_update_root( const Gtk::TreeModel::Children& children );
         void check_update_root( const bool tab_open = false );
@@ -150,11 +197,15 @@ namespace BBSLIST
         bool slot_key_press( GdkEventKey* event );
         bool slot_key_release( GdkEventKey* event );
         bool slot_scroll_event( GdkEventScroll* event );
+        void slot_dropped_from_other( const CORE::DATA_INFO_LIST& list_info );
+
         void slot_open_tab();
         void slot_open_browser();
         void slot_append_favorite();
         void slot_newdir();
         void slot_newcomment();
+        void slot_newetcboard();
+        void slot_moveetcboard();
         void slot_rename();
         void slot_copy_url();
         void slot_copy_title_url();
@@ -169,51 +220,27 @@ namespace BBSLIST
         void slot_preferences_image();
         void slot_row_exp( const Gtk::TreeModel::iterator& it, const Gtk::TreeModel::Path& path );
         void slot_row_col( const Gtk::TreeModel::iterator& it, const Gtk::TreeModel::Path& path );        
-        void slot_ren_text_on_edited( const Glib::ustring& path, const Glib::ustring& text );
         void slot_checkupdate_selected_rows();
         void slot_checkupdate_open_selected_rows();
 
+        virtual void delete_view_impl();
+
+        // 外部板追加/編集
+        void add_newetcboard( const bool move, const std::string& _url, const std::string& _name, const std::string& _id, const std::string& _passwd );
+
         // D&D 関係
-        void slot_drag_begin();
-        void slot_drag_motion( Gtk::TreeModel::Path path );
-        void slot_drag_drop( Gtk::TreeModel::Path path );
-        void slot_drag_end();
-        void slot_receive_dnd_begin();
-        void slot_receive_dnd_end();
+        void slot_drag_drop( Gtk::TreeModel::Path path, const bool after );
 
-        Gtk::TreeViewColumn* create_column();
         virtual const bool open_row( Gtk::TreePath& path, const bool tab );
         virtual void switch_rightview();
         void open_selected_rows();
         void checkupdate_selected_rows();
-        Glib::ustring path2url( const Gtk::TreePath& path );
         Glib::ustring row2url( const Gtk::TreeModel::Row& row );
-        Glib::ustring path2name( const Gtk::TreePath& path );
-        bool is_dir( Gtk::TreeModel::iterator& it );
-        bool is_dir( const Gtk::TreePath& path );
 
-        Gtk::TreeModel::Path append_row( const std::string& url, const std::string& name, int type,
-                                         Gtk::TreeModel::Path path_dest = Gtk::TreeModel::Path()
-                                         , bool subdir = true, bool after = true );
-
-        bool copy_row( Gtk::TreeModel::iterator& src, Gtk::TreeModel::iterator& dest, bool subdir, bool after = true );
-        void move_selected_row( const Gtk::TreePath& path, bool after );
-
-        void draw_underline( const Gtk::TreePath& path, bool draw );
         void show_status();
 
-        // 検索
-        void slot_active_search();
-        void slot_push_down_search();
-        void slot_push_up_search();
-        void slot_entry_operate( int controlid );
-
-        void slot_combo_changed();
-
-        void set_info_to_sharedbuffer( Gtk::TreePath& path );
-
-        // 全てのツリーに m_columns.m_expand の値をセットする
-        void set_expanded_row( const Gtk::TreeModel::Children& children );
+        // ツリーの編集ウィンドウが閉じた
+        void slot_hide_editlistwin();
     };
 };
 
