@@ -22,7 +22,7 @@ namespace BBSLIST
       protected:
 
         // xml保存
-        virtual void save_xml( bool backup );
+        virtual void save_xml( const bool backup );
 
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
     };
