@@ -10,6 +10,10 @@
 
 #include <string>
 
+#define ARTICLE_SIGN "_ARTICLE_"
+#define NEXT_SIGN "_NEXT_"
+#define TIME_SIGN "_TIME_"
+
 namespace BOARD
 {
     class BoardToolBar;
@@ -24,7 +28,7 @@ namespace BOARD
 
       protected:
 
-        virtual COMMAND_ARGS get_open_list_args( const std::string& url );
+        virtual COMMAND_ARGS get_open_list_args( const std::string& url, const COMMAND_ARGS& command_list );
         virtual SKELETON::View* create_view( const COMMAND_ARGS& command );
 
         // ツールバー
@@ -40,9 +44,8 @@ namespace BOARD
 
       private:
 
-        // タブの D&D 処理
-        virtual void slot_drag_begin( int page );
-        virtual void slot_drag_end();
+        // タブをお気に入りにドロップした時にお気に入りがデータ送信を要求してきた
+        virtual void slot_drag_data_get( Gtk::SelectionData& selection_data, const int page );
     };
     
     BoardAdmin* get_admin();
