@@ -26,8 +26,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
       m_entry_writename( true, "名前：" ),
       m_entry_writemail( true, "メール：" ),
       m_check_noname( "名前欄が空白の時は書き込まない" ),
+      m_bt_clear_post_history( "この板にある全スレの書き込み履歴クリア" ),
 
-      m_frame_cookie( "クッキー＆Hana" ),
+      m_frame_cookie( "クッキーと書き込みキーワード" ),
       m_button_cookie( "削除" ) ,
 
       m_check_live( "実況する" ),
@@ -41,9 +42,10 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
 
 
       m_label_noname( false, "デフォルト名無し：", DBTREE::default_noname( get_url() ) ),
-      m_label_line( false, "1レスの最大改行数：" ),
-      m_label_byte( false, "1レスの最大バイト数：" ),
+      m_label_max_line( false, "1レスの最大改行数：" ),
+      m_label_max_byte( false, "1レスの最大バイト数：" ),
       m_entry_max_res( false, "最大レス数：" ),
+      m_label_last_access( false, "最終アクセス日時 ：" ),
       m_label_modified( false, "最終更新日時 ：" ),
       m_button_clearmodified( "日時クリア" ),
       m_label_samba( false, "書き込み規制秒数 (Samba24) ：" ),
@@ -60,32 +62,37 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     // JD_MAIL_BLANK の場合空白をセットする
     else if( m_entry_writemail.get_text() == JD_MAIL_BLANK ) m_entry_writemail.set_text( std::string() );
 
-    m_hbox_write.set_spacing( 8 );
-    m_hbox_write.pack_start( m_entry_writename );
-    m_hbox_write.pack_start( m_entry_writemail );
+    m_bt_clear_post_history.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_post_history ) );
+    m_hbox_write1.set_spacing( 8 );
+    m_hbox_write1.pack_start( m_check_noname );
+    m_hbox_write1.pack_start( m_bt_clear_post_history );
+
+    m_hbox_write2.set_spacing( 8 );
+    m_hbox_write2.pack_start( m_entry_writename );
+    m_hbox_write2.pack_end( m_entry_writemail, Gtk::PACK_SHRINK );
 
     m_vbox_write.set_border_width( 8 );
     m_vbox_write.set_spacing( 8 );
-    m_vbox_write.pack_start( m_check_noname, Gtk::PACK_SHRINK );
-    m_vbox_write.pack_start( m_hbox_write, Gtk::PACK_SHRINK );
+    m_vbox_write.pack_start( m_hbox_write1, Gtk::PACK_SHRINK );
+    m_vbox_write.pack_start( m_hbox_write2, Gtk::PACK_SHRINK );
 
     m_frame_write.add( m_vbox_write );
 
 
-    // cookie と hana の設定
-    std::string str_cookies_hana;
+    // cookie と 書き込みキーワード の設定
+    std::string str_cookies;
     std::list< std::string > list_cookies = DBTREE::board_list_cookies_for_write( get_url() );
-    if( list_cookies.empty() ) str_cookies_hana = "cookie: 未取得\n";
+    if( list_cookies.empty() ) str_cookies = "cookie: 未取得\n";
     else{
         std::list< std::string >::iterator it = list_cookies.begin();
         for( ; it != list_cookies.end(); ++it )
-            str_cookies_hana += "cookie: " + MISC::Iconv( (*it), DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
+            str_cookies += "cookie: " + MISC::Iconv( (*it), DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
     }
 
-    std::string hana = DBTREE::board_hana_for_write( get_url() );
-    if( ! hana.empty() ) str_cookies_hana += "\nhana: " + hana + "\n";
+    const std::string keyword = DBTREE::board_keyword_for_write( get_url() );
+    if( ! keyword.empty() ) str_cookies += "\nkeyword: " + keyword + "\n";
 
-    m_edit_cookies.set_text( str_cookies_hana );
+    m_edit_cookies.set_text( str_cookies );
 
     m_hbox_cookie.set_border_width( 8 );
     m_hbox_cookie.set_spacing( 8 );
@@ -119,13 +126,20 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_hbox_live.pack_start( m_check_live, Gtk::PACK_SHRINK );
 
     // 一般ページのパッキング
-    m_label_line.set_text( MISC::itostr( DBTREE::line_number( get_url() ) * 2 ) );
-    m_label_byte.set_text( MISC::itostr( DBTREE::message_count( get_url() ) ) );
+    m_label_max_line.set_text( MISC::itostr( DBTREE::line_number( get_url() ) * 2 ) );
+    m_label_max_byte.set_text( MISC::itostr( DBTREE::message_count( get_url() ) ) );
 
     int max_res = DBTREE::board_get_number_max_res( get_url() );
     if( ! max_res ) m_entry_max_res.set_text( "未設定 " );
     else m_entry_max_res.set_text( MISC::itostr( max_res ) );
 
+    m_hbox_max.pack_start( m_label_max_line );
+    m_hbox_max.pack_start( m_label_max_byte );
+    m_hbox_max.pack_start( m_entry_max_res );
+
+    const time_t last_access = DBTREE::board_last_access_time( get_url() );
+    if( last_access ) m_label_last_access.set_text( MISC::timettostr( last_access ) );
+
     if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
     else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
 
@@ -148,9 +162,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_vbox.pack_start( m_label_cache, Gtk::PACK_SHRINK );
 
     m_vbox.pack_start( m_label_noname, Gtk::PACK_SHRINK );
-    m_vbox.pack_start( m_label_line, Gtk::PACK_SHRINK );
-    m_vbox.pack_start( m_label_byte, Gtk::PACK_SHRINK );
-    m_vbox.pack_start( m_entry_max_res, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_hbox_max, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_label_last_access, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_modified, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_live, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_samba, Gtk::PACK_SHRINK );
@@ -161,6 +174,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_localrule = CORE::ViewFactory( CORE::VIEW_ARTICLEINFO, get_url() );
 
     // プロキシ
+    std::string host;
     m_vbox_proxy.set_border_width( 16 );
     m_vbox_proxy.set_spacing( 8 );
 
@@ -171,7 +185,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         case DBTREE::PROXY_DISABLE: m_proxy_frame.rd_disable.set_active(); break;
         case DBTREE::PROXY_LOCAL: m_proxy_frame.rd_local.set_active(); break;
     }
-    m_proxy_frame.entry_host.set_text( DBTREE::board_get_local_proxy( get_url() ) );
+    if( DBTREE::board_get_local_proxy_basicauth( get_url() ).empty() ) host = DBTREE::board_get_local_proxy( get_url() );
+    else host = DBTREE::board_get_local_proxy_basicauth( get_url() ) + "@" + DBTREE::board_get_local_proxy( get_url() );
+    m_proxy_frame.entry_host.set_text( host );
     m_proxy_frame.entry_port.set_text( MISC::itostr( DBTREE::board_get_local_proxy_port( get_url() ) ) );
 
     switch( DBTREE::board_get_mode_local_proxy_w( get_url() ) ){
@@ -179,7 +195,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         case DBTREE::PROXY_DISABLE: m_proxy_frame_w.rd_disable.set_active(); break;
         case DBTREE::PROXY_LOCAL: m_proxy_frame_w.rd_local.set_active(); break;
     }
-    m_proxy_frame_w.entry_host.set_text( DBTREE::board_get_local_proxy_w( get_url() ) );
+    if( DBTREE::board_get_local_proxy_basicauth_w( get_url() ).empty() ) host = DBTREE::board_get_local_proxy_w( get_url() );
+    else host = DBTREE::board_get_local_proxy_basicauth_w( get_url() ) + "@" + DBTREE::board_get_local_proxy_w( get_url() );
+    m_proxy_frame_w.entry_host.set_text( host );
     m_proxy_frame_w.entry_port.set_text( MISC::itostr( DBTREE::board_get_local_proxy_port_w( get_url() ) ) );
 
     m_vbox_proxy.pack_start( m_label_proxy, Gtk::PACK_SHRINK );
@@ -222,9 +240,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     // スレッドあぼーん
 
     // スレ数、時間
-    m_label_abone_thread.set_text( "以下の数字が0の時は、設定メニューの全体あぼ〜ん設定で指定した数字が用いられます。\n\n" );
+    m_label_abone_thread.set_text( "以下の数字が0の時は、設定メニューの全体あぼ〜ん設定で指定した数字が用いられます。\nまたキャッシュにログがあるスレはあぼ〜んされません。\n\n" );
 
-    m_label_number.set_text( "スレ以上のレスをあぼ〜ん" );
+    m_label_number.set_text( "レス以上のスレをあぼ〜ん" );
     m_spin_number.set_range( 0, 1001 );
     m_spin_number.set_increments( 1, 1 );
     m_spin_number.set_value( DBTREE::get_abone_number_thread( get_url() ) );
@@ -233,7 +251,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_hbox_number.pack_start( m_spin_number, Gtk::PACK_SHRINK );
     m_hbox_number.pack_start( m_label_number, Gtk::PACK_SHRINK );
 
-    m_label_hour.set_text( "時間以上スレ立てから経過したレスをあぼ〜ん" );
+    m_label_hour.set_text( "時間以上スレ立てから経過したスレをあぼ〜ん" );
     m_spin_hour.set_range( 0, 1000 );
     m_spin_hour.set_increments( 1, 1 );
     m_spin_hour.set_value( DBTREE::get_abone_hour_thread( get_url() ) );
@@ -313,10 +331,24 @@ void Preferences::slot_clear_samba()
 }
 
 
+void Preferences::slot_clear_post_history()
+{
+    SKELETON::MsgDiag mdiag( NULL, "この板にある全てのスレの書き込み履歴を削除しますか？\n\nスレ数によっては時間がかかります。",
+                             false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+
+    DBTREE::board_clear_all_post_history( get_url() );
+
+    // スレ一覧とスレビューの表示更新
+    CORE::core_set_command( "update_board", DBTREE::url_subject( get_url() ) );
+    CORE::core_set_command( "redraw_article" );
+}
+
+
 void Preferences::slot_delete_cookie()
 {
     DBTREE::board_set_list_cookies_for_write( get_url(), std::list< std::string >() );
-    DBTREE::board_set_hana_for_write( get_url(), std::string() );
+    DBTREE::board_set_keyword_for_write( get_url(), std::string() );
 
     m_edit_cookies.set_text( "未取得" );
 }
@@ -397,8 +429,7 @@ void Preferences::slot_ok_clicked()
 }
 
 
-bool Preferences::slot_timeout( int timer_number )
+void Preferences::timeout()
 {
     if( m_localrule ) m_localrule->clock_in();    
-    return true;
 }
