@@ -5,6 +5,7 @@
 #ifndef _CACHE_H
 #define _CACHE_H
 
+#include <stdint.h>
 #include <string>
 #include <list>
 
@@ -27,9 +28,6 @@ namespace CACHE
     // セッション情報ファイル
     std::string path_session();
 
-    // ディストリ判別用ファイル
-    std::string path_issue_net();
-
     // ロックファイル
     std::string path_lock();
 
@@ -54,6 +52,10 @@ namespace CACHE
 
     // ユーザーコマンド設定ファイル
     std::string path_usrcmd();
+    std::string path_usrcmd_old();
+
+    // リンクフィルタ
+    std::string path_linkfilter();
 
     // スレ履歴
     std::string path_xml_history();
@@ -67,6 +69,9 @@ namespace CACHE
     std::string path_xml_history_close();
     std::string path_xml_history_close_old();
 
+    // View履歴
+    std::string path_xml_history_view();
+
     // 板移転情報
     std::string path_movetable();
 
@@ -114,12 +119,16 @@ namespace CACHE
     // html
     std::string path_reshtml();
 
-    // 書き込みログ
-    std::string path_postlog();
+    // ログ
+    std::string path_logroot();
+    std::string path_postlog(); // 書き込みログ
 
     // 検索や名前などの補完情報
     std::string path_completion( int mode );
 
+    // サウンドファイルのルートパス
+    std::string path_sound_root();
+
     /////////////////////////////////////////////////
     //
     // ユーティリティ関数
@@ -129,6 +138,7 @@ namespace CACHE
     {
         EXIST_FILE = 0,  // ファイル
         EXIST_DIR,       // ディレクトリ
+        EXIST_FIFO,      // FIFO
         EXIST,           // 存在しない or 何か存在してる
         EXIST_ERROR      // エラー
     };
@@ -147,12 +157,13 @@ namespace CACHE
     bool mkdir_imgroot_favorite();
     bool mkdir_parent_of_board( const std::string& url );
     bool mkdir_boardroot( const std::string& url );
+    bool mkdir_logroot();
 
     // 生データ読み書き
     size_t load_rawdata( const std::string& path, std::string& str );
-    size_t load_rawdata( const std::string& path, char* data, size_t n );    
-    size_t save_rawdata( const std::string& path, const std::string& str, bool append = false );
-    size_t save_rawdata( const std::string& path, const char* data, size_t n, bool append = false );
+    size_t load_rawdata( const std::string& path, char* data, const size_t n );    
+    size_t save_rawdata( const std::string& path, const std::string& str, const bool append = false );
+    size_t save_rawdata( const std::string& path, const char* data, const size_t n, const bool append = false );
 
     // ファイル情報
     const int file_exists( const std::string& path );
