@@ -20,6 +20,8 @@ namespace CONFIG
 {
     class ConfigItems
     {
+        // 設定をロード済み
+        bool m_loaded;
 
     public:
 
@@ -49,16 +51,19 @@ namespace CONFIG
         bool use_proxy_for2ch;
         std::string proxy_for2ch;
         int proxy_port_for2ch;
+        std::string proxy_basicauth_for2ch;
 
         // 書き込み用プロクシとポート番号
         bool use_proxy_for2ch_w;
         std::string proxy_for2ch_w;
         int proxy_port_for2ch_w;
+        std::string proxy_basicauth_for2ch_w;
 
         // 2chの外にアクセスするときのプロクシとポート番号
         bool use_proxy_for_data;
         std::string proxy_for_data;
         int proxy_port_for_data;
+        std::string proxy_basicauth_for_data;
 
         // 2ch にアクセスするときのエージェント名
         std::string agent_for2ch;
@@ -109,9 +114,17 @@ namespace CONFIG
         // インライン画像を表示する
         bool use_inline_image;
 
+        // ssspアイコン表示
+        bool show_ssspicon;
+
         // 画像にモザイクかける
         bool use_mosaic;
 
+        // モザイクの大きさ
+        // 画像を一度mosaic_sizeまで縮めてから表示する
+        // 画像のサイズがmosaic_sizeより小さい場合はモザイクをかけない
+        int mosaic_size;
+
         // 画像をデフォルトでウィンドウサイズに合わせる
         bool zoom_to_fit;
 
@@ -223,6 +236,9 @@ namespace CONFIG
         // 書き込みログの最大サイズ
         int maxsize_postlog;
 
+        // 書き込み履歴を保存
+        bool save_posthist;
+
         // 「書き込み中」のダイアログを表示しない
         bool hide_writing_dialog;
 
@@ -330,6 +346,18 @@ namespace CONFIG
         // 3ペーン時にスレ一覧やスレビューを最大化するか
         bool expand_rpane;
 
+        // 次スレ検索の類似度のしきい値
+        int threshold_next;
+
+        // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
+        bool replace_favorite_next;
+
+        // スレをお気に入りに追加したときにしおりをセットする
+        bool bookmark_drop;
+
+        // Ctrl+qでウィンドウを閉じない
+        bool disable_close;
+
 #ifdef HAVE_MIGEMO_H
         // migemo-dictの場所
         std::string migemodict_path;
@@ -347,13 +375,22 @@ namespace CONFIG
         // 保存
         void save();
 
+        // フォントのリセット
+        void reset_fonts();
+
         // 色のリセット
         void reset_colors();
 
+        // プロクシ設定
+        void set_proxy_for2ch( const std::string& proxy );
+        void set_proxy_for2ch_w( const std::string& proxy );
+        void set_proxy_for_data( const std::string& proxy );
+
       private:
 
         void save_impl( const std::string& path );
 
+        void set_fonts( JDLIB::ConfLoader& cf );
         void set_colors( JDLIB::ConfLoader& cf );
     };
     
