@@ -105,6 +105,9 @@ void CONFIG::set_fontname( int id, const std::string& fontname )
     get_confitem()->fontname[ id ] = fontname;
 }
 
+void CONFIG::reset_fonts(){ get_confitem()->reset_fonts(); }
+
+
 const std::string CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix + get_confitem()->ref_prefix_space_str; }
 const int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
 
@@ -115,6 +118,9 @@ const std::string& CONFIG::get_url_bbsmenu() { return get_confitem()->url_bbsmen
 
 const bool CONFIG::use_link_as_board(){ return get_confitem()->use_link_as_board; }
 
+const bool CONFIG::get_show_movediag(){ return get_confitem()->show_movediag; }
+void CONFIG::set_show_movediag( const bool show ){ get_confitem()->show_movediag = show; }
+
 const std::string& CONFIG::get_menu_search_title(){ return get_confitem()->menu_search_title; }
 const std::string& CONFIG::get_url_search_title(){ return get_confitem()->url_search_title; }
 const std::string& CONFIG::get_regex_search_title(){ return get_confitem()->regex_search_title; }
@@ -122,22 +128,27 @@ const std::string& CONFIG::get_regex_search_title(){ return get_confitem()->rege
 const std::string& CONFIG::get_menu_search_web(){ return get_confitem()->menu_search_web; }
 const std::string& CONFIG::get_url_search_web(){ return get_confitem()->url_search_web; }
 
+const std::string& CONFIG::get_url_writep2(){ return get_confitem()->url_writep2; }
+const std::string& CONFIG::get_url_resp2(){ return get_confitem()->url_resp2; }
+
 const std::string& CONFIG::get_agent_for2ch() { return get_confitem()->agent_for2ch; }
 
 const bool CONFIG::get_use_proxy_for2ch() { return get_confitem()->use_proxy_for2ch; }
 const std::string& CONFIG::get_proxy_for2ch() { return get_confitem()->proxy_for2ch; }
 const int CONFIG::get_proxy_port_for2ch() { return get_confitem()->proxy_port_for2ch; }
+const std::string& CONFIG::get_proxy_basicauth_for2ch() { return get_confitem()->proxy_basicauth_for2ch; }
 
 void CONFIG::set_use_proxy_for2ch( bool set ){ get_confitem()->use_proxy_for2ch = set; }
-void CONFIG::set_proxy_for2ch( const std::string& proxy ){ get_confitem()->proxy_for2ch = proxy; }
+void CONFIG::set_proxy_for2ch( const std::string& proxy ){ get_confitem()->set_proxy_for2ch( proxy ); }
 void CONFIG::set_proxy_port_for2ch( int port ){ get_confitem()->proxy_port_for2ch = port; }
 
 const bool CONFIG::get_use_proxy_for2ch_w() { return get_confitem()->use_proxy_for2ch_w; }
 const std::string& CONFIG::get_proxy_for2ch_w() { return get_confitem()->proxy_for2ch_w; }
 const int CONFIG::get_proxy_port_for2ch_w() { return get_confitem()->proxy_port_for2ch_w; }
+const std::string& CONFIG::get_proxy_basicauth_for2ch_w() { return get_confitem()->proxy_basicauth_for2ch_w; }
 
 void CONFIG::set_use_proxy_for2ch_w( bool set ){ get_confitem()->use_proxy_for2ch_w = set; }
-void CONFIG::set_proxy_for2ch_w( const std::string& proxy ){ get_confitem()->proxy_for2ch_w = proxy; }
+void CONFIG::set_proxy_for2ch_w( const std::string& proxy ){ get_confitem()->set_proxy_for2ch_w( proxy ); }
 void CONFIG::set_proxy_port_for2ch_w( int port ){ get_confitem()->proxy_port_for2ch_w = port; }
 
 const std::string& CONFIG::get_agent_for_data() { return get_confitem()->agent_for_data; }
@@ -145,11 +156,12 @@ const std::string& CONFIG::get_agent_for_data() { return get_confitem()->agent_f
 const bool CONFIG::get_use_proxy_for_data() { return get_confitem()->use_proxy_for_data; }
 const std::string& CONFIG::get_proxy_for_data() { return get_confitem()->proxy_for_data; }
 const int CONFIG::get_proxy_port_for_data() { return get_confitem()->proxy_port_for_data; }
+const std::string& CONFIG::get_proxy_basicauth_for_data() { return get_confitem()->proxy_basicauth_for_data; }
 
 const std::string& CONFIG::get_x_2ch_ua() { return get_confitem()->x_2ch_ua; }
 
 void CONFIG::set_use_proxy_for_data( bool set ){ get_confitem()->use_proxy_for_data = set; }
-void CONFIG::set_proxy_for_data( const std::string& proxy ){ get_confitem()->proxy_for_data = proxy; }
+void CONFIG::set_proxy_for_data( const std::string& proxy ){ get_confitem()->set_proxy_for_data( proxy ); }
 void CONFIG::set_proxy_port_for_data( int port ){ get_confitem()->proxy_port_for_data = port; }
 
 const int CONFIG::get_loader_bufsize(){ return get_confitem()->loader_bufsize; }
@@ -175,22 +187,26 @@ const int CONFIG::get_imgpopup_width(){ return get_confitem()->imgpopup_width; }
 const int CONFIG::get_imgpopup_height(){ return get_confitem()->imgpopup_height; }
 
 const bool CONFIG::get_use_image_popup(){ return get_confitem()->use_image_popup; }
-void CONFIG::set_use_image_popup( bool use ){ get_confitem()->use_image_popup = use; }
+void CONFIG::set_use_image_popup( const bool use ){ get_confitem()->use_image_popup = use; }
 
 const bool CONFIG::get_use_image_view(){ return get_confitem()->use_image_view; }
-void CONFIG::set_use_image_view( bool image_view ){ get_confitem()->use_image_view = image_view; }
+void CONFIG::set_use_image_view( const bool image_view ){ get_confitem()->use_image_view = image_view; }
 
 const bool CONFIG::get_use_inline_image(){ return get_confitem()->use_inline_image; }
-void CONFIG::set_use_inline_image( bool inline_img ){ get_confitem()->use_inline_image = inline_img; }
+void CONFIG::set_use_inline_image( const bool inline_img ){ get_confitem()->use_inline_image = inline_img; }
+
+const bool CONFIG::get_show_ssspicon(){ return get_confitem()->show_ssspicon; }
+void CONFIG::set_show_sssp_icon( const bool show ){ get_confitem()->show_ssspicon = show; }
 
 const bool CONFIG::get_use_mosaic(){ return get_confitem()->use_mosaic; }
-void CONFIG::set_use_mosaic( bool mosaic ) { get_confitem()->use_mosaic = mosaic; }
+void CONFIG::set_use_mosaic( const bool mosaic ) { get_confitem()->use_mosaic = mosaic; }
+const int CONFIG::get_mosaic_size(){ return get_confitem()->mosaic_size; }
 const bool CONFIG::get_zoom_to_fit(){ return get_confitem()->zoom_to_fit; }
-void CONFIG::set_zoom_to_fit( bool fit ){ get_confitem()->zoom_to_fit = fit; }
+void CONFIG::set_zoom_to_fit( const bool fit ){ get_confitem()->zoom_to_fit = fit; }
 const int CONFIG::get_del_img_day(){ return get_confitem()->del_img_day; }
-void CONFIG::set_del_img_day( int day ){ get_confitem()->del_img_day = day; }
+void CONFIG::set_del_img_day( const int day ){ get_confitem()->del_img_day = day; }
 const int CONFIG::get_del_imgabone_day(){ return get_confitem()->del_imgabone_day; }
-void CONFIG::set_del_imgabone_day( int day ){ get_confitem()->del_imgabone_day = day; }
+void CONFIG::set_del_imgabone_day( const int day ){ get_confitem()->del_imgabone_day = day; }
 const int CONFIG::get_max_img_size(){ return get_confitem()->max_img_size; }
 const int CONFIG::get_max_img_pixel(){ return get_confitem()->max_img_pixel; }
 
@@ -201,6 +217,9 @@ const int CONFIG::get_newthread_hour(){ return get_confitem()->newthread_hour; }
 
 const bool CONFIG::get_inc_search_board(){ return get_confitem()->inc_search_board; }
 
+const bool CONFIG::get_show_deldiag(){ return get_confitem()->show_deldiag; }
+void CONFIG::set_show_deldiag( const bool show ){ get_confitem()->show_deldiag = show; }
+
 const int CONFIG::get_tree_scroll_size(){ return get_confitem()->tree_scroll_size; }
 const int CONFIG::get_scroll_size(){ return get_confitem()->scroll_size; }
 const int CONFIG::get_key_scroll_size(){ return get_confitem()->key_scroll_size; }
@@ -219,12 +238,17 @@ const int CONFIG::get_live_threshold(){ return get_confitem()->live_threshold; }
 void CONFIG::set_live_threshode( const int th ){ get_confitem()->live_threshold = th; }
 
 const bool CONFIG::get_open_one_category(){ return get_confitem()->open_one_category; }
+const bool CONFIG::get_open_one_favorite(){ return get_confitem()->open_one_favorite; }
 const bool CONFIG::get_always_write_ok() { return get_confitem()->always_write_ok; }
 void CONFIG::set_always_write_ok( bool write_ok ){ get_confitem()->always_write_ok = write_ok; }
 
-const bool CONFIG::get_save_postlog(){ return get_confitem()->save_postlog; }
-void CONFIG::set_save_postlog( bool save ){ get_confitem()->save_postlog = save; }
-const size_t CONFIG::get_maxsize_postlog(){ return get_confitem()->maxsize_postlog; }
+const bool CONFIG::get_save_post_log(){ return get_confitem()->save_postlog; }
+void CONFIG::set_save_post_log( bool save ){ get_confitem()->save_postlog = save; }
+const size_t CONFIG::get_maxsize_post_log(){ return get_confitem()->maxsize_postlog; }
+
+// 書き込み履歴を保存
+const bool CONFIG::get_save_post_history(){ return get_confitem()->save_posthist; }
+void CONFIG::set_save_post_history( bool save ){ get_confitem()->save_posthist = save; }
 
 const bool CONFIG::get_hide_writing_dialog(){ return get_confitem()->hide_writing_dialog; }
 const bool CONFIG::get_fold_message(){ return get_confitem()->fold_message; }
@@ -288,7 +312,7 @@ const int CONFIG::get_num_id_low(){ return get_confitem()->num_id_low; }
 const bool CONFIG::get_loose_url(){ return get_confitem()->loose_url; }
 
 const bool CONFIG::get_hide_usrcmd(){ return get_confitem()->hide_usrcmd; }
-const int CONFIG::get_max_show_usrcmd(){ return get_confitem()->max_show_usrcmd; }
+void CONFIG::set_hide_usrcmd( bool hide ){ get_confitem()->hide_usrcmd = hide; }
 
 const bool CONFIG::get_reload_allthreads(){ return get_confitem()->reload_allthreads; }
 
@@ -361,6 +385,22 @@ void CONFIG::set_abone_chain( bool set ){ get_confitem()->abone_chain = set; }
 
 const bool CONFIG::get_expand_sidebar(){ return get_confitem()->expand_sidebar; }
 
+const bool CONFIG::get_expand_rpane(){ return get_confitem()->expand_rpane; }
+
+
+// 次スレ検索の類似度のしきい値
+const int CONFIG::get_threshold_next(){ return get_confitem()->threshold_next; }
+
+// 次スレを開いたときにお気に入りのアドレスと名前を自動更新
+const bool CONFIG::get_replace_favorite_next(){ return get_confitem()->replace_favorite_next; }
+
+// スレをお気に入りに追加したときにしおりをセットする
+const bool CONFIG::get_bookmark_drop(){ return get_confitem()->bookmark_drop; }
+
+// Ctrl+qでウィンドウを閉じない
+const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
+
+
 #ifdef HAVE_MIGEMO_H
 const std::string& CONFIG::get_migemodict_path() { return get_confitem()->migemodict_path; }
 #endif
