@@ -56,6 +56,7 @@ namespace CONFIG
     // フォント
     const std::string& get_fontname( int id );
     void set_fontname( int id, const std::string& fontname );
+    void reset_fonts();
 
     // レスを参照するときに前に付ける文字
     const std::string get_ref_prefix();
@@ -100,23 +101,25 @@ namespace CONFIG
     // 2ch にログインするときのX-2ch-UA
     const std::string& get_x_2ch_ua();
 
-    // 読み込み用プロクシとポート番号
+    // 2ch 読み込み用プロクシとポート番号
     const bool get_use_proxy_for2ch();
     const std::string& get_proxy_for2ch();
     const int get_proxy_port_for2ch();
+    const std::string& get_proxy_basicauth_for2ch();
 
-    void set_use_proxy_for2ch( bool set );
+    void set_use_proxy_for2ch( const bool set );
     void set_proxy_for2ch( const std::string& proxy );
-    void set_proxy_port_for2ch( int port );
+    void set_proxy_port_for2ch( const int port );
 
-    // 書き込み用プロクシとポート番号
+    // 2ch 書き込み用プロクシとポート番号
     const bool get_use_proxy_for2ch_w();
     const std::string& get_proxy_for2ch_w();
     const int get_proxy_port_for2ch_w();
+    const std::string& get_proxy_basicauth_for2ch_w();
 
-    void set_use_proxy_for2ch_w( bool set );
+    void set_use_proxy_for2ch_w( const bool set );
     void set_proxy_for2ch_w( const std::string& proxy );
-    void set_proxy_port_for2ch_w( int port );
+    void set_proxy_port_for2ch_w( const int port );
 
     // 2ch外にアクセスするときのエージェント名
     const std::string& get_agent_for_data();
@@ -125,10 +128,11 @@ namespace CONFIG
     const bool get_use_proxy_for_data();
     const std::string& get_proxy_for_data();
     const int get_proxy_port_for_data();
+    const std::string& get_proxy_basicauth_for_data();
 
-    void set_use_proxy_for_data( bool set );
+    void set_use_proxy_for_data( const bool set );
     void set_proxy_for_data( const std::string& proxy );
-    void set_proxy_port_for_data( int port );
+    void set_proxy_port_for_data( const int port );
 
     // ローダのバッファサイズ
     const int get_loader_bufsize();
@@ -166,31 +170,38 @@ namespace CONFIG
 
     // 画像ポップアップを使用する
     const bool get_use_image_popup();
-    void set_use_image_popup( bool use );
+    void set_use_image_popup( const bool use );
 
     // 画像ビューを使用する
     const bool get_use_image_view();
-    void set_use_image_view( bool image_view );
+    void set_use_image_view( const bool image_view );
 
     // インライン画像表示をする
     const bool get_use_inline_image();
-    void set_use_inline_image( bool inline_img );
+    void set_use_inline_image( const bool inline_img );
+
+    // ssspアイコン表示
+    const bool get_show_ssspicon();
+    void set_show_sssp_icon( const bool show );
 
     // 画像にモザイクかける
     const bool get_use_mosaic();
-    void set_use_mosaic( bool mosaic );
+    void set_use_mosaic( const bool mosaic );
+
+    // モザイクの大きさ
+    const int get_mosaic_size();
 
     // 画像をデフォルトでウィンドウサイズに合わせる
     const bool get_zoom_to_fit();
-    void set_zoom_to_fit( bool fit );
+    void set_zoom_to_fit( const bool fit );
 
     // 画像キャッシュ削除の日数
     const int get_del_img_day();
-    void set_del_img_day( int day );
+    void set_del_img_day( const int day );
 
     // 画像あぼーん削除の日数
     const int get_del_imgabone_day();
-    void set_del_imgabone_day( int day );
+    void set_del_imgabone_day( const int day );
 
     // ダウンロードする画像の最大ファイルサイズ(Mbyte)
     const int get_max_img_size();
@@ -255,11 +266,15 @@ namespace CONFIG
     void set_always_write_ok( bool write_ok );
 
     // 書き込みログを保存
-    const bool get_save_postlog();
-    void set_save_postlog( bool save );
+    const bool get_save_post_log();
+    void set_save_post_log( bool save );
 
     // 書き込みログの最大サイズ
-    const size_t get_maxsize_postlog();
+    const size_t get_maxsize_post_log();
+
+    // 書き込み履歴を保存
+    const bool get_save_post_history();
+    void set_save_post_history( bool save );
 
     // 書き込み中のダイアログを表示しない
     const bool get_hide_writing_dialog();
@@ -380,6 +395,18 @@ namespace CONFIG
     // 3ペーン時にスレ一覧やスレビューを最大化するか
     const bool get_expand_rpane();
 
+    // 次スレ検索の類似度のしきい値
+    const int get_threshold_next();
+
+    // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
+    const bool get_replace_favorite_next();
+
+    // スレをお気に入りに追加したときにしおりをセットする
+    const bool get_bookmark_drop();
+
+    // Ctrl+qでウィンドウを閉じない
+    const bool get_disable_close();
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     const std::string& get_migemodict_path();
