@@ -131,10 +131,12 @@ namespace CORE
 
         void slot_activate_menubar();
 
-        void slot_toggle_save_postlog();
+        void slot_toggle_save_post_log();
+        void slot_toggle_save_post_history();
         void slot_toggle_use_mosaic();
         void slot_toggle_use_imgpopup();
         void slot_toggle_use_inlineimg();
+        void slot_toggle_show_ssspicon();
         void slot_delete_all_images();
 
         void slot_clear_privacy();
@@ -144,6 +146,8 @@ namespace CORE
         void slot_clear_search();
         void slot_clear_name();
         void slot_clear_mail();
+        void slot_clear_post_log();
+        void slot_clear_post_history();
 
         void slot_changefont_main();
         void slot_changefont_popup();
@@ -155,6 +159,9 @@ namespace CORE
         bool open_color_diag( std::string title, int id );
         
         void slot_setup_fontcolor();
+        void slot_setup_key();
+        void slot_setup_mouse();
+        void slot_setup_button();
         void slot_setup_proxy();
         void slot_setup_passwd();
         void slot_toggle_ipv6();
@@ -167,6 +174,8 @@ namespace CORE
         void slot_board_pref();
         void slot_article_pref();
         void slot_image_pref();
+        void slot_usrcmd_pref();
+        void slot_filter_pref();
         void slot_setup_browser();
         void slot_setup_abone();
         void slot_setup_abone_thread();
@@ -181,12 +190,14 @@ namespace CORE
         void slot_quit();
         void slot_reload_list();
         void slot_check_update_root();
+        void slot_edit_favorite();
         void slot_check_update_open_root();
         void slot_cancel_check_update();
         void slot_save_favorite();
         void slot_toggle_online();
         void slot_toggle_login2ch();
         void slot_toggle_loginbe();
+        void slot_toggle_loginp2();
         void toggle_menubar();
         void toggle_flat_button();
         void toggle_post_mark();
@@ -226,7 +237,7 @@ namespace CORE
         void exec_command_after_boot();
 
         // フォーカス回復
-        void restore_focus( bool force, bool present );
+        void restore_focus( const bool force, const bool present );
 
         // メインタイマー
         bool slot_timeout( int timer_number );
