@@ -111,10 +111,43 @@ void Img::clear()
     m_height = 0;
     m_width_emb = 0;
     m_height_emb = 0;
+    m_width_mosaic = 0;
+    m_height_mosaic = 0;
     m_abone = false;
 }
 
 
+// スレ埋め込み画像の高さ、幅
+const int Img::get_width_emb()
+{
+    if( ! m_width_emb ) set_embedded_size();
+
+    return m_width_emb;
+}
+
+const int Img::get_height_emb()
+{
+    if( ! m_height_emb ) set_embedded_size();
+
+    return m_height_emb;
+}
+
+
+// モザイク処理時に縮小するサイズ
+const int Img::get_width_mosaic()
+{
+    if( ! m_width_mosaic ) set_mosaic_size();
+
+    return m_width_mosaic;
+}
+
+const int Img::get_height_mosaic()
+{
+    if( ! m_height_mosaic ) set_mosaic_size();
+
+    return m_height_mosaic;
+}
+
 
 const bool Img::is_cached()
 {
@@ -157,7 +190,10 @@ const std::string Img::get_cache_path()
 //
 // receive_data()　と receive_finish() がコールバックされる
 //
-void Img::download_img( const std::string refurl )
+// refurl : 参照元のスレのアドレス
+// nomosaic : trueの時はモザイク解除
+//
+void Img::download_img( const std::string& refurl, const bool nomosaic )
 {
     // ダウンロード初回(リダイレクトでは無い)
     if( ! m_count_redirect ) m_url_alt = std::string();
@@ -185,6 +221,7 @@ void Img::download_img( const std::string refurl )
 
     clear();
     m_refurl = refurl;
+    if( nomosaic ) m_mosaic = false;
                
     JDLIB::LOADERDATA data;
 
@@ -195,6 +232,7 @@ void Img::download_img( const std::string refurl )
     if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
     else data.host_proxy = std::string();
     data.port_proxy = CONFIG::get_proxy_port_for_data();
+    data.basicauth_proxy = CONFIG::get_proxy_basicauth_for_data();
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout_img();
 
@@ -350,6 +388,7 @@ void Img::receive_data( const char* data, size_t size )
             stop_load();
 
 #ifdef _DEBUG
+            std::cout << "no image : size = " << size << std::endl;
             std::cout << data << std::endl;
 #endif
         }
@@ -376,7 +415,9 @@ void Img::receive_finish()
 {
 #ifdef _DEBUG
     std::cout << "Img::receive_finish code = " << get_code() << std::endl
+              << "strcode = " << get_str_code() << std::endl
               << "total byte = " << total_length() << std::endl
+              << "contenttype = " << get_contenttype() << std::endl
               << "cookies : " << std::endl;
 
     if( cookies().size() ){
@@ -401,9 +442,13 @@ void Img::receive_finish()
         if( url_tmp.find( "404" ) != std::string::npos && url_tmp.find( ".htm" ) != std::string::npos ) m_type = T_NOT_FOUND;
 
         else if( ! location().empty() && m_count_redirect < MAX_REDIRECT ){
+
+#ifdef _DEBUG
+            std::cout << "exec redirect\n";
+#endif
             ++m_count_redirect;
             m_url_alt = location();
-            download_img( m_refurl );
+            download_img( m_refurl, false );
             return;
         }
         else m_type = T_NODATA;
@@ -417,7 +462,6 @@ void Img::receive_finish()
 
         MISC::get_img_size( get_cache_path(), m_width, m_height );
         if( ! m_width || ! m_height ) m_type = T_NOSIZE;
-        else set_embedded_size();
     }
 
 
@@ -426,7 +470,7 @@ void Img::receive_finish()
 
     if( m_type == T_NOIMG ){
         set_code( HTTP_ERR );
-        set_str_code( "画像ファイルではありません" );
+        set_str_code( "画像ファイルではありません (" + get_contenttype() + ")" );
         set_current_length( 0 );
     }
 
@@ -497,6 +541,14 @@ void Img::receive_finish()
               << "refurl = " << m_refurl << std::endl;
 #endif
 
+    // 画像が小さい場合はモザイクを解除
+    if( m_width && m_height ){
+
+        const int minsize = MAX( 1, CONFIG::get_mosaic_size() );
+        if( m_width >= m_height && m_width < minsize ) m_mosaic = false;
+        else if( m_width < m_height && m_height < minsize ) m_mosaic = false;
+    }
+
     // 拡張子が偽装されている時はモザイク表示にする
     if( is_fake() ) m_mosaic = true;
 
@@ -519,9 +571,14 @@ void Img::set_embedded_size()
     double scale_w = ( double ) MAX_WIDTH_EMB / m_width;
     double scale_h = ( double ) MAX_HEIGHT_EMB / m_height;
     scale = MIN( scale_w, scale_h );
-
-    m_width_emb = (int)( m_width * scale );
-    m_height_emb = (int)( m_height * scale );
+    if( scale < 1.0 ){
+        m_width_emb = (int)( m_width * scale );
+        m_height_emb = (int)( m_height * scale );
+    }
+    else{
+        m_width_emb = m_width;
+        m_height_emb = m_height;
+    }
 
 #ifdef _DEBUG
     std::cout << "Img::set_embedded_size w = " << m_width_emb << " h = " << m_height_emb << std::endl;
@@ -529,6 +586,34 @@ void Img::set_embedded_size()
 }
 
 
+// モザイク処理時に縮小するサイズを経産
+void Img::set_mosaic_size()
+{
+    if( ! m_width || ! m_height ) return;
+
+    // 一旦元画像の横幅を mossize ピクセルまで縮めてから描画サイズに戻す
+    const int mossize = MAX( 1, CONFIG::get_mosaic_size() );
+    int moswidth = m_width;
+    int mosheight = m_height;
+
+    if( moswidth >= mosheight ){
+
+        const int dev = MAX( 1, moswidth / mossize );
+        mosheight /= dev;
+        moswidth = mossize;
+    }
+    else{
+
+        const int dev = MAX( 1, mosheight / mossize );
+        mosheight = mossize;
+        moswidth /= dev;
+    }
+
+    m_width_mosaic = MAX( 1, moswidth );
+    m_height_mosaic = MAX( 1, mosheight );
+}
+
+
 //
 // キャッシュ情報読み込み
 //
@@ -637,7 +722,6 @@ void Img::read_info()
             if( total_length() ) save_info();
         }
         set_current_length( total_length() );
-        set_embedded_size();
     }
 
 #ifdef _DEBUG
