@@ -13,6 +13,7 @@
 #include "jdlib/misctime.h"
 #include "jdlib/miscmsg.h"
 #include "jdlib/jdregex.h"
+#include "jdlib/tfidf.h"
 
 #include "config/globalconf.h"
 
@@ -79,11 +80,10 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_bookmarked_thread( false ),
       m_cached( cached ),
       m_read_info( 0 ),
-      m_save_info( 0 ),
-      m_enable_load( false )
+      m_save_info( 0 )
 {
 #ifdef _DEBUG
-    std::cout << "ArticleBase::ArticleBase : " << m_id << std::endl;
+//    std::cout << "ArticleBase::ArticleBase : " << m_id << std::endl;
 #endif
 
     memset( &m_access_time, 0, sizeof( struct timeval ) );
@@ -103,7 +103,7 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
 ArticleBase::~ArticleBase()
 {
 #ifdef _DEBUG
-    std::cout << "ArticleBase::~ArticleBase : " << m_id << std::endl;
+//    std::cout << "ArticleBase::~ArticleBase : " << m_id << std::endl;
 #endif
 
     // 参照ロックが外れていない
@@ -347,6 +347,7 @@ void ArticleBase::update_datbase( const std::string& datbase )
 #endif
 
     // URL 更新
+    m_datbase = datbase;
     m_url = datbase + m_id;
 
     // info ファイルのパスも更新
@@ -425,22 +426,26 @@ void ArticleBase::set_subject( const std::string& subject )
 }
 
 
-void ArticleBase::set_number( int number )
+void ArticleBase::set_number( const int number )
 {
     if( number && number > m_number ){
+
         m_number = number;
-        if( m_number_load < m_number ) m_enable_load = true;
+
+        // キャッシュがあって更新可能になった場合は
+        // スレの場合はお気に入りとスレタブのアイコンを更新
+        if( is_cached() && !( m_status & STATUS_UPDATE ) && m_number_load < m_number ) show_updateicon( true );
     }
 }
 
 
-void ArticleBase::set_number_load( int number_load )
+void ArticleBase::set_number_load( const int number_load )
 {
     if( number_load && number_load != m_number_load ) m_number_load = number_load;
 }
 
 
-void ArticleBase::set_number_seen( int number_seen )
+void ArticleBase::set_number_seen( const int number_seen )
 {
     if( number_seen && number_seen != m_number_seen ){
         m_number_seen = number_seen;
@@ -448,6 +453,7 @@ void ArticleBase::set_number_seen( int number_seen )
     }
 }
 
+
 //
 // 書き込み時間更新
 //
@@ -455,7 +461,7 @@ void ArticleBase::update_writetime()
 {
     struct timeval tv;
     struct timezone tz;
-    if( gettimeofday( &tv, &tz ) == 0 ){
+    if( CONFIG::get_save_post_history() && gettimeofday( &tv, &tz ) == 0 ){
 
         m_write_time = tv;
         m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
@@ -469,26 +475,11 @@ void ArticleBase::update_writetime()
         CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
     }
 
-    // 板の書き込み時間も更新
+    // 板の書き込み時間を更新
     DBTREE::board_update_writetime( m_url );
 }
 
 
-//
-// 経過時間(秒)
-//
-const time_t ArticleBase::get_write_pass()
-{
-    time_t ret = 0;
-    struct timeval tv;
-    struct timezone tz;
-
-    if( m_write_time.tv_sec && gettimeofday( &tv, &tz ) == 0 ) ret = MAX( 0, tv.tv_sec - m_write_time.tv_sec );
-
-    return ret;
-}
-
-
 //
 // 書き込み数
 //
@@ -505,7 +496,7 @@ const int ArticleBase::get_num_posted()
 //
 // スレ自体のスレ一覧でのブックマーク
 //
-void ArticleBase::set_bookmarked_thread( bool bookmarked )
+void ArticleBase::set_bookmarked_thread( const bool bookmarked )
 {
     m_bookmarked_thread = bookmarked;
     save_info( true );
@@ -515,6 +506,15 @@ void ArticleBase::set_bookmarked_thread( bool bookmarked )
 }
 
 
+//
+// キャッシュがあって、かつ新着の読み込みが可能
+//
+const bool ArticleBase::enable_load()
+{
+    return ( is_cached() && ( m_status & STATUS_UPDATE ) );
+}
+
+
 //
 // キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
 //
@@ -584,9 +584,9 @@ void ArticleBase::update_abone()
 // あぼーん状態のリセット(情報セットと状態更新)
 //
 void ArticleBase::reset_abone( std::list< std::string >& ids, std::list< std::string >& names
-                               ,std::list< std::string >& words, std::list< std::string >& regexs
-                               ,std::vector< char >& vec_abone_res
-                               ,bool transparent, bool chain )
+                               ,std::list< std::string >& words,  std::list< std::string >& regexs
+                               ,const std::vector< char >& vec_abone_res
+                               ,const bool transparent, const bool chain )
 {
     if( empty() ) return;
 
@@ -812,6 +812,37 @@ const bool ArticleBase::is_refer_posted( const int number )
 }
 
 
+// 書き込み履歴のリセット
+void ArticleBase::clear_post_history()
+{
+    if( empty() ) return;
+    if( ! is_cached() ) return;
+
+    read_info();
+    if( m_vec_posted.size() || m_write_time.tv_sec || m_write_time.tv_usec ){
+
+#ifdef _DEBUG
+        std::cout << "ArticleBase::clear_post_history size = " << m_vec_posted.size()
+                  << " time = " << m_write_time_date
+                  << " subject = " << m_subject << std::endl;
+#endif
+        m_vec_posted.clear();
+        memset( &m_write_time, 0, sizeof( struct timeval ) );
+        m_write_time_date = std::string();
+
+        // nodetreeが作られている時はnodetreeもリセット
+        if( m_nodetree ) m_nodetree->clear_post_history();
+
+        m_write_name = std::string();
+        m_write_mail = std::string();
+        m_write_fixname = false;
+        m_write_fixmail = false;
+
+        save_info( true );
+    }
+}
+
+
 //
 // NodeTree作成
 //
@@ -911,7 +942,9 @@ void ArticleBase::download_dat( const bool check_update )
     if( empty() ) return;
 
 #ifdef _DEBUG
-    std::cout << "ArticleBase::download_dat " << m_url << " status = " << m_status << " checkupdate = " << check_update << std::endl;
+    std::cout << "ArticleBase::download_dat " << m_url << " status = " << m_status
+              << " checkupdate = " << check_update << std::endl
+              << "url_pre_article = " << m_url_pre_article << std::endl;
 #endif
 
     struct timeval tv;
@@ -922,6 +955,15 @@ void ArticleBase::download_dat( const bool check_update )
 
         if( ! SESSION::is_online() ) return;
 
+        // 既に更新状態の時はチェックしない
+        if( enable_load() ){
+
+            // 次のスレを更新チェック
+            CORE::get_checkupdate_manager()->pop_front();
+
+            return;
+        }
+
         // 一度更新チェックしたらしばらくは再チェックできないようにする
         time_t passed = 0;
         if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
@@ -955,6 +997,72 @@ void ArticleBase::download_dat( const bool check_update )
 }
 
 
+//
+// 前スレのアドレスの指定
+//
+// 前スレのアドレスをセットしてからdownload_dat()を呼び出すと
+// ロード終了時( slot_load_finished() )に次スレ移行チェックをする
+//
+void ArticleBase::set_url_pre_article( const std::string& url_pre_article )
+{
+#ifdef _DEBUG
+    std::cout << "ArticleBase::set_url_pre_article url = " << url_pre_article << std::endl;
+#endif
+
+    m_url_pre_article = url_pre_article;
+
+    if( ! m_url_pre_article.empty() ){
+
+        // 既読スレや板違いのスレに対しては移行チェックはしない
+        if( m_number_load
+            || m_datbase != DBTREE::url_datbase( m_url_pre_article )
+            || get_since_time() < DBTREE::article_since_time( m_url_pre_article )
+            ) m_url_pre_article = std::string();
+    }
+
+    // TFIDFによる類似度判定のためオフラインに切り替えてからキャッシュにあるsubject.txtを読み込む
+    if( ! m_url_pre_article.empty() && ! DBTREE::board_list_subject( m_url ).size() ){
+
+#ifdef _DEBUG
+        std::cout << "load subjects\n";
+#endif
+
+        const bool online = SESSION::is_online();
+        SESSION::set_online( false );
+
+        DBTREE::board_download_subject( m_url, std::string() );
+
+        SESSION::set_online( online );
+    }
+}
+
+
+//
+// url_src で示されるスレの情報をコピー
+//
+void ArticleBase::copy_article_info( const std::string& url_src )
+{
+    if( url_src.empty() ) return;
+    if( ! DBTREE::article_is_cached( url_src ) ) return;
+
+    // 名前、メール
+    m_write_fixname = DBTREE::write_fixname( url_src );
+    m_write_name = DBTREE::write_name( url_src );
+
+    m_write_fixmail = DBTREE::write_fixmail( url_src );
+    m_write_mail = DBTREE::write_mail( url_src );
+
+    // あぼーん関係
+    std::list< std::string > ids;
+    std::list< std::string > names = DBTREE::get_abone_list_name( url_src );
+    std::list< std::string > words = DBTREE::get_abone_list_word( url_src );
+    std::list< std::string > regexs = DBTREE::get_abone_list_regex( url_src );
+    std::vector< char > vec_abone_res;
+    const bool transparent = DBTREE::get_abone_transparent( url_src );
+    const bool chain = DBTREE::get_abone_chain( url_src );
+
+    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain );
+}
 
 
 //
@@ -1035,16 +1143,22 @@ void ArticleBase::slot_load_finished()
         std::cout << "check_update code = " << m_code << std::endl;
 #endif
 
-        // スレタブとお気に入りのアイコンを更新
+        // スレタブとお気に入りとスレ一覧のアイコンを更新
         if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
 
             show_updateicon( true );
+
+            CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
         }
 
         // code と modified を戻しておく
         m_code = old_code;
         m_nodetree->set_date_modified( m_date_modified );
 
+#ifdef _DEBUG
+        std::cout << "check_update done\n";
+#endif
+
         // 次のスレを更新チェック
         CORE::get_checkupdate_manager()->pop_front();
 
@@ -1074,6 +1188,88 @@ void ArticleBase::slot_load_finished()
         }
     }
 
+    // 次スレチェック
+    bool relayout = false;
+    if( m_number_load && ! m_url_pre_article.empty() && ! m_subject.empty() ){
+
+        const std::string pre_subject = DBTREE::article_subject( m_url_pre_article );
+        if( ! pre_subject.empty() ){
+
+#ifdef _DEBUG
+            std::cout << "check next\n";
+#endif
+            int value = 0;
+
+            const std::list< DBTREE::ArticleBase* >& list_subject = DBTREE::board_list_subject( m_url );
+
+            // subjectがキャッシュにある場合は TFIDF を使って類似度チェック
+            if( list_subject.size() ){
+#ifdef _DEBUG
+                std::cout << "use tfidf\n";
+#endif
+                // 単語ベクトル作成
+                MISC::VEC_WORDS vec_words;
+                MISC::tfidf_create_vec_words( vec_words, pre_subject );
+
+                // IDFベクトル計算
+                MISC::VEC_IDF vec_idf;
+                MISC::tfidf_create_vec_idf_from_board( vec_idf, pre_subject, list_subject, vec_words );
+
+                // TFIDFベクトル計算
+                MISC::VEC_TFIDF vec_tfidf_src;
+                MISC::VEC_TFIDF vec_tfidf;
+                vec_tfidf_src.resize( vec_words.size() );
+                vec_tfidf.resize( vec_words.size() );
+                MISC::tfidf_calc_vec_tfifd( vec_tfidf_src, pre_subject, vec_idf, vec_words );
+                MISC::tfidf_calc_vec_tfifd( vec_tfidf, m_subject, vec_idf, vec_words );
+
+                value = ( int )( MISC::tfidf_cos_similarity( vec_tfidf_src, vec_tfidf ) * 10 + .5 );
+            }
+
+            // subject がキャッシュに無い場合はレーベンシュタイン距離を使って類似度チェック
+            else{
+#ifdef _DEBUG
+                std::cout << "use leven\n";
+#endif
+                const int MAXSTR = 256;
+                std::vector< std::vector< int > > dist( MAXSTR, std::vector< int >( MAXSTR ) );
+                value = 10 - ( int )( MISC::leven( dist, pre_subject, m_subject ) * 10 + .5 );
+            }
+
+#ifdef _DEBUG
+            std::cout << "pre_subject = " << pre_subject << std::endl
+                      << "subject = " << m_subject << std::endl
+                      << "value = " << value << std::endl;
+#endif
+
+            // このスレは m_url_pre_article の次スレとみなして情報をコピーする
+            if( value >= CONFIG::get_threshold_next() ){
+
+#ifdef _DEBUG
+                std::cout << "hit!\n";
+#endif
+                copy_article_info( m_url_pre_article );
+
+                // お気に入りのアドレスと名前を自動更新
+                if( CONFIG::get_replace_favorite_next() ){
+                    CORE::core_set_command( "replace_favorite_thread", "", m_url_pre_article, m_url );
+                }
+
+                // 前スレにしおりがセットされていたらしおりをつける
+                if( DBTREE::is_bookmarked_thread( m_url_pre_article ) ){
+                    set_bookmarked_thread( true );
+                }
+
+                relayout = true;
+            }
+#ifdef _DEBUG
+            else std::cout << "not hit\n";
+#endif
+        }
+
+        m_url_pre_article = std::string();
+    }
+
     m_number_before_load = m_number_load;
     m_ext_err = m_nodetree->get_ext_err();
 
@@ -1087,21 +1283,20 @@ void ArticleBase::slot_load_finished()
             || m_date_modified != m_old_modified // ときどき modified が誤って返るときがあるので最新の値を保存しておく
             ){
 
+            m_cached = true;
+            m_read_info = true;
+            m_save_info = true;
+
             struct timeval tv;
             struct timezone tz;
             if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
 
             if( m_number < m_number_load ) m_number = m_number_load;
 
-            m_cached = true;
-            m_read_info = true;
-            m_save_info = true;
-            m_enable_load = false;
+            show_updateicon( false );
 
             // 情報ファイルのパスをセット
             if( m_path_article_info.empty() ) SET_INFOPATH();
-
-            show_updateicon( false );
         }
     }
 
@@ -1125,6 +1320,9 @@ void ArticleBase::slot_load_finished()
     // articleビューに終了を知らせる
     CORE::core_set_command( "update_article", m_url );
     CORE::core_set_command( "update_article_finish", m_url );
+
+    // あぼーん情報が前スレよりコピーされたので再レイアウト指定
+    if( relayout ) CORE::core_set_command( "relayout_article", m_url );
 }
 
 
@@ -1132,12 +1330,13 @@ void ArticleBase::slot_load_finished()
 //
 // 更新アイコン表示
 //
-// updated == true の時に表示。falseなら戻す
+// update == true の時に表示。falseなら戻す
 //
 void ArticleBase::show_updateicon( const bool update )
 {
 #ifdef _DEBUG
-    std::cout << "ArticleBase::show_updateicon url = " << m_url << " update = " << update << " status = " << m_status << std::endl;
+    std::cout << "ArticleBase::show_updateicon url = " << m_url
+              << " update = " << update << " status = " << ( m_status & STATUS_UPDATE ) << std::endl;
 #endif
 
     struct timeval tv;
@@ -1146,19 +1345,27 @@ void ArticleBase::show_updateicon( const bool update )
 
     if( update ){
 
-        if( ! ( m_status & STATUS_UPDATE ) ){
-            m_status |= STATUS_UPDATE;
-            CORE::core_set_command( "toggle_article_icon", m_url);
-            CORE::core_set_command( "toggle_favorite_icon", m_url );
-        }
+#ifdef _DEBUG
+        std::cout << "toggle_icon on\n";
+#endif
+
+        if( ! ( m_status & STATUS_UPDATE ) ) m_save_info = true;
+        m_status |= STATUS_UPDATE;
+
+        CORE::core_set_command( "toggle_article_icon", m_url);
+        CORE::core_set_command( "toggle_favorite_icon", m_url );
     }
     else{
 
+#ifdef _DEBUG
+        std::cout << "toggle_icon off\n";
+#endif
+
+        if( m_status & STATUS_UPDATE ) m_save_info = true;
+        m_status &= ~STATUS_UPDATE;
+
         // お気に入りのアイコン表示を戻す。スレタブのアイコンの方はArticleViewが戻す
-        if( m_status & STATUS_UPDATE ){
-            m_status &= ~STATUS_UPDATE;
-            CORE::core_set_command( "toggle_favorite_icon", m_url );
-        }
+        CORE::core_set_command( "toggle_favorite_icon", m_url );
     }
 }
 
@@ -1166,6 +1373,8 @@ void ArticleBase::show_updateicon( const bool update )
 //
 // キャッシュ削除
 //
+// cache_only == true の時はキャッシュだけ削除してスレ情報は消さない
+//
 void ArticleBase::delete_cache( const bool cache_only )
 {
 #ifdef _DEBUG
@@ -1212,18 +1421,19 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_abone_chain = false;
         m_read_info = false;
         m_save_info = false;
-        m_enable_load = false;
         m_bookmarked_thread = false;
     
-        // info
+        // info 削除
         if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
 
-        // 拡張info
+        // 拡張info 削除
         if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
 
+        // お気に入りから削除
+        CORE::core_set_command( "remove_favorite", m_url );
     }
 
-    // キャッシュ
+    // キャッシュ削除
     std::string path_dat = CACHE::path_dat( m_url );
     if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( path_dat.c_str() );
 
@@ -1273,7 +1483,7 @@ void ArticleBase::read_info()
 {
     if( m_read_info ) return; // 一度読んだら2度読みしない
     if( empty() ) return;
-    if( ! m_cached ) return;  // キャッシュがないなら読まない
+    if( ! is_cached() ) return;  // キャッシュがないなら読まない
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::read_info :  url = " << m_url << std::endl;
@@ -1338,7 +1548,7 @@ void ArticleBase::read_info()
                 m_write_time.tv_usec = atoi( ( *(it_tmp++) ).c_str() );
             }
 
-            m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
+            if( m_write_time.tv_sec ) m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
         }
 
         // write name
@@ -1363,7 +1573,6 @@ void ArticleBase::read_info()
         m_status = STATUS_UNKNOWN;
         GET_INFOVALUE( str_tmp, "status = " );
         if( ! str_tmp.empty() ) m_status = atoi( str_tmp.c_str() );
-        m_status &= ~STATUS_UPDATE; // 更新可能状態解除
 
         // あぼーん ID
         GET_INFOVALUE( str_tmp, "aboneid = " );
@@ -1528,15 +1737,15 @@ void ArticleBase::read_info()
 //
 // infoファイル書き込み
 //
-// キャッシュがある( m_cached = true )　かつ
+// キャッシュがある( is_cached() == true )　かつ
 // m_save_info = true の時に保存。save_info()を呼ぶ前にm_save_infoをセットすること。
 //
 // キャッシュがあって、force = true の時は強制書き込み
 //
-void ArticleBase::save_info( bool force )
+void ArticleBase::save_info( const bool force )
 {
     if( empty() ) return;
-    if( ! m_cached ) return;
+    if( ! is_cached() ) return;
     if( ! force && ! m_save_info ) return;
     m_save_info = false;
 
@@ -1546,6 +1755,7 @@ void ArticleBase::save_info( bool force )
     std::cout << "ArticleBase::save_info force = " << force << std::endl;
     std::cout << "path_article_info = " << m_path_article_info << std::endl;
     std::cout << "path_article_ext_info = " << m_path_article_ext_info << std::endl;
+    std::cout << "subject = " << m_subject << std::endl;
 #endif
 
     // 書き込み時間
@@ -1622,7 +1832,7 @@ void ArticleBase::save_info( bool force )
 void ArticleBase::save_navi2ch_info()
 {
     if( empty() ) return;
-    if( ! m_cached ) return;
+    if( ! is_cached() ) return;
     if( m_path_article_info.empty() ) return;
 
     std::string name = "nil";
@@ -1643,14 +1853,30 @@ void ArticleBase::save_navi2ch_info()
 
         std::list< std::string > lists = MISC::get_elisp_lists( str_info );
         std::list< std::string >::iterator it = lists.begin();
-        ++it;
-        name = *( it++ );
-        ++it;
-        hide = *( it++ );
-        important = *( it++ );
-        unfilter = *( it++ );
-        mail = *( it++ );
-        kako = *( it++ );        
+
+        do{
+            ++it;
+            if( it == lists.end() ) break;
+            name = *( it++ );
+
+            if( it == lists.end() ) break;
+            ++it;
+            if( it == lists.end() ) break;
+            hide = *( it++ );
+
+            if( it == lists.end() ) break;
+            important = *( it++ );
+
+            if( it == lists.end() ) break;
+            unfilter = *( it++ );
+
+            if( it == lists.end() ) break;
+            mail = *( it++ );
+
+            if( it == lists.end() ) break;
+            kako = *( it++ );
+
+        } while(0);
     }
 
     std::ostringstream sstr;
