@@ -35,6 +35,7 @@ namespace DBTREE
         JDLIB::ConstPtr< NodeTreeBase > m_nodetree;
 
         std::string m_url;           // dat ファイルのURL
+        std::string m_datbase;       // ベースアドレス
         std::string m_id;            // ID ( .datなどの拡張子付き  (例) 1234567.dat )
         std::string m_key;           // ID から拡張子を取った物
         std::string m_date_modified; // サーバのデータが更新された時間
@@ -59,7 +60,7 @@ namespace DBTREE
         struct timeval m_access_time;  // ユーザが最後にロードした時間
         struct timeval m_check_update_time;  // 最終更新チェック時間
         struct timeval m_write_time;   // 最終書き込み時間
-        std::string m_write_time_date; // 書き込み月日( string型 )
+        std::string m_write_time_date; // 最終書き込み月日( string型 )
         std::string m_write_name;      // 書き込み時の名前
         std::string m_write_mail;      // 書き込み時のメアド
         bool m_write_fixname;          // 書き込み時名前固定
@@ -92,8 +93,10 @@ namespace DBTREE
         // true ならunlock_impl()がコールバックされたときに情報保存
         bool m_save_info;
 
-        // キャッシュがあって、かつ新着の読み込みが可能
-        bool m_enable_load;
+        // 前スレのアドレス
+        // スレが未取得で、この変数がemptyで無いとき download_dat()を呼び出すと
+        // ロード終了時に次スレ移行チェックと前スレの情報のコピーをする
+        std::string m_url_pre_article;
 
       protected:
         void set_key( const std::string& key ){ m_key = key; }
@@ -128,7 +131,7 @@ namespace DBTREE
         const int get_number_seen() const{  return m_number_seen; }
         const int get_number_max() const { return m_number_max; }
 
-        void set_number_max( int number ){ if( number > 0 ) m_number_max = number; }
+        void set_number_max( const int number ){ if( number > 0 ) m_number_max = number; }
 
         // スレ速度
         const int get_speed();
@@ -220,15 +223,19 @@ namespace DBTREE
         // 最終書き込み時間
         const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
         const std::string& get_write_date() const { return m_write_time_date; } // string型
-        const time_t get_write_pass(); // 経過時間(秒)
 
-        // 書き込みしたレス番号
-        const int get_num_posted();  // 書き込み数
+        // 書き込み数
+        const int get_num_posted();
+
+        // 自分の書き込みか
         const bool is_posted( const int number );
 
         // 自分の書き込みにレスしたか
         const bool is_refer_posted( const int number );
 
+        // 書き込み履歴のリセット
+        void clear_post_history();
+
         // スレ立て時刻
         const time_t& get_since_time() const { return m_since_time; };
         const std::string& get_since_date() const { return m_since_date; }
@@ -236,6 +243,7 @@ namespace DBTREE
         // 更新時間
         time_t get_time_modified();
         const std::string& get_date_modified() { return m_date_modified; }
+        void set_date_modified( const std::string& date ){ m_date_modified = date; }
 
         // スレが立ってからの経過時間( 時間 )
         const int get_hour();
@@ -253,9 +261,9 @@ namespace DBTREE
         void reset_status();
         
         void set_subject( const std::string& subject );
-        void set_number( int number );
-        void set_number_load( int number_load );
-        void set_number_seen( int number_seen );
+        void set_number( const int number );
+        void set_number_load( const int number_load );
+        void set_number_seen( const int number_seen );
         void update_writetime();
 
         // キャッシュ削除
@@ -272,7 +280,7 @@ namespace DBTREE
         const bool is_cache_read() const { return ( m_nodetree ); }
 
         // キャッシュがあって、かつ新着の読み込みが可能
-        const bool enable_load() const { return m_enable_load; }
+        const bool enable_load();
 
         // キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
         const bool is_finished();
@@ -297,9 +305,9 @@ namespace DBTREE
 
         // あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
         void reset_abone( std::list< std::string >& ids, std::list< std::string >& names
-                          ,std::list< std::string >& words, std::list< std::string >& regexs
-                          ,std::vector< char >& vec_abone_res
-                          ,bool transparent, bool chain );
+                          ,std::list< std::string >& words,  std::list< std::string >& regexs
+                          ,const std::vector< char >& vec_abone_res
+                          ,const bool transparent, const bool chain );
 
         // あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
         void add_abone_id( const std::string& id );
@@ -310,7 +318,7 @@ namespace DBTREE
         void set_abone_chain( bool set ); // 連鎖
 
         // 「スレ」のブックマーク
-        void set_bookmarked_thread( bool bookmarked );
+        void set_bookmarked_thread( const bool bookmarked );
         const bool is_bookmarked_thread() const { return m_bookmarked_thread; }
 
         // 「レス」のブックマーク
@@ -323,15 +331,25 @@ namespace DBTREE
 
         // 情報ファイル書き込み
         // キャッシュがあって、force = true の時は強制書き込み
-        void save_info( bool force );
+        void save_info( const bool force );
 
         // スレッドのロード開始
         const bool is_loading();
         void stop_load();
+
+        // スレッドのロード開始
+        // DAT落ちの場合はロードしないので、強制的にリロードしたいときは reset_status() で
+        // ステータスをリセットしてからロードする
+        // check_update : true の時はHEADによる更新チェックをおこなう
         void download_dat( const bool check_update );
 
-        // 更新アイコン表示
-        void show_updateicon( const bool update );
+        // 前スレのアドレスを指定
+        // 前スレのアドレスをセットしてからdownload_dat()を呼び出すと
+        // ロード終了時( slot_load_finished() )に次スレ移行チェックをする
+        void set_url_pre_article( const std::string& url_pre_article );
+
+        // url_src で示されるスレの情報をコピー
+        void copy_article_info( const std::string& url_src );
 
       private:
 
@@ -345,6 +363,10 @@ namespace DBTREE
         void slot_load_finished();
         virtual void unlock_impl();
 
+        // 更新アイコン表示
+        // update == true の時に表示。falseなら戻す
+        void show_updateicon( const bool update );
+
         // navi2ch互換情報ファイル書き込み
         void save_navi2ch_info();
     };
