@@ -43,6 +43,7 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_name( name )
     , m_samba_sec( 0 )
     , m_live_sec( 0 )
+    , m_last_access_time( 0 )
     , m_number_max_res( 0 )
     , m_rawdata( 0 )
     , m_read_info( 0 )
@@ -123,17 +124,17 @@ void BoardBase::update_name( const std::string& name )
 }
 
 
-// user agent
+// ユーザエージェント
 const std::string& BoardBase::get_agent()
 {
     return CONFIG::get_agent_for_data();
 }
 
 
-// プロキシ
+// 読み込み用プロキシ
 const std::string BoardBase::get_proxy_host()
 {
-    int mode = get_mode_local_proxy();
+    const int mode = get_mode_local_proxy();
 
     if( mode == DBTREE::PROXY_GLOBAL ){
 
@@ -146,7 +147,7 @@ const std::string BoardBase::get_proxy_host()
 
 const int BoardBase::get_proxy_port()
 {
-    int mode = get_mode_local_proxy();
+    const int mode = get_mode_local_proxy();
 
     if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_port_for_data();
     else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_port();
@@ -154,12 +155,26 @@ const int BoardBase::get_proxy_port()
     return 0;
 }
 
+const std::string BoardBase::get_proxy_basicauth()
+{
+    const int mode = get_mode_local_proxy();
+
+    if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_basicauth_for_data();
+    else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_basicauth();
+
+    return std::string();
+}
+
+
 // 書き込み用プロキシ
 const std::string BoardBase::get_proxy_host_w()
 {
-    int mode = get_mode_local_proxy_w();
+    const int mode = get_mode_local_proxy_w();
 
-    if( mode == DBTREE::PROXY_GLOBAL ) return get_proxy_host();
+    if( mode == DBTREE::PROXY_GLOBAL ){
+
+        if( CONFIG::get_use_proxy_for_data() ) return CONFIG::get_proxy_for_data();
+    }
     else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_w();
 
     return std::string();
@@ -167,15 +182,26 @@ const std::string BoardBase::get_proxy_host_w()
 
 const int BoardBase::get_proxy_port_w()
 {
-    int mode = get_mode_local_proxy_w();
+    const int mode = get_mode_local_proxy_w();
 
-    if( mode == DBTREE::PROXY_GLOBAL ) return get_proxy_port();
+    if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_port_for_data();
     else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_port_w();
 
     return 0;
 }
 
 
+const std::string BoardBase::get_proxy_basicauth_w()
+{
+    const int mode = get_mode_local_proxy_w();
+
+    if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_basicauth_for_data();
+    else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_basicauth_w();
+
+    return std::string();
+}
+
+
 // ローカルルール
 const std::string BoardBase::localrule()
 {
@@ -229,6 +255,25 @@ void BoardBase::clear()
 }
 
 
+//
+// m_url_update_views に登録されている view に update_board コマンドを送る
+//
+void BoardBase::send_update_board()
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::send_update_board\n";
+#endif
+
+    std::list< std::string >::iterator it = m_url_update_views.begin();
+    for( ; it != m_url_update_views.end(); ++it ){
+#ifdef _DEBUG
+        std::cout << "update : " << *it << std::endl;
+#endif 
+        CORE::core_set_command( "update_board", *it );
+    }
+    m_url_update_views.clear();
+}
+
 
 //
 // 新しくArticleBaseクラスを追加してそのポインタを返す
@@ -283,10 +328,26 @@ time_t BoardBase::get_write_leftsec()
     if( ! m_samba_sec ) return 0;
     if( ! get_write_pass() ) return 0;
 
+    // ログイン中は書き込み規制無し
+    if( SESSION::login2ch() ) return 0;
+
     return MAX( 0, m_samba_sec + mrg - get_write_pass() );
 }
 
 
+//
+// 全書き込み履歴クリア
+//
+void BoardBase::clear_all_post_history()
+{
+    // キャッシュにあるレスをデータベースに登録
+    append_all_article_in_cache();
+    if( m_list_article.size() == 0 ) return;
+
+    std::list< ArticleBase* >::iterator it;
+    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ) ( *it )->clear_post_history();
+}
+
 
 //
 // 板情報の取得
@@ -351,7 +412,7 @@ void BoardBase::update_url( const std::string& root, const std::string& path_boa
 //
 // 戻り値 : "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15
 //
-const std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_to )
+const std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str )
 {
     if( empty() ) return std::string();
 
@@ -365,12 +426,12 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     num_from = num_to = 0;
 
     // dat 型
-    std::string datpath = MISC::replace_str( url_datpath(), "?", "\\?" );
-    std::string query_dat = "^ *(http://.+" + datpath  + ")([1234567890]+" + get_ext() + ") *$";
+    const std::string datpath = MISC::replace_str( url_datpath(), "?", "\\?" );
+    const std::string query_dat = "^ *(http://.+" + datpath  + ")([1234567890]+" + get_ext() + ") *$";
 
     // read.cgi型
-    std::string cgipath = MISC::replace_str( url_readcgipath(), "?", "\\?" );
-    std::string query_cgi = "^ *(http://.+" + cgipath + ")([1234567890]+)/?r?(l50)?([1234567890]+)?(-)?([1234567890]+)?.*$";
+    const std::string cgipath = MISC::replace_str( url_readcgipath(), "?", "\\?" );
+    const std::string query_cgi = "^ *(http://.+" + cgipath + ")([1234567890]+)/?r?(l50)?([1234567890]+)?(-)?([1234567890]+)?.*$";
 
 #ifdef _DEBUG
     std::cout << "query_dat = " << query_dat << std::endl;
@@ -405,6 +466,7 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
         else if( num_to != 0 ) num_from = 1;
 
         num_to = MAX( num_from, num_to );
+        num_str = MISC::get_filename( url );
     }
 
     // どちらでもない(スレのURLでない)場合
@@ -431,7 +493,7 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
 #ifdef _DEBUG
             std::cout << "moved -> " << url_tmp << std::endl;
 #endif
-            return url_dat( url_tmp, num_from, num_to );
+            return url_dat( url_tmp, num_from, num_to, num_str );
         }
 
 #ifdef _DEBUG
@@ -442,7 +504,8 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
 
 #ifdef _DEBUG
     std::cout << "BoardBase::url_dat result : " << url << " ->\n";
-    std::cout << "datbase = " << url_datbase() << " id = " << id << " from " << num_from << " to " << num_to << std::endl;
+    std::cout << "datbase = " << url_datbase() << " id = " << id << " from " << num_from << " to " << num_to
+              << " num = " << num_str << std::endl;
 #endif
 
     // もしurl(スレッドのURL)が移転前の旧URLのものだったら対応するarticlebaseクラスに旧ホスト名を教えてあげる
@@ -715,7 +778,8 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
 
     // urlをdat型に変換してからID取得
     int num_from, num_to;
-    std::string urldat = url_dat( url, num_from, num_to );
+    std::string num_str;
+    const std::string urldat = url_dat( url, num_from, num_to, num_str );
 
     // 板がDBに登録されてないので NULL クラスを返す
     if( urldat.empty() ){
@@ -752,34 +816,43 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
 //
 // subject.txt ダウンロード
 //
-void BoardBase::download_subject()
+// url_update_view : CORE::core_set_command( "update_board" ) を送信するビューのアドレス
+//
+void BoardBase::download_subject( const std::string& url_update_view )
 {
 #ifdef _DEBUG
-    std::cout << "BoardBase::download_subject " << url_subject() << std::endl;
+    std::cout << "BoardBase::download_subject " << url_subject() << std::endl
+              << "url_update_view = " << url_update_view << std::endl
+              << "empty = " << empty() << std::endl
+              << "loading = " << is_loading() << std::endl
+              << "views = " << m_url_update_views.size() << std::endl;
 #endif
 
+    // ダウンロード中に他のビューから再びダウンロード依頼が来たら
+    // ダウンロード終了時にまとめてビューにupdateコマンドを送る
+    m_url_update_views.push_back( url_update_view );
+    if( m_url_update_views.size() >= 2 ) return;
+
     if( empty() ) return;
     if( is_loading() ) return;
 
     clear();
     m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
     m_read_url_boardbase = false;
-    m_load_rule_setting = false;
+    m_is_online = SESSION::is_online();
 
     // オフライン
-    if( ! SESSION::is_online() ){
+    if( ! m_is_online  ){
 
         set_str_code( "" );
 
-        // ディスパッチャ経由でreceive_finish()を呼ぶ
+        // ディスパッチャ経由で receive_finish() を呼び出す
         finish();
         return;
     }
 
     // オンライン
 
-    m_load_rule_setting = true;
-
     // subject.txtのキャッシュが無かったら modified をリセット
     std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
     if( CACHE::file_exists( path_subject ) != CACHE::EXIST_FILE ) set_date_modified( std::string() );
@@ -787,7 +860,7 @@ void BoardBase::download_subject()
     JDLIB::LOADERDATA data;    
     create_loaderdata( data );
     if( ! start_load( data ) ){
-        CORE::core_set_command( "update_board", url_subject() );
+        send_update_board();
         clear();
     }
 }
@@ -803,6 +876,7 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
     data.agent = get_agent();
     data.host_proxy = get_proxy_host();
     data.port_proxy = get_proxy_port();
+    data.basicauth_proxy = get_proxy_basicauth();
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout();
     data.basicauth = get_basicauth();
@@ -826,7 +900,7 @@ void BoardBase::receive_data( const char* data, size_t size )
 void BoardBase::receive_finish()
 {
     // 別スレッドでローカルルールとSETTING.TXT のダウンロード開始
-    if( m_load_rule_setting ) download_rule_setting();
+    if( m_is_online ) download_rule_setting();
 
     m_list_subject.clear();
 
@@ -847,7 +921,7 @@ void BoardBase::receive_finish()
 #endif
         m_rawdata[ m_lng_rawdata ] = '\0';
         set_date_modified( std::string() );
-        CORE::core_set_command( "update_board", url_subject() );
+        send_update_board();
 
         if( get_code() == HTTP_OK && std::string( m_rawdata ).find( "window.location.href" ) != std::string::npos ){
 
@@ -858,17 +932,31 @@ void BoardBase::receive_finish()
             std::string query = ".*window.location.href=\"([^\"]*)\".*";
             if( regex.exec( query, m_rawdata ) ){
 
-                std::string new_url = regex.str( 1 );
-                std::string msg = "「" + get_name() + "」は\n\n" + new_url + " に移転しました。\n\nデータベースを更新しますか？";
+                const std::string new_url = regex.str( 1 );
+                int ret = Gtk::RESPONSE_YES;
 
-                SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-                mdiag.set_default_response( Gtk::RESPONSE_YES );
-                if( mdiag.run() == Gtk::RESPONSE_YES ){
+                if( CONFIG::get_show_movediag() ){
 
-                    DBTREE::move_board( url_boardbase(), new_url );
+                    const std::string msg = "「" + get_name() + "」は\n\n" + new_url + " に移転しました。\n\nデータベースを更新しますか？";
 
-                    // 再読み込み
-                    CORE::core_set_command( "open_board", url_subject() );
+                    SKELETON::MsgCheckDiag mdiag( NULL,
+                                                  msg,
+                                                  "今後表示しない(常に更新)(_D)",
+                                                  Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+
+                    mdiag.set_title( "更新確認" );
+                    ret = mdiag.run();
+                    if( ret == Gtk::RESPONSE_YES && mdiag.get_chkbutton().get_active() ) CONFIG::set_show_movediag( false );
+                }
+
+                if( ret == Gtk::RESPONSE_YES ){
+
+                    if( DBTREE::move_board( url_boardbase(), new_url ) ){
+
+                        // 再読み込み
+                        const std::string str_tab = "false";
+                        CORE::core_set_command( "open_board", url_subject(), str_tab );
+                    }
                 }
             }
         }
@@ -889,14 +977,19 @@ void BoardBase::receive_finish()
 
         m_lng_rawdata = 0;
 
-        // リダイレクトの場合は移転確認
+        //
+        // リダイレクト(302)の場合は移転確認
+        //
+        // ちなみにdatの読み込みでリダイレクト(302)が返ってきたときは、移転かdat落ちか判断出来ないので注意
+        // NodeTree2ch::receive_finish()も参照せよ
+        //
         if( get_code() == HTTP_REDIRECT ){
 
             set_date_modified( std::string() );
 
             if( start_checkking_if_board_moved() ) return;
 
-            CORE::core_set_command( "update_board", url_subject() );
+            send_update_board();
             clear();
             return;
         }
@@ -905,10 +998,10 @@ void BoardBase::receive_finish()
         read_from_cache = true;
     }
 
-    // ローダがエラーを返した or not modified or offline ならキャッシュからデータをロード
+    // ローダがエラーを返した 又は not modified 又はオフラインならキャッシュからデータをロード
     if( get_code() == HTTP_ERR
         || get_code() == HTTP_NOT_MODIFIED
-        || ! SESSION::is_online() ) read_from_cache = true;
+        || ! m_is_online ) read_from_cache = true;
 
     // キャッシュから読み込み
     if( read_from_cache ){
@@ -930,11 +1023,11 @@ void BoardBase::receive_finish()
         set_date_modified( std::string() );
 
         // 移転した可能性があるので url_boardbase をロードして解析
-        if( SESSION::is_online() && get_code() == HTTP_OK ){
+        if( m_is_online && get_code() == HTTP_OK ){
             if( start_checkking_if_board_moved() ) return;
         }
 
-        CORE::core_set_command( "update_board", url_subject() );
+        send_update_board();
         clear();
         return;
     }
@@ -947,15 +1040,17 @@ void BoardBase::receive_finish()
 
     //////////////////////////////
     // データベース更新
-    // subject.txtを解析して現行スレだけリスト(m_list_subject)に加える
+    // subject.txtを解析して現行スレだけsubjectリスト(m_list_subject)に加える
+
+    std::list< ArticleBase* >::iterator it;
 
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
 
     // 一度全てのarticleをdat落ち状態にして subject.txt に
     // 含まれているものだけ parse_subject()の中で通常状態にする
-    std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+    // オフラインの場合は状態を変えない
+    if( m_is_online ) for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
 
         int status = ( *it )->get_status();
         status &= ~STATUS_NORMAL;
@@ -973,7 +1068,7 @@ void BoardBase::receive_finish()
         std::cout << "list_subject was updated\n";
 #endif
 
-        // DAT落ちなどでsubject.txtに無いスレもリストに加える
+        // DAT落ちなどでsubject.txtに無いスレもsubjectリストに加える
         // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
         // 取得する必要がある
         if( CONFIG::get_show_oldarticle() ){
@@ -991,7 +1086,7 @@ void BoardBase::receive_finish()
 #endif                
                     ( *it )->read_info();
 
-                    // read_info()で状態が変わる時があるのでDAT落ちにしてからリスト(m_list_subject)に加える
+                    // ↑のread_info()で状態が変わる時があるのでDAT落ちに戻してからsubjectリスト(m_list_subject)に加える
                     int status = ( *it )->get_status();
 
                     if( status & STATUS_NORMAL ){
@@ -1006,8 +1101,20 @@ void BoardBase::receive_finish()
             }
         }
 
+        // オンライン、かつcodeが200か304なら最終アクセス時刻を更新
+        if( m_is_online && ( get_code() == HTTP_OK || get_code() == HTTP_NOT_MODIFIED ) ){
+
+            m_last_access_time = time( NULL );
+
+#ifdef _DEBUG
+            std::cout << "access time " << m_last_access_time << std::endl;
+#endif
+        }
+
         // オンライン、かつcodeが200なら情報を保存して subject.txt をキャッシュに保存
-        if( SESSION::is_online() && get_code() == HTTP_OK ){
+        if( m_is_online && get_code() == HTTP_OK ){
+
+            m_last_access_time = time( NULL );
 
 #ifdef _DEBUG
             std::cout << "save info and subject.txt\n";
@@ -1046,7 +1153,7 @@ void BoardBase::receive_finish()
     }
 
     // コアにデータベース更新を知らせる
-    CORE::core_set_command( "update_board", url_subject() );
+    send_update_board();
 
     delete libiconv;
     clear();
@@ -1056,7 +1163,11 @@ void BoardBase::receive_finish()
 //
 // url_boardbase をロードして移転したかどうか解析開始
 //
-// 移転した場合は window.location.href が含まれるテキストがサーバから送られてくる
+// 移転するとコード200で
+//
+// <script language="javascript">window.location.href="http://hoge.2ch.net/hoge/"</script>
+//
+// の様なHTML本文が送られて来るので移転先が分かる
 //
 bool BoardBase::start_checkking_if_board_moved()
 {
@@ -1070,6 +1181,7 @@ bool BoardBase::start_checkking_if_board_moved()
     if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
     else data.host_proxy = std::string();
     data.port_proxy = CONFIG::get_proxy_port_for_data();
+    data.basicauth_proxy = CONFIG::get_proxy_basicauth_for_data();
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout_img();
 
@@ -1233,15 +1345,19 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
 //
 void BoardBase::update_abone_thread()
 {
+#ifdef _DEBUG
+    std::cout << "BoardBase::update_abone_thread\n";
+#endif
+
     // Root::update_abone_all_board() であぼーん状態を全更新するときなど
     // まだスレ一覧にスレを表示していないBoardBaseクラスは更新しない
     if( ! m_list_subject_created ) return;
 
     // オフラインに切り替えてからキャッシュにあるsubject.txtを再読み込みする
-    bool online = SESSION::is_online();
+    const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    download_subject();
+    download_subject( url_subject() );
 
     SESSION::set_online( online );
 }
@@ -1321,7 +1437,7 @@ void BoardBase::reset_abone_thread( std::list< std::string >& threads,
     if( empty() ) return;
 
 #ifdef _DEBUG
-    std::cout << "BoardBase::reset_abone\n";
+    std::cout << "BoardBase::reset_abone_thread\n";
 #endif
 
     // 前後の空白と空白行を除く
@@ -1342,6 +1458,44 @@ void BoardBase::reset_abone_thread( std::list< std::string >& threads,
 }
 
 
+//
+// 読み込み用ローカルプロキシ設定
+//
+void BoardBase::set_local_proxy( const std::string& proxy )
+{
+    m_local_proxy = proxy;
+    m_local_proxy_basicauth = std::string();
+    if( proxy.empty() ) return;
+
+    // basic認証
+    JDLIB::Regex regex;
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    {
+        m_local_proxy_basicauth = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        m_local_proxy = regex.str( 2 );
+    }
+}
+
+
+//
+// 書き込み用ローカルプロキシ設定
+//
+void BoardBase::set_local_proxy_w( const std::string& proxy )
+{
+    m_local_proxy_w = proxy;
+    m_local_proxy_basicauth_w = std::string();
+    if( proxy.empty() ) return;
+
+    // basic認証
+    JDLIB::Regex regex;
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    {
+        m_local_proxy_basicauth_w = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        m_local_proxy_w = regex.str( 2 );
+    }
+}
+
+
 //
 // キャッシュ内のログ検索
 //
@@ -1481,11 +1635,13 @@ void BoardBase::read_board_info()
 
     // ローカルプロキシ
     m_mode_local_proxy = cf.get_option( "mode_local_proxy", 0 );
-    m_local_proxy = cf.get_option( "local_proxy", "" );
+    str_tmp = cf.get_option( "local_proxy", "" );
+    set_local_proxy( str_tmp );
     m_local_proxy_port = cf.get_option( "local_proxy_port", 8080 );
  
     m_mode_local_proxy_w = cf.get_option( "mode_local_proxy_w", 0 );
-    m_local_proxy_w = cf.get_option( "local_proxy_w", "" );
+    str_tmp = cf.get_option( "local_proxy_w", "" );
+    set_local_proxy_w( str_tmp );
     m_local_proxy_port_w = cf.get_option( "local_proxy_port_w", 8080 );
 
     // 書き込み時のデフォルトの名前とメアド
@@ -1498,8 +1654,11 @@ void BoardBase::read_board_info()
     // 実況の秒数
     m_live_sec = cf.get_option( "live_sec", 0 );
 
+    // 最終アクセス時刻
+    m_last_access_time = cf.get_option( "last_access_time", 0 );
+
 #ifdef _DEBUG
-    std::cout << "modified = " << date_modified() << std::endl;
+    std::cout << "modified = " << get_date_modified() << std::endl;
 #endif
 }
 
@@ -1541,6 +1700,15 @@ void BoardBase::save_jdboard_info()
     std::string str_abone_thread = MISC::listtostr( m_list_abone_thread );
     std::string str_abone_word_thread = MISC::listtostr( m_list_abone_word_thread );
     std::string str_abone_regex_thread = MISC::listtostr( m_list_abone_regex_thread );
+
+    // ローカルプロキシ
+    std::string local_proxy;
+    if( m_local_proxy_basicauth.empty() ) local_proxy = m_local_proxy;
+    else local_proxy = m_local_proxy_basicauth + "@" + m_local_proxy;
+
+    std::string local_proxy_w;
+    if( m_local_proxy_basicauth_w.empty() ) local_proxy_w = m_local_proxy_w;
+    else local_proxy_w = m_local_proxy_basicauth_w + "@" + m_local_proxy_w;
     
     std::ostringstream sstr;
     sstr << "modified = " << get_date_modified() << std::endl
@@ -1565,15 +1733,16 @@ void BoardBase::save_jdboard_info()
          << "abonehourthread = " << m_abone_hour_thread << std::endl
          << "mode_local_proxy = " << m_mode_local_proxy << std::endl
 
-         << "local_proxy = " << m_local_proxy << std::endl
+         << "local_proxy = " << local_proxy << std::endl
          << "local_proxy_port = " << m_local_proxy_port << std::endl
          << "mode_local_proxy_w = " << m_mode_local_proxy_w << std::endl
-         << "local_proxy_w = " << m_local_proxy_w << std::endl
+         << "local_proxy_w = " << local_proxy_w << std::endl
          << "local_proxy_port_w = " << m_local_proxy_port_w << std::endl
          << "write_name = " << m_write_name << std::endl
          << "write_mail = " << m_write_mail << std::endl
          << "samba_sec = " << m_samba_sec << std::endl
          << "live_sec = " << m_live_sec << std::endl
+         << "last_access_time = " << m_last_access_time << std::endl
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
@@ -1659,10 +1828,11 @@ void BoardBase::save_board_info()
 
         std::list< std::string > lists = MISC::get_elisp_lists( str_info );
         std::list< std::string >::iterator it = lists.begin();
-        bookmark = *( it++ );
-        hide = *( it++ );
-        ++it;
-        logo = *( it++ );
+        for( ; it != lists.end(); ++it ){
+            if( ( *it ).find( "bookmark" ) != std::string::npos ) bookmark = *it;
+            if( ( *it ).find( "hide" ) != std::string::npos ) hide = *it;
+            if( ( *it ).find( "logo" ) != std::string::npos ) logo = *it;
+        }
     }
 
     std::string str_out = "(" + bookmark + " " + hide + " " + time + " " + logo + ")";
