@@ -49,8 +49,8 @@ namespace DBTREE
         // setting.txtの modified 時刻
         std::string m_modified_setting;
 
-        // subjectダウンロード後にローカルルールとsetting.txtをロードする
-        bool m_load_rule_setting;
+        // subjectダウンロード指示時(BoardBase::download_subject)にオンラインだったか
+        bool m_is_online;
 
         // ビュワーでソートをする列番号、ソード順
         int m_view_sort_column;
@@ -104,14 +104,17 @@ namespace DBTREE
         int m_abone_number_thread; // レスの数
         int m_abone_hour_thread; // スレ立てからの経過時間
 
-        // ローカルプロキシ設定
+        // 読み込み用ローカルプロキシ設定
         int m_mode_local_proxy;
         std::string m_local_proxy;
         int m_local_proxy_port;
+        std::string m_local_proxy_basicauth; // basic 認証用の「ユーザID:パスワード」の組
 
+        // 書き込み用ローカルプロキシ設定
         int m_mode_local_proxy_w;
         std::string m_local_proxy_w;
         int m_local_proxy_port_w;
+        std::string m_local_proxy_basicauth_w; // basic 認証用の「ユーザID:パスワード」の組
 
         // 書き込み時のデフォルトの名前とメアド
         std::string m_write_name;      
@@ -132,6 +135,8 @@ namespace DBTREE
         // 最大レス数
         int m_number_max_res;
 
+        // ダウンロード用変数
+        std::list< std::string > m_url_update_views; // CORE::core_set_command( "update_board" ) を送信するビューのアドレス
         char* m_rawdata;
         int m_lng_rawdata;
 
@@ -226,12 +231,18 @@ namespace DBTREE
         void update_name( const std::string& name );
         const std::string& get_subjecttxt() const { return m_subjecttxt; }
 
-        // ダウンロード、書き込み時のエージェント名やプロキシ
+        // ダウンロード、書き込み時のエージェント名
         virtual const std::string& get_agent();
+
+        // ダウンロード時のプロキシ
         virtual const std::string get_proxy_host();
         virtual const int get_proxy_port();
+        virtual const std::string get_proxy_basicauth();
+
+        // 書き込み時のプロキシ
         virtual const std::string get_proxy_host_w();
         virtual const int get_proxy_port_w();
+        virtual const std::string get_proxy_basicauth_w();
 
         // ローカルルール
         virtual const std::string localrule();
@@ -320,7 +331,9 @@ namespace DBTREE
         ArticleBase* get_article_create( const std::string& id );
         ArticleBase* get_article_fromURL( const std::string& url );
 
-        void download_subject();
+        // subject.txt ダウンロード
+        // url_update_view : CORE::core_set_command( "update_board" ) を送信するビューのアドレス
+        void download_subject( const std::string& url_update_view );
 
         // 新スレ作成用のメッセージ変換
         virtual const std::string create_newarticle_message( const std::string& subject,
@@ -371,15 +384,19 @@ namespace DBTREE
         const int get_mode_local_proxy() const { return m_mode_local_proxy; }
         const std::string& get_local_proxy() const { return m_local_proxy; }
         const int get_local_proxy_port() const { return m_local_proxy_port; }
+        const std::string& get_local_proxy_basicauth() const { return m_local_proxy_basicauth; }
+
         void set_mode_local_proxy( int mode ){ m_mode_local_proxy = mode; }
-        void set_local_proxy( const std::string& proxy ){ m_local_proxy = proxy; }
+        void set_local_proxy( const std::string& proxy );
         void set_local_proxy_port( int port ){ m_local_proxy_port = port; }
 
         const int get_mode_local_proxy_w() const { return m_mode_local_proxy_w; }
         const std::string& get_local_proxy_w() const { return m_local_proxy_w; }
         const int get_local_proxy_port_w() const { return m_local_proxy_port_w; }
+        const std::string& get_local_proxy_basicauth_w() const { return m_local_proxy_basicauth_w; }
+
         void set_mode_local_proxy_w( int mode ){ m_mode_local_proxy_w = mode; }
-        void set_local_proxy_w( const std::string& proxy ){ m_local_proxy_w = proxy; }
+        void set_local_proxy_w( const std::string& proxy );
         void set_local_proxy_port_w( int port ){ m_local_proxy_port_w = port; }
 
         // 書き込み時のデフォルトの名前とメアド
@@ -397,6 +414,9 @@ namespace DBTREE
         void set_samba_sec( time_t sec ){ m_samba_sec = sec; }
         time_t get_write_leftsec(); // 書き込み可能までの残り秒
 
+        // 全書き込み履歴クリア
+        void clear_all_post_history();
+
         // 実況の秒数
         const time_t get_live_sec() const{ return m_live_sec; }
         void set_live_sec( time_t sec ){ m_live_sec = sec; }
@@ -421,6 +441,9 @@ namespace DBTREE
 
         void clear();
 
+        // m_url_update_views に登録されている view に update_board コマンドを送る
+        void send_update_board();
+
         // キャッシュのファイル名が正しいかどうか
         virtual bool is_valid( const std::string& filename ){ return false; }
 
