@@ -24,7 +24,10 @@ void DBTREE::create_root()
 
 void DBTREE::delete_root()
 {
-    if( instance_dbtree_root ) delete instance_dbtree_root;
+    if( instance_dbtree_root ){
+        instance_dbtree_root->terminate_load();
+        delete instance_dbtree_root;
+    }
 }
 
 
@@ -82,9 +85,9 @@ const std::string DBTREE::url_datbase( const std::string& url )
 
 
 // urlをdat型のurlに変換
-const std::string DBTREE::url_dat( const std::string& url, int& num_from, int& num_to )
+const std::string DBTREE::url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str )
 {
-    return DBTREE::get_board( url )->url_dat( url, num_from, num_to );
+    return DBTREE::get_board( url )->url_dat( url, num_from, num_to, num_str );
 }
 
 
@@ -92,7 +95,8 @@ const std::string DBTREE::url_dat( const std::string& url, int& num_from, int& n
 const std::string DBTREE::url_dat( const std::string& url )
 {
     int num_from, num_to;
-    return url_dat( url, num_from, num_to );
+    std::string num_str;
+    return url_dat( url, num_from, num_to, num_str );
 }
 
 
@@ -135,15 +139,26 @@ const std::string DBTREE::url_subbbscgi_new( const std::string& url )
 }
 
 
+// 簡易版
 const std::string  DBTREE::is_board_moved( const std::string& url )
 {
     return get_root()->is_board_moved( url );
 }
 
-
-void DBTREE::update_board( const std::string& url, const std::string& name, const std::string& basicauth, bool etc )
+const std::string  DBTREE::is_board_moved( const std::string& url,
+                                        std::string& old_root,
+                                        std::string& old_path_board,
+                                        std::string& new_root,
+                                        std::string& new_path_board
+    )
 {
-    get_root()->update_board( url, name, basicauth, etc );
+    return get_root()->is_board_moved( url, old_root, old_path_board, new_root, new_path_board );
+}
+
+
+const bool DBTREE::move_board( const std::string& url_old, const std::string& url_new )
+{
+    return get_root()->move_board( url_old, url_new, false );
 }
 
 
@@ -153,9 +168,37 @@ const XML::Document& DBTREE::get_xml_document()
 }
 
 
-const std::map< std::string, std::string >& DBTREE::get_xml_etc()
+const std::list< DBTREE::ETCBOARDINFO >& DBTREE::get_etcboards()
 {
-    return get_root()->xml_etc();
+    return get_root()->get_etcboards();
+}
+
+
+bool DBTREE::add_etc( const std::string& url, const std::string& name, const std::string& basicauth, const std::string& id )
+{
+    return get_root()->add_etc( url, name, basicauth, id );
+}
+
+
+bool DBTREE::move_etc( const std::string& url_old, const std::string& url_new,
+               const std::string& name_old, const std::string& name_new,
+               const std::string& basicauth, const std::string& boardid )
+{
+    return get_root()->move_etc( url_old, url_new,
+                                 name_old, name_new,
+                                 basicauth, boardid );
+}
+
+
+bool DBTREE::remove_etc( const std::string& url, const std::string& name )
+{
+    return get_root()->remove_etc( url, name );
+}
+
+
+void DBTREE::save_etc()
+{
+    get_root()->save_etc();
 }
 
 
@@ -176,10 +219,22 @@ const std::string DBTREE::board_id( const std::string& url )
     return DBTREE::get_board( url )->get_id();
 }
 
-// 更新時間
+// 更新時間( time_t )
 const time_t DBTREE::board_time_modified( const std::string& url )
 {
-    return DBTREE::get_board( url )->time_modified();
+    return DBTREE::get_board( url )->get_time_modified();
+}
+
+// 板の更新時間( 文字列 )
+const std::string DBTREE::board_date_modified( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_date_modified();
+}
+
+// 板の更新時間( 文字列 )をセット
+void DBTREE::board_set_date_modified( const std::string& url, const std::string& date )
+{
+    DBTREE::get_board( url )->set_date_modified( date );
 }
 
 const std::string& DBTREE::board_get_modified_localrule( const std::string& url )
@@ -239,15 +294,21 @@ void DBTREE::board_set_list_cookies_for_write( const std::string& url, const std
 }
 
 
-const std::string DBTREE::board_hana_for_write( const std::string& url )
+const std::string DBTREE::board_keyword_for_write( const std::string& url )
 {
-    return DBTREE::get_board( url )->hana_for_write();
+    return DBTREE::get_board( url )->get_keyword_for_write();
 }
 
 
-void DBTREE::board_set_hana_for_write( const std::string& url, const std::string& hana )
+void DBTREE::board_set_keyword_for_write( const std::string& url, const std::string& keyword )
 {
-    DBTREE::get_board( url )->set_hana_for_write( hana );
+    DBTREE::get_board( url )->set_keyword_for_write( keyword );
+}
+
+
+void DBTREE::board_analyze_keyword_for_write( const std::string& url, const std::string& html )
+{
+    DBTREE::get_board( url )->analyze_keyword_for_write( html );
 }
 
 
@@ -280,9 +341,14 @@ void DBTREE::board_save_info( const std::string& url )
 }
 
 
-void DBTREE::board_download_subject( const std::string& url )
+void DBTREE::board_download_subject( const std::string& url, const std::string& url_update_view )
 {
-    DBTREE::get_board( url )->download_subject();
+    DBTREE::get_board( url )->download_subject( url_update_view );
+}
+
+const bool DBTREE::board_is_loading( const std::string& url )
+{
+    return DBTREE::get_board( url )->is_loading();
 }
 
 void DBTREE::board_stop_load( const std::string& url )
@@ -370,6 +436,11 @@ const int DBTREE::board_get_local_proxy_port( const std::string& url )
     return DBTREE::get_board( url )->get_local_proxy_port();
 }
 
+const std::string& DBTREE::board_get_local_proxy_basicauth( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_local_proxy_basicauth();
+}
+
 void DBTREE::board_set_mode_local_proxy( const std::string& url, int mode )
 {
     DBTREE::get_board( url )->set_mode_local_proxy( mode );
@@ -395,6 +466,11 @@ const std::string& DBTREE::board_get_local_proxy_w( const std::string& url )
     return DBTREE::get_board( url )->get_local_proxy_w();
 }
 
+const std::string& DBTREE::board_get_local_proxy_basicauth_w( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_local_proxy_basicauth_w();
+}
+
 const int DBTREE::board_get_local_proxy_port_w( const std::string& url )
 {
     return DBTREE::get_board( url )->get_local_proxy_port_w();
@@ -436,6 +512,13 @@ void DBTREE::board_set_write_mail( const std::string& url, const std::string& ma
 }
 
 
+// 全スレの書き込み履歴のリセット
+void DBTREE::clear_all_post_history()
+{
+    DBTREE::get_root()->clear_all_post_history();
+}
+
+
 void DBTREE::read_boardinfo_all()
 {
     DBTREE::get_root()->read_boardinfo_all();
@@ -481,6 +564,14 @@ time_t DBTREE::board_write_leftsec( const std::string& url )
     return DBTREE::get_board( url )->get_write_leftsec();
 }
 
+
+// 板に属する全スレの書き込み履歴のリセット
+void DBTREE::board_clear_all_post_history( const std::string& url )
+{
+    DBTREE::get_board( url )->clear_all_post_history();
+}
+
+
 const int DBTREE::board_get_number_max_res( const std::string& url )
 {
     return DBTREE::get_board( url )->get_number_max_res();
@@ -491,6 +582,21 @@ void DBTREE::board_set_number_max_res( const std::string& url, const int number
     DBTREE::get_board( url )->set_number_max_res( number );
 }
 
+const time_t DBTREE::board_get_live_sec( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_live_sec();
+}
+
+void DBTREE::board_set_live_sec( const std::string& url, time_t sec )
+{
+    DBTREE::get_board( url )->set_live_sec( sec );
+}
+
+const time_t DBTREE::board_last_access_time( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_last_access_time();
+}
+
 
 /////////////////////////////////////////////////
 
@@ -619,7 +725,7 @@ const std::string DBTREE::article_since_date( const std::string& url )
 }
 
 
-// スレの更新時間( size_t )
+// スレの更新時間( time_t )
 const time_t DBTREE::article_time_modified( const std::string& url )
 {
     return DBTREE::get_article( url )->get_time_modified();
@@ -632,6 +738,11 @@ const std::string DBTREE::article_date_modified( const std::string& url )
     return DBTREE::get_article( url )->get_date_modified();
 }
 
+// スレの更新時間( 文字列 )をセット
+void DBTREE::article_set_date_modified( const std::string& url, const std::string& date )
+{
+    DBTREE::get_article( url )->set_date_modified( date );
+}
 
 const int  DBTREE::article_hour( const std::string& url )
 {
@@ -651,12 +762,6 @@ const std::string DBTREE::article_write_date( const std::string& url )
     return DBTREE::get_article( url )->get_write_date();
 }
 
-// 経過時間(秒
-const time_t DBTREE::article_write_pass( const std::string& url )
-{
-    return DBTREE::get_article( url )->get_write_pass();
-}
-
 
 const int DBTREE::article_status( const std::string& url )
 {
@@ -726,6 +831,15 @@ void DBTREE::article_download_dat( const std::string& url, const bool check_upda
     DBTREE::get_article( url )->download_dat( check_update );
 }
 
+void DBTREE::article_set_url_pre_article( const std::string& url, const std::string& url_pre_article )
+{
+    DBTREE::get_article( url )->set_url_pre_article( url_pre_article );
+}
+
+void DBTREE::article_copy_article_info( const std::string& url, const std::string& url_src )
+{
+    DBTREE::get_article( url )->copy_article_info( url_src );
+}
 
 void DBTREE::article_stop_load( const std::string& url )
 {
@@ -738,6 +852,14 @@ const int DBTREE::article_get_speed( const std::string& url )
     return DBTREE::get_article( url )->get_speed();
 }
 
+
+// 書き込み履歴のリセット
+void DBTREE::article_clear_post_history( const std::string& url )
+{
+    DBTREE::get_article( url )->clear_post_history();
+}
+
+
 const std::string& DBTREE::get_agent( const std::string& url )
 {
     return DBTREE::get_board( url )->get_agent();
@@ -753,6 +875,11 @@ const int DBTREE::get_proxy_port( const std::string& url )
     return DBTREE::get_board( url )->get_proxy_port();
 }
 
+const std::string DBTREE::get_proxy_basicauth( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_proxy_basicauth();
+}
+
 const std::string DBTREE::get_proxy_host_w( const std::string& url )
 {
     return DBTREE::get_board( url )->get_proxy_host_w();
@@ -763,6 +890,11 @@ const int DBTREE::get_proxy_port_w( const std::string& url )
     return DBTREE::get_board( url )->get_proxy_port_w();
 }
 
+const std::string DBTREE::get_proxy_basicauth_w( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_proxy_basicauth_w();
+}
+
 
 const std::string DBTREE::localrule( const std::string& url )
 {
@@ -969,11 +1101,17 @@ const bool DBTREE::is_bookmarked_thread( const std::string& url )
     return DBTREE::get_article( url )->is_bookmarked_thread();
 }
 
-void DBTREE::set_bookmarked_thread( const std::string& url, bool bookmarked )
+void DBTREE::set_bookmarked_thread( const std::string& url, const bool bookmarked )
 {
     DBTREE::get_article( url )->set_bookmarked_thread( bookmarked );
 }
 
+
+const int DBTREE::get_num_bookmark( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_num_bookmark();
+}
+
 const bool DBTREE::is_bookmarked( const std::string& url, int number )
 {
     return DBTREE::get_article( url )->is_bookmarked( number );
