@@ -105,7 +105,8 @@ namespace DBTREE
     const int board_code( const std::string& url );
     const std::string board_str_code( const std::string& url );
     void board_save_info( const std::string& url );
-    void board_download_subject( const std::string& url );
+    void board_download_subject( const std::string& url, const std::string& url_update_view );
+    const bool board_is_loading( const std::string& url );
     void board_stop_load( const std::string& url );
     std::list< DBTREE::ArticleBase* >& board_list_subject( const std::string& url );
     const int board_view_sort_column( const std::string& url );
@@ -121,12 +122,14 @@ namespace DBTREE
     const int board_get_mode_local_proxy( const std::string& url );
     const std::string& board_get_local_proxy( const std::string& url );
     const int board_get_local_proxy_port( const std::string& url );
+    const std::string& board_get_local_proxy_basicauth( const std::string& url );
     void board_set_mode_local_proxy( const std::string& url, int mode );
     void board_set_local_proxy( const std::string& url, const std::string& proxy );
     void board_set_local_proxy_port( const std::string& url, int port );
     const int board_get_mode_local_proxy_w( const std::string& url );
     const std::string& board_get_local_proxy_w( const std::string& url );
     const int board_get_local_proxy_port_w( const std::string& url );
+    const std::string& board_get_local_proxy_basicauth_w( const std::string& url );
     void board_set_mode_local_proxy_w( const std::string& url, int mode );
     void board_set_local_proxy_w( const std::string& url, const std::string& proxy );
     void board_set_local_proxy_port_w( const std::string& url, int port );
@@ -140,12 +143,18 @@ namespace DBTREE
     const time_t board_samba_sec( const std::string& url );
     void board_set_samba_sec( const std::string& url, time_t sec );
     time_t board_write_leftsec( const std::string& url );
+
+    // 各板に属する全スレの書き込み履歴のリセット
+    void board_clear_all_post_history( const std::string& url );
+
     const int board_get_number_max_res( const std::string& url );
     void board_set_number_max_res( const std::string& url, const int number );
     const time_t board_get_live_sec( const std::string& url );
     void board_set_live_sec( const std::string& url, time_t sec );
     const time_t board_last_access_time( const std::string& url );
 
+    // 全スレの書き込み履歴のリセット
+    void clear_all_post_history();
 
     // 全板の情報ファイル読み込み
     void read_boardinfo_all();
@@ -167,7 +176,6 @@ namespace DBTREE
     const int article_hour( const std::string& url );
     const time_t article_write_time( const std::string& url );
     const std::string article_write_date( const std::string& url );
-    const time_t article_write_pass( const std::string& url );
     const int article_status( const std::string& url );
     void article_reset_status( const std::string& url );
     const int article_code( const std::string& url );
@@ -181,9 +189,14 @@ namespace DBTREE
     const int article_number_new( const std::string& url );    
     const bool article_is_loading( const std::string& url );
     void article_download_dat( const std::string& url, const bool check_update );
+    void article_set_url_pre_article( const std::string& url, const std::string& url_pre_article );
+    void article_copy_article_info( const std::string& url, const std::string& url_src );
     void article_stop_load( const std::string& url );
     const int article_get_speed( const std::string& url );
 
+    // 書き込み履歴のリセット
+    void article_clear_post_history( const std::string& url );
+
     // キャッシュ削除
     // cache_only == true の時はキャッシュだけ削除してスレ情報は消さない
     void delete_article( const std::string& url, const bool cache_only );  
@@ -194,13 +207,18 @@ namespace DBTREE
     void article_update_writetime( const std::string& url );
     size_t article_lng_dat( const std::string& url );
 
-    // agent, プロキシ
-
+    // ユーザーエージェント
     const std::string& get_agent( const std::string& url );
-    const std::string get_proxy_host( const std::string& url ); // 読み込み用
+
+    // 読み込み用プロキシ
+    const std::string get_proxy_host( const std::string& url );
     const int get_proxy_port( const std::string& url );
-    const std::string get_proxy_host_w( const std::string& url ); // 書き込み用
+    const std::string get_proxy_basicauth( const std::string& url );
+
+    // 書き込み用プロキシ
+    const std::string get_proxy_host_w( const std::string& url ); 
     const int get_proxy_port_w( const std::string& url );
+    const std::string get_proxy_basicauth_w( const std::string& url );
 
     // ローカルルール
     const std::string localrule( const std::string& url );
@@ -317,7 +335,7 @@ namespace DBTREE
 
     // スレのブックマーク
     const bool is_bookmarked_thread( const std::string& url );
-    void set_bookmarked_thread( const std::string& url, bool bookmarked );
+    void set_bookmarked_thread( const std::string& url, const bool bookmarked );
 
     // レスのブックマーク
     const int get_num_bookmark( const std::string& url );
