@@ -54,14 +54,25 @@ enum
 };
 
 
+// レジュームのモード
+enum
+{
+    RESUME_NO = 0,  // レジューム無し
+    RESUME_MODE1,   // 通常のレジューム
+    RESUME_MODE2,   // サーバが range を無視してデータを送ってきた
+    RESUME_MODE3,   // サーバが range を無視してデータを送ってきた時にデータをスキップ中
+    RESUME_FAILED   // レジューム失敗
+};
+
+
 using namespace DBTREE;
 
 
-NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
+NodeTreeBase::NodeTreeBase( const std::string& url, const std::string& modified )
     : SKELETON::Loadable(),
       m_url( url ),
       m_lng_dat( 0 ),
-      m_resume ( 0 ),
+      m_resume ( RESUME_NO ),
       m_broken( 0 ),
       m_heap( SIZE_OF_HEAP ),
       m_buffer_lines( NULL ),
@@ -69,6 +80,7 @@ NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
       m_buffer_write( NULL ),
       m_check_update( false ),
       m_check_write( false ),
+      m_loading_newthread( false ),
       m_fout ( 0 )
 {
     set_date_modified( modified );
@@ -80,7 +92,7 @@ NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
 
     // ルートヘッダ作成。中は空。
     m_id_header = -1; // ルートヘッダIDが 0 になるように -1
-    NODE* tmpnode = create_header_node(); 
+    NODE* tmpnode = create_node_header(); 
     m_vec_header[ m_id_header ] = tmpnode;
 
     m_default_noname = DBTREE::default_noname( m_url );
@@ -94,7 +106,7 @@ NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
     m_num_id[ LINK_LOW ] = CONFIG::get_num_id_low();
 
 #ifdef _DEBUG
-    std::cout << "NodeTreeBase::NodeTreeBase url = " << m_url << " modified = " << date_modified()
+    std::cout << "NodeTreeBase::NodeTreeBase url = " << m_url << " modified = " << get_date_modified()
               << " noname = " << m_default_noname << std::endl;
 #endif
 }
@@ -660,7 +672,7 @@ const std::string NodeTreeBase::get_id_name( int number )
 //
 // 基本ノード作成
 //
-NODE* NodeTreeBase::createNode()
+NODE* NodeTreeBase::create_node()
 {
     NODE* tmpnode = ( NODE* ) m_heap.heap_alloc( sizeof( NODE ) );
 
@@ -675,12 +687,12 @@ NODE* NodeTreeBase::createNode()
 //
 // ヘッダノード作成
 //
-NODE* NodeTreeBase::create_header_node()
+NODE* NodeTreeBase::create_node_header()
 {
     ++m_id_header;
     m_node_previous = NULL;
 
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
     tmpnode->type =  NODE_HEADER;
 
     // ヘッダ情報
@@ -696,11 +708,11 @@ NODE* NodeTreeBase::create_header_node()
 //
 // 名前や本文などのブロックの先頭に置く
 //
-NODE* NodeTreeBase::create_block_node()
+NODE* NodeTreeBase::create_node_block()
 {
     m_node_previous = NULL;
 
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
     tmpnode->type =  NODE_BLOCK;
     
     return tmpnode;
@@ -710,11 +722,11 @@ NODE* NodeTreeBase::create_block_node()
 //
 // 発言回数(IDの出現数)ノード
 //
-NODE* NodeTreeBase::createIDNumNode()
+NODE* NodeTreeBase::create_node_idnum()
 {
     const char* dummy = " (10000)";
 
-    NODE* tmpnode = createTextNode( dummy, COLOR_CHAR );
+    NODE* tmpnode = create_node_text( dummy, COLOR_CHAR );
     tmpnode->type = NODE_IDNUM;
     tmpnode->text[ 0 ] = '\0'; // メモリだけ確保して文字を消す
     return tmpnode;
@@ -724,9 +736,9 @@ NODE* NodeTreeBase::createIDNumNode()
 //
 // 改行ノード作成
 //
-NODE* NodeTreeBase::createBrNode()
+NODE* NodeTreeBase::create_node_br()
 {
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
     tmpnode->type = NODE_BR;
     return tmpnode;
 }
@@ -735,9 +747,9 @@ NODE* NodeTreeBase::createBrNode()
 //
 // 水平線ノード作成
 //
-NODE* NodeTreeBase::createHrNode()
+NODE* NodeTreeBase::create_node_hr()
 {
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
     tmpnode->type = NODE_HR;
     return tmpnode;
 }
@@ -746,9 +758,9 @@ NODE* NodeTreeBase::createHrNode()
 //
 // スペースノード
 //
-NODE* NodeTreeBase::createSpNode( const int& type )
+NODE* NodeTreeBase::create_node_space( const int type )
 {
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
     tmpnode->type = type;
     return tmpnode;
 }
@@ -757,9 +769,9 @@ NODE* NodeTreeBase::createSpNode( const int& type )
 //
 // 水平タブノード
 //
-NODE* NodeTreeBase::createHTabNode()
+NODE* NodeTreeBase::create_node_htab()
 {
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
     tmpnode->type = NODE_HTAB;
     return tmpnode;
 }
@@ -770,9 +782,9 @@ NODE* NodeTreeBase::createHTabNode()
 //
 // bold : 太字か
 //
-NODE* NodeTreeBase::create_linknode( const char* text, int n, const char* link, int n_link, int color_text, bool bold )
+NODE* NodeTreeBase::create_node_link( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold )
 {
-    NODE* tmpnode = createTextNodeN( text, n, color_text, bold );
+    NODE* tmpnode = create_node_ntext( text, n, color_text, bold );
     if( tmpnode ){
         tmpnode->type = NODE_LINK;
         
@@ -790,10 +802,11 @@ NODE* NodeTreeBase::create_linknode( const char* text, int n, const char* link,
 //
 // アンカーノード作成
 //
-NODE* NodeTreeBase::create_ancnode( const char* text, int n, const char* link, int n_link, int color_text,  bool bold,
-                                    ANCINFO* ancinfo, int lng_ancinfo )
+NODE* NodeTreeBase::create_node_anc( const char* text, const int n, const char* link, const int n_link,
+                                     const int color_text,  const bool bold,
+                                     const ANCINFO* ancinfo, const int lng_ancinfo )
 {
-    NODE* tmpnode = create_linknode( text, n, link, n_link, color_text, bold );
+    NODE* tmpnode = create_node_link( text, n, link, n_link, color_text, bold );
     if( tmpnode ){
 
         tmpnode->linkinfo->ancinfo = ( ANCINFO* )m_heap.heap_alloc( sizeof( ANCINFO ) * ( lng_ancinfo + 1 ) );
@@ -804,12 +817,31 @@ NODE* NodeTreeBase::create_ancnode( const char* text, int n, const char* link, i
 }
 
 
+//
+// SSSPノード
+//
+NODE* NodeTreeBase::create_node_sssp( const char* link, const int n_link )
+{
+    NODE* tmpnode = create_node();
+    tmpnode->type = NODE_SSSP;
+
+    // リンク情報セット
+    tmpnode->linkinfo = ( LINKINFO* )m_heap.heap_alloc( sizeof( LINKINFO ) );
+    tmpnode->linkinfo->link = ( char* )m_heap.heap_alloc( n_link +4 );
+    memcpy( tmpnode->linkinfo->link, link, n_link );
+    tmpnode->linkinfo->link[ n_link ] = '\0';
+    tmpnode->linkinfo->image = true;
+
+    return tmpnode;
+}
+
+
 //
 // 画像ノード作成
 //
-NODE* NodeTreeBase::create_imgnode( const char* text, int n, const char* link, int n_link, int color_text,  bool bold )
+NODE* NodeTreeBase::create_node_img( const char* text, const int n, const char* link, const int n_link, const int color_text,  const bool bold )
 {
-    NODE* tmpnode = create_linknode( text, n, link, n_link, color_text, bold );
+    NODE* tmpnode = create_node_link( text, n, link, n_link, color_text, bold );
     if( tmpnode ) tmpnode->linkinfo->image = true;
     
     return tmpnode;
@@ -819,9 +851,9 @@ NODE* NodeTreeBase::create_imgnode( const char* text, int n, const char* link, i
 //
 // テキストノード作成
 //
-NODE* NodeTreeBase::createTextNode( const char* text, int color_text, bool bold )
+NODE* NodeTreeBase::create_node_text( const char* text, const int color_text, const bool bold )
 {
-    return createTextNodeN( text, strlen( text ), color_text, bold );
+    return create_node_ntext( text, strlen( text ), color_text, bold );
 }
 
 
@@ -829,11 +861,11 @@ NODE* NodeTreeBase::createTextNode( const char* text, int color_text, bool bold
 //
 // テキストノード作成( サイズ指定 )
 //
-NODE* NodeTreeBase::createTextNodeN( const char* text, int n, int color_text, bool bold )
+NODE* NodeTreeBase::create_node_ntext( const char* text, const int n, const int color_text, const bool bold )
 {
     if( n <= 0 ) return NULL;
     
-    NODE* tmpnode = createNode();
+    NODE* tmpnode = create_node();
 
     if( tmpnode ){
         tmpnode->type = NODE_TEXT;
@@ -862,12 +894,18 @@ NODE* NodeTreeBase::append_html( const std::string& html )
     std::cout << "NodeTreeBase::append_html url = " << m_url << " html = " << html << std::endl;
 #endif
 
-    NODE* header = create_header_node();
+    NODE* header = create_node_header();
     m_vec_header[ m_id_header ] = header;
 
     init_loading();
-    header->headinfo->block[ BLOCK_MES ] = create_block_node();
-    parse_html( html.c_str(), html.length(), COLOR_CHAR, false, false, true );
+    header->headinfo->block[ BLOCK_MES ] = create_node_block();
+
+    const bool digitlink = false;
+    const bool bold = false;
+    const bool ahref = true;
+    const bool sssp = false;
+    parse_html( html.c_str(), html.length(), COLOR_CHAR, digitlink, bold, ahref, sssp );
+
     clear();
 
     return header;
@@ -911,6 +949,8 @@ void NodeTreeBase::load_cache()
             size_t size = 0;
             m_check_update = false;
             m_check_write = false;
+            m_loading_newthread = false;
+            set_resume( false );
             init_loading();
             const size_t str_length = str.length();
             while( size < str_length ){
@@ -919,6 +959,12 @@ void NodeTreeBase::load_cache()
                 size += size_tmp;
             }
             receive_finish();
+
+            // レジューム時のチェック用に生データの先頭から RESUME_CHKSIZE バイト分をコピーしておく
+            // 詳しくは NodeTreeBase::receive_data() を参照せよ
+            const size_t length_chk = MIN( RESUME_CHKSIZE, str_length );
+            memcpy( m_resume_head, data, length_chk );
+            m_resume_head[ length_chk ] = '\0';
         }
     }
 }
@@ -934,10 +980,22 @@ void NodeTreeBase::init_loading()
     // 一時バッファ作成
     if( ! m_buffer_lines ) m_buffer_lines = ( char* ) malloc( MAXSISE_OF_LINES ); 
     if( ! m_parsed_text ) m_parsed_text = ( char* ) malloc( MAXSISE_OF_LINES );
-    if( m_check_write && ! m_buffer_write ) m_buffer_write = ( char* ) malloc( MAXSISE_OF_LINES ); 
 }
 
 
+//
+// レジュームのモードをセットする
+//
+void NodeTreeBase::set_resume( const bool resume )
+{
+#ifdef _DEBUG
+    std::cout << "NodeTreeBase::set_resume resume = " << resume << std::endl;
+#endif
+
+    if( resume ) m_resume = RESUME_MODE1;
+    else m_resume = RESUME_NO;
+}
+
 
 //
 // ロード開始
@@ -949,13 +1007,13 @@ void NodeTreeBase::download_dat( const bool check_update )
     if( is_loading() ) return;
 
     m_check_update = check_update;
-    m_check_write = false;
-    if( ! m_check_update ) m_check_write = MESSAGE::get_log_manager()->has_items( m_url, ! get_res_number() );
+    m_check_write = ! m_check_update;
+    m_loading_newthread = ( ! get_res_number() );
 
 #ifdef _DEBUG    
     std::cout << "NodeTreeBase::download_dat : " << m_url << " lng = " << m_lng_dat << std::endl
-              << "modified = " << date_modified() << " check_update = " << check_update
-              << " check_write = " << m_check_write << std::endl;
+              << "modified = " << get_date_modified() << " check_update = " << check_update
+              << " newthread = " << m_loading_newthread << std::endl;
 #endif
 
 
@@ -1029,30 +1087,47 @@ void NodeTreeBase::receive_data( const char* data, size_t size )
 
 #ifdef _DEBUG
         std::cout << "NodeTreeBase::receive_data : code = " << get_code() << std::endl;
+        std::cout << data << std::endl;
 #endif
-
         return;
     }
 
     if( m_check_update ) return;
 
-    // レジューム処理
-    // レジュームした時に先頭が '\n' かチェック
-    // '\n'で無ければあぼーんがあったということ
-    if( m_resume ){
+    // 通常のレジューム処理
+    if( m_resume == RESUME_MODE1 ){
+
+#ifdef _DEBUG
+        std::cout << "resume mode = " << m_resume << " -> ";
+#endif
+
+        // レジュームした時に先頭が '\n' ならレジューム成功
+        if( data[ 0 ] == '\n' ){
 
-        if( data[ 0 ] != '\n' ){
-            m_broken = true;
-            MISC::ERRMSG( "failed to resume" );
-        }
-        else{
             ++data;
             --size;
+            m_resume = RESUME_NO;
         }
 
-        m_resume = false;
+        // サーバが range を無視してデータを送ってきた
+        // 続きは add_raw_lines() を参照
+        else if( get_code() == HTTP_OK ) m_resume = RESUME_MODE2;
+
+        // あぼーんが起きた?
+        else{
+
+            m_broken = true;
+            MISC::ERRMSG( "failed to resume" );
+            m_resume = RESUME_NO;
+        }
+
+#ifdef _DEBUG
+        std::cout << m_resume << std::endl;
+#endif
     }
 
+    if( m_resume == RESUME_FAILED ) return;
+
     if( !size ) return;
     
     // バッファが '\n' で終わるように調整
@@ -1111,7 +1186,7 @@ void NodeTreeBase::receive_finish()
         if( !get_ext_err().empty() ) set_date_modified( std::string() );
 
         // 書き込みチェック終了
-        if( m_check_write
+        if( m_check_write && MESSAGE::get_log_manager()->size()
             && ( get_code() == HTTP_OK
                  || get_code() == HTTP_PARTIAL_CONTENT
                  || get_code() == HTTP_NOT_MODIFIED
@@ -1122,13 +1197,16 @@ void NodeTreeBase::receive_finish()
 #ifdef _DEBUG
     std::cout << "NodeTreeBase::receive_finish lng = " << m_lng_dat
               << " code = " << get_code() << " " << get_str_code()
-              << " modified = " << date_modified() << std::endl;
+              << " modified = " << get_date_modified() << std::endl;
 #endif    
     
     // 親 article クラスにシグナルを打ってツリー構造が変わったことを教える
     m_sig_finished.emit();
 
     clear();
+    m_check_update = false;
+    m_check_write = false;
+    m_loading_newthread = false;
 }
 
 
@@ -1149,10 +1227,59 @@ void NodeTreeBase::add_raw_lines( char* rawlines, size_t size )
     // 保存前にrawデータを加工
     rawlines = process_raw_lines( rawlines );
 
-    // キャッシュに保存
     size_t lng = strlen( rawlines );
-    if( !lng ) return;
+    if( ! lng ) return;
+
+    // サーバが range を無視してデータを送ってきたときのレジューム処理
+    if( m_resume == RESUME_MODE2 ){
+
+#ifdef _DEBUG
+        std::cout << "NodeTreeBase::add_raw_lines : resume\n";
+#endif
+
+        // 先頭からdatを送ってきたかチェック
+        const size_t length_chk = MIN( lng, MIN( RESUME_CHKSIZE, strlen( m_resume_head ) ) );
+        if( strncmp( rawlines, m_resume_head, length_chk ) == 0 ){
+            m_resume = RESUME_MODE3;
+            m_resume_lng = 0;
+        }
+
+        // 全く違うデータを送ってきた
+        else{
+
+            m_broken = true;
+            MISC::ERRMSG( "failed to resume" );
+            m_resume = RESUME_FAILED;
+            return;
+        }
+    }
+
+    // レジューム処理でデータをスキップ中
+    if( m_resume == RESUME_MODE3 ){
+
+#ifdef _DEBUG
+        std::cout << "NodeTreeBase::add_raw_lines : resume skip resume_lng = " << m_resume_lng
+                  << " lng = " << lng << " / lng_dat = " << m_lng_dat << std::endl;
+#endif
+
+        m_resume_lng += lng;
+        if( m_resume_lng <= m_lng_dat ) return;
+
+        // 越えた分をカットしてレジューム処理終了
+        rawlines += ( lng  - ( m_resume_lng - m_lng_dat ) );
+        lng = ( m_resume_lng - m_lng_dat );
+        m_resume = RESUME_NO;
+
+#ifdef _DEBUG
+        std::cout << "resume finished : lng = " << lng << std::endl;
+#endif
+    }
+
+    if( ! lng ) return;
+
     m_lng_dat += lng;
+
+    // キャッシュに保存
     if( m_fout ){
 #ifdef _DEBUG
         std::cout << "NodeTreeBase::add_raw_lines save " << lng << " bytes\n";
@@ -1205,7 +1332,7 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
     if( *pos == '\0' || *pos == '\n' ) return datline;
 
     int i;
-    NODE* header = create_header_node();
+    NODE* header = create_node_header();
     m_vec_header[ m_id_header ] =  header;
 
     // レス番号
@@ -1213,8 +1340,8 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
     snprintf( tmpstr, LNG_RES, "%d", header->id_header );
     snprintf( tmplink, LNG_RES,"%s%d", PROTO_RES, header->id_header );    
 
-    header->headinfo->block[ BLOCK_NUMBER ] = create_block_node();
-    create_linknode( tmpstr, strlen( tmpstr ) , tmplink, strlen( tmplink ), COLOR_CHAR_LINK, true );
+    header->headinfo->block[ BLOCK_NUMBER ] = create_node_block();
+    create_node_link( tmpstr, strlen( tmpstr ) , tmplink, strlen( tmplink ), COLOR_CHAR_LINK, true );
 
     const char* section[ SECTION_NUM ];
     int section_lng[ SECTION_NUM ];
@@ -1240,14 +1367,14 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
 #endif
 
         m_broken = true;
-        header->headinfo->block[ BLOCK_NAME ] = create_block_node();
+        header->headinfo->block[ BLOCK_NAME ] = create_node_block();
 
-        createTextNode( " 壊れています", COLOR_CHAR );
+        create_node_text( " 壊れています", COLOR_CHAR );
 
-        header->headinfo->block[ BLOCK_MES ] = create_block_node();
+        header->headinfo->block[ BLOCK_MES ] = create_node_block();
         const char str_broken[] = "ここ";
-        create_linknode( str_broken, strlen( str_broken ) , PROTO_BROKEN, strlen( PROTO_BROKEN ), COLOR_CHAR_LINK, false );
-        createTextNode( "をクリックしてスレを再取得して下さい。", COLOR_CHAR );
+        create_node_link( str_broken, strlen( str_broken ) , PROTO_BROKEN, strlen( PROTO_BROKEN ), COLOR_CHAR_LINK, false );
+        create_node_text( "をクリックしてスレを再取得して下さい。", COLOR_CHAR );
         
         return pos;
     }
@@ -1255,17 +1382,22 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
     // 名前
     int color_name = COLOR_CHAR_NAME;
     if( ! section_lng[ 1 ] ) color_name = COLOR_CHAR_NAME_NOMAIL;
-    parseName( header, section[ 0 ], section_lng[ 0 ], color_name );
+    parse_name( header, section[ 0 ], section_lng[ 0 ], color_name );
     
     // メール
-    parseMail( header, section[ 1 ], section_lng[ 1 ] );
+    parse_mail( header, section[ 1 ], section_lng[ 1 ] );
 
     // 日付とID
     parse_date_id( header, section[ 2 ], section_lng[ 2 ] );
 
     // 本文
-    header->headinfo->block[ BLOCK_MES ] = create_block_node();
-    parse_html( section[ 3 ], section_lng[ 3 ], COLOR_CHAR );
+    header->headinfo->block[ BLOCK_MES ] = create_node_block();
+
+    const bool digitlink = false;
+    const bool bold = false;
+    const bool ahref = false;
+    const bool sssp = true;
+    parse_html( section[ 3 ], section_lng[ 3 ], COLOR_CHAR, digitlink, bold, ahref, sssp );
 
     // サブジェクト
     if( header->id_header == 1 ){
@@ -1277,7 +1409,9 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
     }
 
     // 自分の書き込みかチェック
-    if( m_check_write ){
+    if( m_check_write && MESSAGE::get_log_manager()->has_items( m_url, m_loading_newthread ) ){
+
+        if( ! m_buffer_write ) m_buffer_write = ( char* ) malloc( MAXSISE_OF_LINES ); 
 
         // 簡易チェック
         // 最初の lng_check 文字だけ見る
@@ -1308,27 +1442,30 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
 //
 // 名前
 //
-void NodeTreeBase::parseName( NODE* header, const char* str, int lng, int color_name )
+void NodeTreeBase::parse_name( NODE* header, const char* str, const int lng, const int color_name )
 {
     bool digitlink = true;
     const bool bold = true;
+    const bool ahref = false;
+    const bool sssp = false;
+
     const bool defaultname = ( strncmp( m_default_noname.data(), str, lng ) == 0 );
 
-    header->headinfo->block[ BLOCK_NAMELINK ] = create_block_node();
+    header->headinfo->block[ BLOCK_NAMELINK ] = create_node_block();
 
     // デフォルトの名前で無いときはリンクにする
-    if( defaultname ) createTextNode( "名前", COLOR_CHAR );
+    if( defaultname ) create_node_text( "名前", COLOR_CHAR );
     else{
         const char namestr[] = "名前";
-        create_linknode( namestr, strlen( namestr ) , PROTO_NAME, strlen( PROTO_NAME ), COLOR_CHAR, false );
+        create_node_link( namestr, strlen( namestr ) , PROTO_NAME, strlen( PROTO_NAME ), COLOR_CHAR, false );
     }
 
-    NODE* node = header->headinfo->block[ BLOCK_NAME ] = create_block_node();
+    NODE* node = header->headinfo->block[ BLOCK_NAME ] = create_node_block();
 
     // デフォルト名無しと同じときはアンカーを作らない
     if( defaultname ){
         digitlink = false;
-        parse_html( str, lng, color_name, digitlink, bold );
+        parse_html( str, lng, color_name, digitlink, bold, ahref, sssp );
     }
     else{
 
@@ -1348,7 +1485,7 @@ void NodeTreeBase::parseName( NODE* header, const char* str, int lng, int color_
             // </b>の前までパース
             if( i != pos ){
                 digitlink = true;
-                parse_html( str + pos, i - pos, color_name, digitlink, bold );
+                parse_html( str + pos, i - pos, color_name, digitlink, bold, ahref, sssp );
             }
             if( i >= lng ) break;
             pos = i + 4; // 4 = strlen( "</b>" );
@@ -1375,7 +1512,7 @@ void NodeTreeBase::parseName( NODE* header, const char* str, int lng, int color_
 
             // </b><b>の中をパース
             digitlink = false; // 数字が入ってもリンクしない
-            parse_html( str + pos, pos_end - pos, COLOR_CHAR_NAME_B, digitlink, bold );
+            parse_html( str + pos, pos_end - pos, COLOR_CHAR_NAME_B, digitlink, bold, ahref, sssp );
 
             pos = pos_end + 3; // 3 = strlen( "<b>" );
         }
@@ -1403,7 +1540,7 @@ void NodeTreeBase::parseName( NODE* header, const char* str, int lng, int color_
 //
 // メール
 //
-void NodeTreeBase::parseMail( NODE* header, const char* str, int lng )
+void NodeTreeBase::parse_mail( NODE* header, const char* str, const int lng )
 {
     // sage 以外の時は色を変える
     int color = COLOR_CHAR;
@@ -1411,19 +1548,24 @@ void NodeTreeBase::parseMail( NODE* header, const char* str, int lng )
     while( str[ i ] != 's' && i < lng ) ++i;
     if( str[ i ] != 's' || str[ i+1 ] != 'a' || str[ i+2 ] != 'g' || str[ i+3 ] != 'e' ) color = COLOR_CHAR_AGE;
 
-    header->headinfo->block[ BLOCK_MAIL ] = create_block_node();
-    createTextNode( "[", color );
-    parse_html( str, lng, color, true );
+    header->headinfo->block[ BLOCK_MAIL ] = create_node_block();
+    create_node_text( "[", color );
 
-    if( color == COLOR_CHAR ) createTextNode( "]", color );
-    else createTextNode( "]", color );
+    const bool digitlink = true;
+    const bool bold = false;
+    const bool ahref = false;
+    const bool sssp = false;
+    parse_html( str, lng, color, digitlink, bold, ahref, sssp );
+
+    if( color == COLOR_CHAR ) create_node_text( "]", color );
+    else create_node_text( "]", color );
 }
 
 
 //
 // 日付とID、及びBE、株、その他
 //
-void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
+void NodeTreeBase::parse_date_id( NODE* header, const char* str, const int lng )
 {
     int start = 0;
     int lng_text = 0;
@@ -1432,7 +1574,7 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
     int lng_id_tmp;
     char tmpid[ LNG_ID ];
 
-    header->headinfo->block[ BLOCK_DATE ] = create_block_node();
+    header->headinfo->block[ BLOCK_DATE ] = create_node_block();
 
     for(;;){
 
@@ -1451,7 +1593,7 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
             // フラッシュ
             if( lng_text ){
                 if( *( str + start + lng_text - 1 ) == ' ' ) --lng_text;
-                createTextNodeN( str + start, lng_text, COLOR_CHAR );
+                create_node_ntext( str + start, lng_text, COLOR_CHAR );
             }
 
             // id 取得
@@ -1464,12 +1606,12 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
             memcpy( tmplink + sizeof( PROTO_ID ) - 1, tmpid, lng_id_tmp + 1 );
             
             // リンク作成
-            header->headinfo->block[ BLOCK_ID_NAME ] = create_block_node();
-            create_linknode( "ID:", 3 , tmplink, strlen( tmplink ), COLOR_CHAR, false );
-            createTextNodeN( tmpid, lng_id_tmp, COLOR_CHAR);
+            header->headinfo->block[ BLOCK_ID_NAME ] = create_node_block();
+            create_node_link( "ID:", 3 , tmplink, strlen( tmplink ), COLOR_CHAR, false );
+            create_node_ntext( tmpid, lng_id_tmp, COLOR_CHAR);
 
             // 発言回数ノード作成
-            createIDNumNode();
+            create_node_idnum();
 
             // 次のブロックへ移動
             start = start_block + lng_block;
@@ -1482,7 +1624,7 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
             const int strlen_of_BE = 3; // = strlen( "BE:" );
 
             // フラッシュ
-            if( lng_text ) createTextNodeN( str + start, lng_text, COLOR_CHAR );
+            if( lng_text ) create_node_ntext( str + start, lng_text, COLOR_CHAR );
 
             // id 取得
             int lng_header = 0;
@@ -1497,8 +1639,8 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
             memcpy( tmplink + sizeof( PROTO_BE ) -1, tmpid, lng_id_tmp + 1 );
 
             // リンク作成
-            create_linknode( "?", 1, tmplink, strlen( tmplink ), COLOR_CHAR, false );
-            createTextNodeN( str + start_block + lng_header, lng_block - lng_header, COLOR_CHAR);
+            create_node_link( "?", 1, tmplink, strlen( tmplink ), COLOR_CHAR, false );
+            create_node_ntext( str + start_block + lng_header, lng_block - lng_header, COLOR_CHAR);
 
             // 次のブロックへ移動
             start = start_block + lng_block;
@@ -1511,7 +1653,7 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
                  && str[ start_block + 2 ] == ' ' ){
 
             // フラッシュ
-            if( lng_text ) createTextNodeN( str + start, lng_text, COLOR_CHAR );
+            if( lng_text ) create_node_ntext( str + start, lng_text, COLOR_CHAR );
 
             // </a>までブロックの長さを伸ばす
             while( start_block + lng_block < lng
@@ -1519,7 +1661,11 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
                           && str[ start_block + lng_block ] == '>' ) ) ++lng_block;
             ++lng_block;
 
-            parse_html( str + start_block, lng_block, COLOR_CHAR, false, false, true );
+            const bool digitlink = false;
+            const bool bold = false;
+            const bool ahref = true;
+            const bool sssp = false;
+            parse_html( str + start_block, lng_block, COLOR_CHAR, digitlink, bold, ahref, sssp );
 
             // 次のブロックへ移動
             start = start_block + lng_block;
@@ -1531,28 +1677,31 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
     }
 
     // フラッシュ
-    if( lng_text ) createTextNodeN( str + start, lng_text, COLOR_CHAR );
+    if( lng_text ) create_node_ntext( str + start, lng_text, COLOR_CHAR );
 }
 
 
 //
 // HTMLパーサ
 //
-// digitlink : true の時は先頭に数字が現れたらアンカーにする( parseName() などで使う )
+// digitlink : true の時は先頭に数字が現れたらアンカーにする( parse_name() などで使う )
 //             false なら数字の前に >> がついてるときだけアンカーにする
 //
-// bold : ボールド標示
+// bold : ボールド表示
 //
 // ahref : <a href=～></a> からリンクノードを作成する
 // (例) parse_html( "<a href=\"hoge.com\">hoge</a>", 27, COLOR_CHAR, false, false, true );
 //
+// enable_sssp : true の時はssspアイコンを有効にする( ssspは 1 レス 1 つだけアイコン表示)
+//
 // (パッチ)
 //
 // 行頭の空白は全て除くパッチ
 // Thanks to 「パッチ投稿スレ」の28氏
 // http://jd4linux.sourceforge.jp/cgi-bin/bbs/test/read.cgi/support/1151836078/28
 //
-void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool digitlink, bool bold, bool ahref )
+void NodeTreeBase::parse_html( const char* str, const int lng, const int color_text,
+                               bool digitlink, const bool bold, const bool ahref, bool enable_sssp )
 {
     const char* pos = str;
     const char* pos_end = str + lng;
@@ -1580,7 +1729,7 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                      ( *( pos + 1 ) == 'a' || *( pos + 1 ) == 'A' ) && *( pos + 2 ) == ' ' ){
 
                 // フラッシュ
-                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+                create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
 
                 while( pos < pos_end && *pos != '=' ) ++pos;
                 ++pos;
@@ -1615,7 +1764,7 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                 ++pos;
 
                 if( lng_link && lng_str ){
-                    create_linknode( pos_str_start, lng_str , pos_link_start, lng_link, COLOR_CHAR_LINK, false );
+                    create_node_link( pos_str_start, lng_str , pos_link_start, lng_link, COLOR_CHAR_LINK, false );
                 }
             }
 
@@ -1683,10 +1832,10 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                      && ( *( pos + 2 ) == 'r' || *( pos + 2 ) == 'R' ) ){
 
                 // フラッシュ
-                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+                create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
 
                 // 水平線ノード作成
-                createHrNode();
+                create_node_hr();
 
                 pos += 4;
             }
@@ -1695,7 +1844,7 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
             else {
 
                 // フラッシュ
-                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+                create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
                 
                 while( pos < pos_end && *pos != '>' ) ++pos;
                 ++pos;
@@ -1706,10 +1855,10 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
 
                 // フラッシュ
                 if( *( pos - 1 ) == ' ' ) --lng_text; // 改行前の空白を取り除く
-                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+                create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
 
                 // 改行ノード作成
-                createBrNode();
+                create_node_br();
 
                 // 改行直後と行頭の空白は全て除く
                 while( *pos != '>' ) ++pos; ++pos;
@@ -1737,7 +1886,7 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
         if( check_anchor( mode , pos, n_in, tmpstr + lng_str, tmplink + lng_link, LNG_LINK - lng_link, ancinfo + lng_anc ) ){
 
             // フラッシュしてからアンカーノードをつくる
-            createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+            create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
 
             memcpy( tmplink, PROTO_ANCHORE, strlen( PROTO_ANCHORE ) );
             lng_str += strlen( tmpstr ) - lng_str;
@@ -1756,7 +1905,7 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                 pos += n_in; 
             }
 
-            create_ancnode( tmpstr, lng_str, tmplink, lng_link, COLOR_CHAR_LINK, bold, ancinfo, lng_anc );
+            create_node_anc( tmpstr, lng_str, tmplink, lng_link, COLOR_CHAR_LINK, bold, ancinfo, lng_anc );
 
             // forのところで++されるので--しておく
             --pos;
@@ -1771,22 +1920,29 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
 
         ///////////////////////
         // リンク(http)のチェック
-        if( check_link( pos, (int)( pos_end - pos ), n_in, tmplink, LNG_LINK ) ){
+        const int linktype = check_link( pos, (int)( pos_end - pos ), n_in, tmplink, LNG_LINK );
+        if( linktype != MISC::SCHEME_NONE ){
 
             // フラッシュしてからリンクノードつくる
-            createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+            create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
 
             while( remove_imenu( tmplink ) );
 
             lng_link = strlen( tmplink );
 
+            // ssspアイコン
+            if( enable_sssp && linktype == MISC::SCHEME_SSSP ){
+                create_node_sssp( tmplink, lng_link );
+                enable_sssp = false;
+            }
+
             // 画像リンク
-            if( DBIMG::get_type_ext( tmplink, lng_link ) != DBIMG::T_UNKNOWN ){
-                create_imgnode( pos, n_in, tmplink , lng_link, COLOR_IMG_NOCACHE, bold );
+            else if( DBIMG::get_type_ext( tmplink, lng_link ) != DBIMG::T_UNKNOWN ){
+                create_node_img( pos, n_in, tmplink , lng_link, COLOR_IMG_NOCACHE, bold );
             }
 
             // 一般リンク
-            else create_linknode( pos, n_in, tmplink , lng_link, COLOR_CHAR_LINK, bold );
+            else create_node_link( pos, n_in, tmplink , lng_link, COLOR_CHAR_LINK, bold );
 
             pos += n_in;
 
@@ -1806,9 +1962,9 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
 
                 // 文字以外の空白ノードならフラッシュして空白ノード追加
                 if( ret_decode != NODE_TEXT ){
-                    createTextNodeN( m_parsed_text, lng_text, color_text, bold );
+                    create_node_ntext( m_parsed_text, lng_text, color_text, bold );
                     lng_text = 0;
-                    createSpNode( ret_decode );
+                    create_node_space( ret_decode );
                 }
                 else lng_text += n_out;
 
@@ -1825,8 +1981,8 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
         if( *pos == 0x09 ){
 
             // フラッシュしてからタブノードをつくる
-            createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
-            createHTabNode();
+            create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+            create_node_htab();
             continue;
         }
 
@@ -1844,19 +2000,26 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
         m_parsed_text[ lng_text++ ] = *pos;
     }
 
-    createTextNodeN( m_parsed_text, lng_text, color_text, bold );
+    create_node_ntext( m_parsed_text, lng_text, color_text, bold );
 }
 
 
 //
 // 書き込みログ比較用文字列作成
 //
+// m_buffer_write に作成した文字列をセットする
+//
 // max_lng_write > 0 のときは m_buffer_write の文字数が max_lng_write 以上になったら停止
 //
 void NodeTreeBase::parse_write( const char* str, const int lng, const int max_lng_write )
 {
     if( ! m_buffer_write ) return;
 
+#ifdef _DEBUG
+    std::cout << "NodeTreeBase::parse_write lng = " << lng << " max = " << max_lng_write << std::endl;
+#endif
+
+    bool head = true;
     const char* pos = str;
     const char* pos_end = str + lng;
 
@@ -1904,6 +2067,34 @@ void NodeTreeBase::parse_write( const char* str, const int lng, const int max_ln
             continue;
         }
 
+        // quot
+        else if( *pos == '&' && ( *( pos + 1 ) == 'q' && *( pos + 2 ) == 'u' && *( pos + 3 ) == 'o' && *( pos + 4 ) == 't' && *( pos + 5 ) == ';' ) ){
+
+            *(pos_write++) = '"';
+            pos += 5;
+
+            continue;
+        }
+
+        // 先頭のsssp
+        else if( head && *pos == 's' && ( *( pos + 1 ) == 's' && *( pos + 2 ) == 's' && *( pos + 3 ) == 'p' ) ){
+
+            // 次のタグ(改行)が来るまで進める
+            while( pos < pos_end && *pos != '>' ) ++pos;
+            
+            continue;
+        }
+
+        // 水平タブ
+        else if( *pos == '\t' ){
+
+            // 空白に置き換える
+            *(pos_write++) = ' ';
+
+            continue;
+        }
+
+        head = false;
         *(pos_write++) = *pos;
     }
 
@@ -2067,20 +2258,20 @@ bool NodeTreeBase::check_anchor( int mode, const char* str_in,
 // n_in : str_in から何バイト読み取ったか
 // str_link : リンクの文字列
 //
-// 戻り値 : リンクが現れれば true
+// 戻り値 : リンクのタイプ(例えばSCHEME_HTTPなど)
 //
 // 注意 : MISC::is_url_scheme() と MISC::is_url_char() の仕様に合わせる事
 //
-bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char* str_link, int lng_link )
+const int NodeTreeBase::check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link )
 {
-    // CONFIG::get_loose_url() == true の時はRFCで規定されていない文字も含める
-    const bool loose_url = CONFIG::get_loose_url();
-
     // http://, https://, ftp://, ttp(s)://, tp(s):// のチェック
     int delim_pos = 0;
-    int linktype = MISC::is_url_scheme( str_in, &delim_pos );
+    const int linktype = MISC::is_url_scheme( str_in, &delim_pos );
 
-    if( linktype == MISC::SCHEME_NONE ) return false;
+    if( linktype == MISC::SCHEME_NONE ) return MISC::SCHEME_NONE;
+
+    // CONFIG::get_loose_url() == true の時はRFCで規定されていない文字も含める
+    const bool loose_url = CONFIG::get_loose_url();
 
     // リンクの長さを取得
     n_in = delim_pos;
@@ -2102,6 +2293,13 @@ bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char*
                    && *( str_in + n_in + 3 ) == 'o'
                    && *( str_in + n_in + 4 ) == 't'
                    && *( str_in + n_in + 5 ) == ';'
+                 ) || (
+                   // nbsp;
+                   *( str_in + n_in + 1 ) == 'n'
+                   && *( str_in + n_in + 2 ) == 'b'
+                   && *( str_in + n_in + 3 ) == 's'
+                   && *( str_in + n_in + 4 ) == 'p'
+                   && *( str_in + n_in + 5 ) == ';'
                  ) || (
                    // lt;
                    *( str_in + n_in + 1 ) == 'l'
@@ -2131,7 +2329,7 @@ bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char*
         || *( str_in + n_in -1 ) == ']' ) --n_in;
 
     // URLとして短かすぎる場合は除外する( 最短ドメイン名の例 "1.cc" )
-    if( n_in - delim_pos < 4 ) return false;
+    if( n_in - delim_pos < 4 ) return MISC::SCHEME_NONE;
 
     int offset = 0;
     if( linktype == MISC::SCHEME_TTP || linktype == MISC::SCHEME_TP ){ // ttp://, tp:// の場合、リンクの先頭にhを補完
@@ -2145,7 +2343,7 @@ bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char*
         }
     }
 
-    if( n_in + offset > lng_link ) return false;
+    if( n_in + offset > lng_link ) return MISC::SCHEME_NONE;
 
     if( ! url_encode ){
         memcpy( str_link + offset, str_in, n_in );
@@ -2171,7 +2369,14 @@ bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char*
         *pos = '\0';
     }
 
-    return true;
+    // sssp -> http
+    if( linktype == MISC::SCHEME_SSSP ){
+        str_link[ 0 ] = 'h';
+        str_link[ 1 ] = 't';
+        str_link[ 2 ] = 't';
+    }        
+
+    return linktype;
 }
 
 
@@ -2825,3 +3030,33 @@ const bool NodeTreeBase::is_refer_posted( const int number )
 
     return m_vec_refer_posted[ number ];
 }
+
+
+// 書き込み履歴のリセット
+void NodeTreeBase::clear_post_history()
+{
+    m_vec_posted.clear();
+    m_vec_refer_posted.clear();
+}
+
+
+////////////////////////////////
+
+// ARTICLE::LayoutTree::append_html() で使用するダミークラス
+
+
+NodeTreeDummy::NodeTreeDummy( const std::string& url, const std::string& date_modified )
+    : NodeTreeBase( url, date_modified )
+{
+#ifdef _DEBUG    
+    std::cout << "NodeTreeDummy::NodeTreeDummy : " << get_url() << std::endl;
+#endif
+}
+
+
+NodeTreeDummy::~NodeTreeDummy()
+{
+#ifdef _DEBUG    
+    std::cout << "NodeTreeDummy::~NodeTreeDummy : " << get_url() << std::endl;
+#endif
+}
