@@ -22,7 +22,7 @@
 using namespace DBTREE;
 
 
-NodeTreeMachi::NodeTreeMachi( const std::string url, const std::string& date_modified )
+NodeTreeMachi::NodeTreeMachi( const std::string& url, const std::string& date_modified )
     : NodeTreeBase( url, date_modified )
     , m_regex( 0 )
     , m_iconv( 0 )
@@ -114,6 +114,7 @@ void NodeTreeMachi::create_loaderdata( JDLIB::LOADERDATA& data )
     data.agent = DBTREE::get_agent( get_url() );
     data.host_proxy = DBTREE::get_proxy_host( get_url() );
     data.port_proxy = DBTREE::get_proxy_port( get_url() );
+    data.basicauth_proxy = DBTREE::get_proxy_basicauth( get_url() );
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout();
 
