@@ -17,12 +17,14 @@
 #include "jdlib/loaderdata.h"
 
 #include "skeleton/editviewdialog.h"
+#include "skeleton/msgdiag.h"
 
-#include "global.h"
+#include "type.h"
 #include "command.h"
 #include "config/globalconf.h"
 #include "cache.h"
-#include "jdversion.h"
+#include "httpcode.h"
+#include "environment.h"
 
 #include <sstream>
 #include <cstring>
@@ -53,6 +55,7 @@ Root::Root()
     : SKELETON::Loadable()
     , m_rawdata ( 0 )
     , m_lng_rawdata( 0 )
+    , m_analyzing_board_xml( false )
     , m_board_null( 0 )
     , m_get_board( NULL )
 {
@@ -64,10 +67,10 @@ Root::Root()
     load_etc();
 
     // JDのサポートBBS登録
-    set_board( JDBBS, "JDサポートBBS" );
+    set_board( ENVIRONMENT::get_jdbbs(), "JDサポートBBS" );
 
     // 2chのスレの過去ログ
-    set_board( JD2CHLOG, "2chスレ過去ログ" );
+    set_board( ENVIRONMENT::get_jd2chlog(), "2chスレ過去ログ" );
 
     m_board_null = new DBTREE::BoardBase( "", "", "" );
 }
@@ -126,11 +129,20 @@ BoardBase* Root::get_board( const std::string& url, const int count )
     m_get_board_url = url;
     m_get_board = NULL;
 
-    // 先頭が http:// でなかったら足して再帰呼び出し
-    if( count < max_count && url.find( "http://" ) != 0 ){
-        BoardBase* board = get_board( "http://" + url , count + 1 );
-        m_get_board_url = url;
-        return board;
+    if( count == 0 ){
+
+        size_t pos = url.rfind( "http://" );
+
+        // ユーザープロフィールアドレス( http://be.2ch.net/test/p.php?u=d:http://〜 )の様に
+        // 先頭以外に http:// が入っている場合は失敗
+        if( pos != std::string::npos && pos != 0 ) return m_board_null;
+
+        // http:// が含まれていなかったら先頭に追加して再帰呼び出し
+        else if( pos == std::string::npos ){
+            BoardBase* board = get_board( "http://" + url , count + 1 );
+            m_get_board_url = url;
+            return board;
+        }
     }
 
     // サーチ
@@ -203,7 +215,7 @@ BoardBase* Root::get_board( const std::string& url, const int count )
     }
 
 #ifdef _DEBUG            
-    std::cout << "Root::get_board: not found\n";
+    std::cout << "Root::get_board: not found url = " << url << std::endl;;
 #endif
     
     // それでも見つからなかったらNULLクラスを返す
@@ -255,10 +267,11 @@ void Root::download_bbsmenu()
 
     JDLIB::LOADERDATA data;
     data.url = CONFIG::get_url_bbsmenu();
-    data.agent = CONFIG::get_agent_for2ch(); 
-    if( CONFIG::get_use_proxy_for2ch() ) data.host_proxy = CONFIG::get_proxy_for2ch();
+    data.agent = CONFIG::get_agent_for_data(); 
+    if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
     else data.host_proxy = std::string();
-    data.port_proxy = CONFIG::get_proxy_port_for2ch();
+    data.port_proxy = CONFIG::get_proxy_port_for_data();
+    data.basicauth_proxy = CONFIG::get_proxy_basicauth_for_data();
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout();
 
@@ -283,6 +296,18 @@ void Root::receive_data( const char* data, size_t size )
 // virtual
 void Root::receive_finish()
 {
+    if( get_code() != HTTP_OK ){
+
+        std::string msg = get_str_code() + "\n\n板一覧の読み込みに失敗しました。\n\nプロキシ設定や板一覧を取得するサーバのアドレスを確認して、ファイルメニューから板一覧の再読み込みをして下さい。\n板一覧取得サーバのアドレスはabout:configで確認出来ます。";
+        SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_ERROR );
+        mdiag.run();
+        MISC::ERRMSG( "bbsmenu load failed : " + get_str_code() );
+
+        CORE::core_set_command( "update_bbslist" );
+
+        return;
+    }
+
     // 文字コードを変換してXML作成
     JDLIB::Iconv* libiconv = new JDLIB::Iconv( "MS932", "UTF-8" );
     int byte_out;
@@ -366,7 +391,9 @@ void Root::bbsmenu2xml( const std::string& menu )
             if( CONFIG::use_link_as_board() ) element_name = "board";
             else if( ( regex.exec( "^http://.*/.*/$", url ) && is_2ch( url ) )
                      || is_machi( url )
-                     || is_JBBS( url ) ) element_name = "board";
+                     || is_JBBS( url )
+                     || is_vip2ch( url )
+                ) element_name = "board";
             else element_name = "link";
 
             XML::Dom* board = subdir->appendChild( XML::NODE_TYPE_ELEMENT, element_name );
@@ -395,6 +422,8 @@ void Root::analyze_board_xml()
 #endif
 
     m_move_info = std::string();
+    m_analyzing_board_xml = true;
+    m_analyzed_path_board.clear();
 
     XML::DomList boards = m_document.getElementsByTagName( "board" );
 
@@ -420,6 +449,9 @@ void Root::analyze_board_xml()
         //移転テーブル保存
         save_movetable();
     }
+
+    m_analyzing_board_xml = false;
+    m_analyzed_path_board.clear();
 }
 
 
@@ -464,6 +496,17 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
         }
     }
 
+    // vipサービス
+    else if( is_vip2ch( url ) ){
+
+        if( regex.exec( "(http://[^/]*)/([^/]*)/$" , url ) ){
+            root = regex.str( 1 );
+            path_board = "/" + regex.str( 2 );
+
+            type = TYPE_BOARD_2CH_COMPATI;
+        }
+    }
+
     // その他は互換型
     else{
 
@@ -500,7 +543,7 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
 
     // 移転チェック
     BoardBase* board = NULL;
-    int stat = is_moved( root, path_board, name, &board );
+    const int stat = is_moved( root, path_board, name, &board );
 
 #ifdef _SHOW_BOARD
     std::cout << "root = " << root << " path_board = " << path_board
@@ -511,18 +554,59 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
     if( stat == BOARD_NEW ){
 
         board = DBTREE::BoardFactory( type, root, path_board, name, basicauth );
-        if( board ) m_list_board.push_back( board );
-
+        if( board ){
+            m_list_board.push_back( board );
+            if( m_analyzing_board_xml ) m_analyzed_path_board.insert( path_board );
+        }
     }
 
     // 移転処理
     else if( stat == BOARD_MOVED ){
 
-        exec_move_board( board,
-                         board->get_root(),
-                         board->get_path_board(),
-                         root,
-                         path_board );
+        // XML解析中に、
+        // <board name="ニュース実況+" url="http://anchorage.2ch.net/liveplus/" />
+        // <board name="ニュース実況+" url="http://gimpo.2ch.net/liveplus/" />
+        // のように同じ板で異なるアドレスが現れた場合は、移転処理をせずにキャッシュが存在する方のアドレスを残す
+        if( m_analyzing_board_xml && m_analyzed_path_board.find( path_board ) != m_analyzed_path_board.end() ){
+
+            std::string tmp_msg = "Root::set_board : The XML file is broken !\n";
+            tmp_msg += url + " has already been registerd as " + board->url_boardbase();
+            MISC::ERRMSG( tmp_msg );
+
+            const std::string path1 = CACHE::path_board_root_fast( board->url_boardbase() );
+            const std::string path2 = CACHE::path_board_root_fast( url );
+
+#ifdef _DEBUG
+            std::cout << "path1 = " << path1 << std::endl
+                      << "path2 = " << path2 << std::endl;
+#endif
+            // キャッシュが存在する方を正しいアドレスとする
+            if( CACHE::file_exists( path1 ) == CACHE::EXIST_DIR ){
+#ifdef _DEBUG
+                std::cout << "path1 exists\n";
+#endif
+                // 既に登録済みなので何もしない
+            }
+            else if( CACHE::file_exists( path2 ) == CACHE::EXIST_DIR ){
+#ifdef _DEBUG
+                std::cout << "path2 exists\n";
+#endif
+                // url の方を登録する
+                board->update_url( root, path_board ); 
+            }
+        }
+
+        // 移転処理実行
+        else{
+
+            if( ! exec_move_board( board,
+                                   board->get_root(),
+                                   board->get_path_board(),
+                                   root,
+                                   path_board ) ) return false;
+
+            if( m_analyzing_board_xml ) m_analyzed_path_board.insert( path_board );
+        }
     }
 
     return true;
@@ -533,7 +617,7 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
 //
 // (明示的に)板移転
 //
-bool Root::move_board( const std::string& url_old, const std::string& url_new, const bool etc )
+const bool Root::move_board( const std::string& url_old, const std::string& url_new, const bool etc )
 {
     if( url_old == url_new ) return false;
 
@@ -553,11 +637,12 @@ bool Root::move_board( const std::string& url_old, const std::string& url_new, c
     int type = get_board_type( url_new, root, path_board, etc );
     if( type == TYPE_BOARD_UNKNOWN ) return false;
 
-    exec_move_board( board,
-                     board->get_root(),
-                     board->get_path_board(),
-                     root,
-                     path_board );
+    if( ! exec_move_board( board,
+                           board->get_root(),
+                           board->get_path_board(),
+                           root,
+                           path_board
+            ) ) return false;
 
     // キャッシュを移動した
     if( ! m_move_info.empty() ) save_movetable();
@@ -585,6 +670,16 @@ bool Root::exec_move_board( BoardBase* board,
     std::cout << old_root << old_path_board << " -> " << new_root <<  new_path_board << std::endl;
 #endif
 
+    if( old_root == new_root && old_path_board == new_path_board ){
+
+        std::string errmsg = "移転元のアドレスと移転先のアドレスが同じです\n\n"
+        + old_root + old_path_board + " → " + new_root +  new_path_board;
+
+        SKELETON::MsgDiag mdiag( NULL, errmsg, false, Gtk::MESSAGE_ERROR );
+        mdiag.run();
+        return false;
+    }
+
     const std::string old_url = board->url_boardbase();
     std::string old_path = CACHE::path_board_root( old_url );
 
@@ -654,6 +749,16 @@ void Root::push_movetable( const std::string old_root,
     std::cout << "Root::push_movetable : " << old_root << old_path_board << " -> " << new_root << new_path_board << std::endl;
 #endif            
 
+    if( old_root == new_root && old_path_board == new_path_board ){
+
+        std::string errmsg = "移転元のアドレスと移転先のアドレスが同じです (Root::push_movetable)\n\n"
+        + old_root + old_path_board + " → " + new_root +  new_path_board;
+
+        SKELETON::MsgDiag mdiag( NULL, errmsg, false, Gtk::MESSAGE_ERROR );
+        mdiag.run();
+        return;
+    }
+
     std::string str;
 
     // new_root, new_path_board, old_root, old_path が過去に登録済みなら
@@ -662,7 +767,8 @@ void Root::push_movetable( const std::string old_root,
     for( ; it_move != m_movetable.end(); ){
 
 #ifdef _DEBUG
-        std::cout << ( *it_move ).old_root << ( *it_move ).old_path_board << "/ -> " << ( *it_move ).new_root << std::endl;
+        std::cout << "size = " << m_movetable.size() << " "
+                  << ( *it_move ).old_root << ( *it_move ).old_path_board << "/ -> " << ( *it_move ).new_root << std::endl;
 #endif            
 
         if(
@@ -676,13 +782,23 @@ void Root::push_movetable( const std::string old_root,
 
             ){
 
-            str += "削除: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + ( *it_move ).new_root + "\n";
+            const std::string str_tmp = "削除: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + ( *it_move ).new_root + "\n";
+#ifdef _DEBUG
+            std::cout << str_tmp << std::endl;
+#endif
+            str += str_tmp;
 
             m_movetable.erase( it_move );
             it_move = m_movetable.begin();
             continue;
         }
+
+        // 移転先を最新にする
+        //
+        // (注意) old_root == new_root かつ old_path_board == new_path_board のとき
+        // erase した内容と push_back した内容が同じになるので無限ループに落ちる
         else if(
+
             ( *it_move ).new_root == old_root
             && ( *it_move ).new_path_board == old_path_board ){
 
@@ -690,8 +806,12 @@ void Root::push_movetable( const std::string old_root,
             movetable.new_root = new_root;
             movetable.new_path_board = new_path_board;
 
-            str += "更新: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + ( *it_move ).new_root
+            const std::string str_tmp = "更新: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + ( *it_move ).new_root
             + " => " + movetable.old_root + movetable.old_path_board + "/ -> " + movetable.new_root + "\n";
+#ifdef _DEBUG
+            std::cout << str_tmp << std::endl;
+#endif
+            str += str_tmp;
 
             m_movetable.erase( it_move );
             m_movetable.push_back( movetable );
@@ -1147,23 +1267,35 @@ const std::string Root::is_board_moved( const std::string& url,
         if( url.find( ( *it_move ).old_root ) == 0
             && url.find( ( *it_move ).old_path_board + "/" ) != std::string::npos ){
 
-            std::string new_url = ( *it_move ).new_root + ( *it_move ).new_path_board + "/";
+            const std::string new_url = ( *it_move ).new_root + ( *it_move ).new_path_board + "/";
 
             old_root = ( *it_move ).old_root;
             old_path_board = ( *it_move ).old_path_board;
             new_root = ( *it_move ).new_root;
             new_path_board = ( *it_move ).new_path_board;
 
+            const std::string old_root_bkup = old_root;
+            const std::string old_path_board_bkup = old_path_board;
+
 #ifdef _DEBUG            
-            std::cout << url << " is moved to " << new_url << std::endl;
+            std::cout << "count = " << count << " : " << url << " is moved to " << new_url << std::endl;
 #endif
 
             // 連鎖的に検索
             std::string ret_url = is_board_moved( new_url, old_root, old_path_board, new_root, new_path_board, count +1 ); 
 
             // old_root と old_path_board が書き換わっているので戻しておく
-            old_root = ( *it_move ).old_root;
-            old_path_board = ( *it_move ).old_path_board;
+            //
+            // (注意) もし再帰呼び出ししたis_board_moved() の中で m_movetable.erase を実行すると
+            // it_move は無効になるので、以前の様に
+            // old_root = ( *it_move ).old_root;
+            // old_path_board = ( *it_move ).old_path_board;
+            // と it_move を使ってold_rootなどに代入するとメモリを破壊してセグフォになる時がある
+            // (イテレータのメモリが残っていればセグフォにならないので完全に運まかせ)
+            // 次にJDを起動したときは再帰呼び出ししたis_board_moved() の中の save_movetable()で
+            // 移転テーブルは更新済みで落ちないのでタチが悪い
+            old_root = old_root_bkup;
+            old_path_board = old_path_board_bkup;
 
             return ret_url;
         }
@@ -1205,6 +1337,15 @@ std::list< std::string > Root::search_cache( const std::string& query, bool mode
 }
 
 
+// 全てのスレの書き込み履歴削除
+void Root::clear_all_post_history()
+{
+    std::list< BoardBase* >::iterator it;
+    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
+        ( *it )->clear_all_post_history();
+    }
+}
+
 
 //
 // 移転テーブル保存
@@ -1291,6 +1432,19 @@ bool Root::is_machi( const std::string& url )
 }
 
 
+//
+// vipサービスのURLか
+//
+bool Root::is_vip2ch( const std::string& url )
+{
+    std::string hostname = MISC::get_hostname( url );
+
+    if( hostname.find( ".vip2ch.com" ) != std::string::npos ) return true;
+
+    return false;
+}
+
+
 //
 // 配下の全boardbaseクラスのレスあぼーん状態を更新する
 //
