@@ -14,29 +14,47 @@ namespace ICON
 {
     enum
     {
-        JD16,
+        NONE = -1,
+
+        JD16 = 0,
         JD32,
         JD48,
+        JD96,
 
         BKMARK_UPDATE,
         BKMARK,
+        BKMARK_THREAD,
+
         UPDATE,
         NEWTHREAD,
+        NEWTHREAD_HOUR,
         CHECK,
         DOWN,
         WRITE,
+        POST,
+        POST_REFER,
         LOADING,
         LOADING_STOP,
 
         DIR,
         FAVORITE,
+
         BOARD,
         BOARD_UPDATE,
+        BOARD_UPDATED,
+
         THREAD,
         THREAD_UPDATE,
+        THREAD_UPDATED,
+        THREAD_OLD,
+
         IMAGE,
         LINK,
 
+#if GTKMMVER <= 240   // 2.4 以前は Gtk::Stock::MEDIA_PLAY が無い
+        PLAY,
+#endif
+
         TRANSPARENT,
 
         NUM_ICONS
