@@ -22,11 +22,16 @@ ImageAreaPopup::ImageAreaPopup( const std::string& url )
 #ifdef _DEBUG    
     std::cout << "ImageAreaPopup::ImageAreaPopup url = " << url << std::endl;
 #endif 
-
-    show_image();
 }
 
 
+ImageAreaPopup::~ImageAreaPopup()
+{
+#ifdef _DEBUG    
+    std::cout << "ImageAreaPopup::~ImageAreaPopup url = " << get_url() << std::endl;
+#endif 
+}
+
 
 //
 // 表示
@@ -37,14 +42,15 @@ void ImageAreaPopup::show_image()
     std::cout << "ImageAreaPopup::show_image url = " << get_url() << std::endl;
 #endif    
 
+    if( is_loading() ) return;
+    if( is_ready() ) return;
+
     if( ! get_img()->is_cached() ) return;
 
     set_errmsg( std::string() );
     int width_max = CONFIG::get_imgpopup_width();
     int height_max = CONFIG::get_imgpopup_height();
 
-    clear();
-
     // 縮小比率を計算
     double scale;
     int w_org = get_img()->get_width();
@@ -62,5 +68,5 @@ void ImageAreaPopup::show_image()
         set_height( h_org );
     }
 
-    set_image();
+    load_image();
 }
