@@ -16,6 +16,12 @@
 
 #include <list>
 
+
+namespace SKELETON
+{
+    class Admin;
+}
+
 namespace DBIMG
 {
     class Img;
@@ -45,13 +51,16 @@ namespace IMAGE
 
       protected:
 
+        // Viewが所属するAdminクラス
+        virtual SKELETON::Admin* get_admin();
+
         JDLIB::ConstPtr< DBIMG::Img >& get_img(){ return  m_img;}
 
         JDLIB::ConstPtr< ImageAreaBase >& get_imagearea(){ return  m_imagearea; }
         void set_imagearea( ImageAreaBase* imagearea );
         void remove_imagearea();
 
-        const bool loading() const{ return m_loading; }
+        const bool is_loading() const{ return m_loading; }
         void set_loading( bool loading ){ m_loading = loading; }
         Gtk::EventBox& get_event(){ return  m_event; }
 
@@ -62,16 +71,25 @@ namespace IMAGE
 
         const bool is_under_mouse() const { return m_under_mouse; }
 
-        // コマンド
-        virtual bool set_command( const std::string& command, const std::string& arg = std::string() );
-
+        //
         // SKELETON::View の関数のオーバロード
+        //
+
+        // 親ウィンドウを取得
+        virtual Gtk::Window* get_parent_win();
+
+        // コマンド
+        virtual const bool set_command( const std::string& command,
+                                        const std::string& arg1 = std::string(),
+                                        const std::string& arg2 = std::string()
+            );
+
         virtual void reload();
         virtual void stop();
         virtual void redraw_view();
         virtual void close_view();
         virtual void delete_view();
-        virtual void operate_view( const int& control );
+        virtual const bool operate_view( const int control );
         virtual void show_preference();
 
       protected:
