@@ -8,6 +8,8 @@
 
 #include "winmain.h"
 #include "cache.h"
+#include "environment.h"
+#include "iomonitor.h"
 
 #include "jdlib/miscmsg.h"
 #include "jdlib/miscutil.h"
@@ -18,6 +20,9 @@
 #include <sys/time.h>
 #include <errno.h>
 #include <cstring>
+#include <sstream>
+#include <iostream>
+#include <getopt.h>
 
 #ifdef USE_GNOMEUI
 #include <gnome.h>
@@ -35,64 +40,13 @@ struct XSMPDATA
 };
 #endif
 
-WinMain* Win_Main = NULL;
-
-//
-// ロック
-//
-// 下のいずれかの値が戻る
-//
-
 enum
 {
-    LOCK_OK = 0,  // ロックした
-    LOCK_ALIVE,   // 他のJDが起動している
-    LOCK_EXIST    // ロックファイルはあるがJDは起動していない
+    MAX_SAFE_ARGC = 4,   // 引数の数の制限値
+    MAX_SAFE_ARGV = 1024 // 各引数の文字列の制限値
 };
 
-int lock_jd()
-{
-    pid_t pid = getpid();
-    char str_pid[ 256 ];
-    std::string path = CACHE::path_lock();
-
-    if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ){
-
-        CACHE::load_rawdata( path, str_pid, 256 );
-        pid = atoi( str_pid );
-
-#ifdef _DEBUG
-        std::cout << "lock file exits pid = " << pid << std::endl;
-#endif
-
-        int killret = kill( pid, 0 );
-        if( killret == 0 ||  errno == EPERM ){
-
-#ifdef _DEBUG
-            std::cout << "other jd is alive\n";
-#endif
-            return LOCK_ALIVE;
-
-        }
-
-        return LOCK_EXIST;
-    }
-
-    snprintf( str_pid, 256, "%d", pid );
-    CACHE::save_rawdata( path, str_pid, strlen( str_pid ) );
-
-    return LOCK_OK;
-}
-
-
-// ロック解除
-void unlock_jd()
-{
-    std::string path = CACHE::path_lock();
-
-    if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
-}
-
+WinMain* Win_Main = NULL;
 
 
 // バックアップ復元
@@ -159,7 +113,6 @@ void sig_handler( int sig )
         std::cout << "sig_handler sig = " << sig << std::endl;
 #endif
         if( Win_Main ) Win_Main->shutdown();
-        unlock_jd();
     }
 
     exit(0);
@@ -182,7 +135,6 @@ static int save_yourself_gnome( GnomeClient *client,
 {
 
     if( Win_Main ) Win_Main->save_session();
-    unlock_jd();
 
     return TRUE;
 }
@@ -207,7 +159,6 @@ void xsmp_session_save_yourself( SmcConn smc_connect,
         std::cout << "session_save_yourself\n";
 #endif
         if( Win_Main ) Win_Main->save_session();
-        unlock_jd();
     }
 
     SmcSaveYourselfDone( smc_connect, TRUE ) ;
@@ -333,11 +284,106 @@ void xsmp_session_end( XSMPDATA* xsmpdata )
 
 #endif
 
-
 ////////////////////////////////////////////////////////////
 
+void usage( const int status )
+{
+    // -h, --help で表示するメッセージ
+    std::stringstream help_message;
+    help_message <<
+    "Usage: jd [option] [<url>]\n"
+    "\n"
+    "-h, --help\n"
+    "        Display this information\n"
+    //"-t <url>, --tab=<url>\n"
+    //"        URL open of BBS etc by Tab\n"
+    "-m, --multi\n"
+    "        Does not terminate even if it is a subprocess\n"
+    "-V, --version\n"
+    "        Display version of this program\n";
+
+    std::cout << help_message.str() << std::endl;
+
+    exit( status );
+}
+
+
 int main( int argc, char **argv )
 {
+    /*--- 引数処理 --------------------------------------------------*/
+
+    // 引数の数を制限
+    if( argc > MAX_SAFE_ARGC )
+    {
+        MISC::ERRMSG( "main(): Too many arguments." );
+        exit( EXIT_FAILURE );
+    }
+
+    // 各引数の文字数を制限
+    int i;
+    for( i = 0; i < argc; ++i )
+    {
+        if( strlen( argv[ i ] ) > MAX_SAFE_ARGV )
+        {
+            MISC::ERRMSG( "main(): Too many the strings in argument." );
+            exit( EXIT_FAILURE );
+        }
+    }
+
+    // "現在のタブ/新規タブ"など引数によって開き方を変えたい場合は、--tab=<url>
+    // など新しいオプションを追加する
+    // --help, --tab=<url>, --multi, --version
+    const struct option options[] =
+    {
+        { "help", 0, 0, 'h' },
+        //{ "tab", 1, 0, 't' },
+        { "multi", 0, 0, 'm' },
+        { "version", 0, 0, 'V' },
+        { 0, 0, 0, 0 }
+    };
+
+    char* url = NULL;
+    bool multi_mode = false;
+
+    // -h, -t <url>, -m, -V
+    int opt = 0;
+    while( ( opt = getopt_long( argc, argv, "ht:mV", options, NULL ) ) != -1 )
+    {
+        switch( opt )
+        {
+            case 'h':
+                usage( EXIT_SUCCESS );
+                break;
+
+            //case 't':
+                //url = optarg;
+                //break;
+
+            case 'm':
+                multi_mode = true;
+                break;
+
+            case 'V':
+                std::cout << "JD " << ENVIRONMENT::get_jdversion() << ", " << ENVIRONMENT::get_jdcopyright() << std::endl;
+                break;
+
+            default:
+                usage( EXIT_FAILURE );
+        }
+    }
+
+    if( ! url )
+    {
+        // 引数がURLのみの場合
+        if( argc > optind )
+        {
+            url = argv[ optind ];
+        }
+        // マルチモードでなく、URLを含まない引数だけの場合は終了
+        else if( optind > 1 && ! multi_mode ) return 0;
+    }
+    /*---------------------------------------------------------------*/
+
     // SIGINT、SIGQUITのハンドラ設定
     struct sigaction sigact;
     sigset_t blockset;
@@ -427,32 +473,41 @@ int main( int argc, char **argv )
         CACHE::mkdir_root();
     }
 
-    // ロック
-    int lock = lock_jd();
-    if( lock == LOCK_ALIVE ){
+    /*--- IOMonitor -------------------------------------------------*/
+    CORE::IOMonitor iomonitor;
 
-        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+    // FIFOの状態をチェックする
+    if( iomonitor.get_fifo_stat() == CORE::FIFO_OK )
+    {
+        // 引数にURLがある
+        if( url )
+        {
+            // FIFOに書き込む
+            iomonitor.send_command( url );
+
+            // マルチモードでなく、メインプロセスでもない場合は終了
+            if( ! multi_mode && ! iomonitor.is_main_process() ) return 0;
+        }
+        // マルチモードでなく、メインプロセスでもない場合は問い合わせる
+        else if( ! multi_mode && ! iomonitor.is_main_process() )
+        {
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            int ret = mdiag->run();
+            delete mdiag;
+            if( ret != Gtk::RESPONSE_YES ) return 0;
+        }
+    }
+    // FIFOに問題がある
+    else
+    {
+        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。起動しますか？",
                                                             false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret != Gtk::RESPONSE_YES ) return 0;
-
-        unlock_jd();
-        lock_jd();
-    }
-    else if( lock == LOCK_EXIST ){ 
-
-        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "前回起動時にJDが異常終了しました。\n\nロックファイルを削除して起動しますか？",
-                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-
-        mdiag->set_default_response( Gtk::RESPONSE_YES );
-        int ret = mdiag->run();
-        delete mdiag;
-        if( ret != Gtk::RESPONSE_YES ) return 0;
-
-        unlock_jd();
-        lock_jd();
+        if( ret != Gtk::RESPONSE_YES ) return 1;
     }
+    /*---------------------------------------------------------------*/
 
     // バックアップファイル復元
     restore_bkup();
@@ -472,8 +527,5 @@ int main( int argc, char **argv )
 
     JDLIB::deinit_ssl();
 
-    // ロック解除
-    unlock_jd();
-
     return 0;
 }
