@@ -21,10 +21,11 @@
 
 #include "config/globalconf.h"
 
+#include "control/controlutil.h"
+#include "control/controlid.h"
+
 #include "httpcode.h"
 #include "viewfactory.h"
-#include "controlutil.h"
-#include "controlid.h"
 #include "fontid.h"
 #include "cache.h"
 #include "session.h"
@@ -60,6 +61,8 @@ MessageViewBase::MessageViewBase( const std::string& url )
     : SKELETON::View( url ),
       m_post( 0 ),
       m_preview( 0 ),
+      m_entry_name( CORE::COMP_NAME ),
+      m_entry_mail( CORE::COMP_MAIL ),
       m_enable_focus( true ),
       m_counter( 0 )
 {
@@ -78,8 +81,6 @@ MessageViewBase::MessageViewBase( const std::string& url )
     m_lng_iconv = m_max_str * 3;
     if( ! m_lng_iconv ) m_lng_iconv = MAX_STR_ICONV;
 
-    m_str_iconv = ( char* ) malloc( m_lng_iconv + 1024 );
-
     if( SESSION::get_close_mes() ) unlock();
     else lock();
 }
@@ -111,9 +112,6 @@ MessageViewBase::~MessageViewBase()
     if( m_iconv ) delete m_iconv;
     m_iconv = NULL;
 
-    if( m_str_iconv ) free( m_str_iconv );
-    m_str_iconv = NULL;
-
     SESSION::set_close_mes( ! is_locked() );
 }
 
@@ -124,6 +122,15 @@ SKELETON::Admin* MessageViewBase::get_admin()
 }
 
 
+//
+// 親ウィンドウを取得
+//
+Gtk::Window* MessageViewBase::get_parent_win()
+{
+    return MESSAGE::get_admin()->get_win();
+}
+
+
 //
 // コピー用URL( readcgi型 )
 //
@@ -135,7 +142,6 @@ const std::string MessageViewBase::url_for_copy()
 }
 
 
-
 void MessageViewBase::clock_in()
 {
     if( m_preview ) m_preview->clock_in();
@@ -211,7 +217,7 @@ const bool MessageViewBase::is_loading()
 //
 // コマンド
 //
-bool MessageViewBase::set_command( const std::string& command, const std::string& arg )
+const bool MessageViewBase::set_command( const std::string& command, const std::string& arg1, const std::string& arg2 )
 {
     if( command == "empty" ) return get_message().empty();
 
@@ -237,25 +243,7 @@ bool MessageViewBase::set_command( const std::string& command, const std::string
     // メッセージを追加
     else if( command == "add_message" )
     {
-        std::string caution;
-
-        // 追加する文字列が制限値を超えていないかチェック
-        if( m_max_str && int( arg.length() ) > m_max_str ) caution.append( "文字数" );
-        if( m_max_line && MISC::count_str( arg, "\n" ) > m_max_line )
-        {
-            if( ! caution.empty() ) caution.append( "及び" );
-            caution.append( "改行数" );
-        }
-
-        if( ! caution.empty() )
-        {
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
-                                     caution.append( "がスレッドの制限値を超えています。\n\n追加しますか？" ),
-                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            if( mdiag.run() != Gtk::RESPONSE_YES ) return false;
-        }
-
-        m_text_message.insert_str( arg, true );
+        if( ! arg1.empty() ) m_text_message.insert_str( arg1, true );
     }
 
     // メッセージ保存
@@ -272,7 +260,7 @@ bool MessageViewBase::set_command( const std::string& command, const std::string
                 SESSION::set_dir_draft( MISC::get_dir( save_to ) );
 
                 if( CACHE::save_rawdata( save_to, get_message() ) != get_message().raw().length() ){
-                    SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                    SKELETON::MsgDiag mdiag( get_parent_win(),
                                              "保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
                     mdiag.run();
                 }
@@ -326,21 +314,22 @@ void MessageViewBase::pack_widget()
     m_tooltip.set_tip( m_check_fixname, "チェックすると名前欄を保存して固定にする" );
     m_tooltip.set_tip( m_check_fixmail, "チェックするとメール欄を保存して固定にする" );
 
-    // 名前
-    
+    // スレ別の名前
     if( DBTREE::write_fixname( get_url() ) ){
         m_check_fixname.set_active();
         m_entry_name.set_text( DBTREE::write_name( get_url() ) );
     }
+    // スレ別の名前が設定されていなかったら板別の名前
     else if( ! DBTREE::board_get_write_name( get_url() ).empty() ){
         m_entry_name.set_text( DBTREE::board_get_write_name( get_url() ) );
     }
 
-    // メール
+    // スレ別のメール
     if( DBTREE::write_fixmail( get_url() ) ){
         m_check_fixmail.set_active();
         m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
     }
+    // スレ別の名前が設定されていなかったら板別のメール
     else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
 
         std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
@@ -349,6 +338,7 @@ void MessageViewBase::pack_widget()
         if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
         else m_entry_mail.set_text( tmpmail );
     }
+    // デフォルトはsage
     else m_entry_mail.set_text( "sage" );
 
     m_tool_name.add( m_label_name );
@@ -427,9 +417,9 @@ void MessageViewBase::focus_view()
 //
 // viewの操作
 //
-void MessageViewBase::operate_view( const int& control )
+const bool MessageViewBase::operate_view( const int control )
 {
-    if( control == CONTROL::None ) return;
+    if( control == CONTROL::None ) return false;
 
     switch( control ){
             
@@ -453,9 +443,14 @@ void MessageViewBase::operate_view( const int& control )
 
             // 書き込みボタンにフォーカスを移す
         case CONTROL::FocusWrite:
-            MESSAGE::get_admin()->set_command( "focus_writebutton" );
+            MESSAGE::get_admin()->set_command( "focus_button_write" );
             break;
+
+        default:
+            return false;
     }
+
+    return true;
 }
 
 
@@ -470,14 +465,16 @@ void MessageViewBase::write()
 #endif
 
     time_t left = DBTREE::board_write_leftsec( get_url() );
-    if( left ){
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
+    if( left
+        && ! SESSION::loginbe() // BEログイン中はダイアログを表示しない
+        ){
+        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
         mdiag.run();
         return;
     }
 
     if( m_post && m_post->is_loading() ){
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み中です" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み中です" );
         mdiag.run();
         return;
     }
@@ -490,7 +487,7 @@ void MessageViewBase::write()
 
         std::string name = get_entry_name().get_text();
         if( name.empty() ){
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
             mdiag.run();
             return;
         }
@@ -501,7 +498,7 @@ void MessageViewBase::write()
     if( m_max_line ){
 
         if( m_text_message.get_buffer()->get_line_count() > m_max_line ){
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "行数が多すぎます。" );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "行数が多すぎます。" );
             mdiag.run();
             return;
         }
@@ -511,7 +508,7 @@ void MessageViewBase::write()
     if( m_max_str ){
 
         if( m_lng_str_enc > m_max_str ){
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "文字数が多すぎます。" );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "文字数が多すぎます。" );
             mdiag.run();
             return;
         }
@@ -571,9 +568,7 @@ bool MessageViewBase::slot_key_press( GdkEventKey* event )
               << " alt = " << alt << std::endl;
 #endif
 
-    operate_view( SKELETON::View::get_control().key_press( event ) );
-
-    return true;
+    return operate_view( SKELETON::View::get_control().key_press( event ) );
 }
 
 
@@ -703,7 +698,7 @@ void MessageViewBase::post_fin()
     // タイムアウト
     else if( code == HTTP_TIMEOUT ){
 
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+        SKELETON::MsgDiag mdiag( get_parent_win(),
                                  "タイムアウトしました\n\n書き込み自体は成功している可能性があります。\nメッセージのバックアップをとってからスレを再読み込みして下さい。" );
         mdiag.run();
     }
@@ -711,7 +706,7 @@ void MessageViewBase::post_fin()
     // 失敗
     else if( code != HTTP_CANCEL ){
 
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+        SKELETON::MsgDiag mdiag( get_parent_win(),
                                  "書き込みに失敗しました\n\n" + m_post->errmsg(), false, Gtk::MESSAGE_ERROR  );
         mdiag.run();
     }
@@ -802,19 +797,34 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
 void MessageViewBase::show_status()
 {
     std::stringstream ss;
-    int byte_out;
-
-    if( ( int ) m_text_message.get_text().size() > m_lng_iconv ) m_lng_str_enc = m_max_str;
-    else{
-        strcpy( m_str_iconv,  m_text_message.get_text().substr( 0, m_lng_iconv - 64 ).c_str() );
-        std::string str_enc = m_iconv->convert( m_str_iconv, strlen( m_str_iconv ), byte_out );
-        m_lng_str_enc = str_enc.length();
-    }
 
     ss << " [ 行数 " << m_text_message.get_buffer()->get_line_count();
     if( m_max_line ) ss << "/ " << m_max_line;
 
-    ss << "   /  文字数 " << m_lng_str_enc;
+    const std::string message = m_text_message.get_text();
+
+    ss << "   /  文字数 ";
+
+    if( ( int ) message.size() > m_lng_iconv )
+    {
+        ss << "過多";
+    }
+    else
+    {
+        int byte_out;
+        const char* msgc = message.c_str();
+        std::string str_enc = m_iconv->convert( (char*)msgc, strlen( msgc ), byte_out );
+         m_lng_str_enc = str_enc.length();
+
+         // 特殊文字の文字数を計算
+         m_lng_str_enc += MISC::count_chr( str_enc, '\n' ) * 5; // " <br> " = 6バイト
+         m_lng_str_enc += MISC::count_chr( str_enc, '"' ) * 5; // &quot; = 6バイト
+         m_lng_str_enc += MISC::count_chr( str_enc, '<' ) * 3; // &lt; = 4バイト
+         m_lng_str_enc += MISC::count_chr( str_enc, '>' ) * 3; // &gt; = 4バイト
+
+        ss << m_lng_str_enc;
+    }
+
     if( m_max_str ) ss << "/ " << m_max_str;
 
     if( DBTREE::article_write_time( get_url() ) ) ss << "  /  最終書込 " << DBTREE::article_write_date( get_url() );
