@@ -118,11 +118,17 @@ void Post::post_msg()
         else data.url = DBTREE::url_subbbscgi_new( m_url ); // 2回目の投稿先
     }
 
+    // Content-Type (2009/02/18に報告された"したらば"に書き込めない問題で追加)
+    // http://www.asahi-net.or.jp/~sd5a-ucd/rec-html401j/interact/forms.html#h-17.13.4.1
+    // http://www.w3.org/TR/html401/interact/forms.html#h-17.13.4.1
+    data.contenttype = "application/x-www-form-urlencoded";
+
     data.agent = DBTREE::get_agent( m_url );
     data.referer = DBTREE::url_boardbase( m_url );
     data.str_post = m_msg;
     data.host_proxy = DBTREE::get_proxy_host_w( m_url );
     data.port_proxy = DBTREE::get_proxy_port_w( m_url );
+    data.basicauth_proxy = DBTREE::get_proxy_basicauth_w( m_url );
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout_post();
     data.cookie_for_write = DBTREE::board_cookie_for_write( m_url );
@@ -131,6 +137,7 @@ void Post::post_msg()
 #ifdef _DEBUG
     std::cout << "Post::post_msg : " << std::endl
               << "url = " << data.url << std::endl
+              << "contenttype = " << data.contenttype << std::endl
               << "agent = " << data.agent << std::endl
               << "referer = " << data.referer << std::endl
               << "cookie = " << data.cookie_for_write << std::endl
@@ -200,7 +207,6 @@ void Post::receive_finish()
     std::string title;
     std::string tag_2ch;
     std::string msg;
-    std::string hana;
     std::string conf;
 
     bool ret;
@@ -262,10 +268,6 @@ void Post::receive_finish()
 
     msg = MISC::remove_space( regex.str( 1 ) );
 
-    // 2ch の hana 値
-    regex.exec( ".*<input +type=hidden +name=\"?hana\"? +value=\"?([^\"]*)\"?.*", str, 0, false, false );
-    hana = MISC::remove_space( regex.str( 1 ) );
-
 #ifdef _DEBUG
     std::cout << "TITLE: [" << title << "]\n";
     std::cout << "2ch_X: [" << tag_2ch << "]\n";
@@ -277,7 +279,6 @@ void Post::receive_finish()
     std::list< std::string >::iterator it = list_cookies.begin();
     for( ; it != list_cookies.end(); ++it ) std::cout << "cookie : [" << (*it) << "]\n";
 
-    std::cout << "hana: [" << hana << "]\n";
     std::cout << "location: [" << location() << "]\n";
 #endif
 
@@ -308,35 +309,33 @@ void Post::receive_finish()
 
             std::string diagmsg = MISC::replace_str( msg, "<br>", "\n" );
 
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
-                                     diagmsg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE, false );
-            Gtk::CheckButton ckbt( "次回から表示しない(_D)", true );
-            mdiag.get_vbox()->pack_start( ckbt, Gtk::PACK_SHRINK );
-            mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+            SKELETON::MsgCheckDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                          diagmsg,
+                                          "今後表示しない(常にOK)(_D)",
+                                          Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
 
-            // OKボタンをデフォルトにする
-            Gtk::Button okbt( Gtk::Stock::OK );
-            mdiag.add_action_widget( okbt, Gtk::RESPONSE_OK );
-            okbt.set_flags( Gtk::CAN_DEFAULT );
-            okbt.grab_default();
-            okbt.grab_focus();
-
-            mdiag.show_all_children();
-
-            int ret = mdiag.run();
-            bool ckbt_active = ckbt.get_active();
+            mdiag.set_title( "書き込み確認" );
+            const int ret = mdiag.run();
             mdiag.hide();
-
             if( ret != Gtk::RESPONSE_OK ){
 
                 set_code( HTTP_CANCEL );
                 emit_sigfin();
                 return;
             }
-            CONFIG::set_always_write_ok( ckbt_active );
+            if( mdiag.get_chkbutton().get_active() ) CONFIG::set_always_write_ok( true );
         }
 
-        set_cookies_and_hana( SKELETON::Loadable::cookies(), hana );
+        // 書き込み用キーワード( hana=mogera や suka=pontan など )をセット
+        DBTREE::board_analyze_keyword_for_write( m_url, str );
+
+        // 現在のメッセージにキーワードが付加されていない時は付け加える
+        const std::string keyword = DBTREE::board_keyword_for_write( m_url );
+        if( ! keyword.empty() && m_msg.find( keyword ) == std::string::npos ) m_msg += "&" + keyword;
+
+        // クッキーのセット
+        if( ! SKELETON::Loadable::cookies().empty() )
+            DBTREE::board_set_list_cookies_for_write( m_url, SKELETON::Loadable::cookies() );
 
         ++m_count; // 永久ループ防止
         post_msg();
@@ -348,7 +347,16 @@ void Post::receive_finish()
     else if( m_count < 1 // 永久ループ防止
              && ! m_subbbs && conf.find( "書き込み確認" ) != std::string::npos ){
 
-        set_cookies_and_hana( SKELETON::Loadable::cookies(), hana );
+        // 書き込み用キーワード( hana=mogera や suka=pontan など )をセット
+        DBTREE::board_analyze_keyword_for_write( m_url, str );
+
+        // 現在のメッセージにキーワードが付加されていない時は付け加える
+        const std::string keyword = DBTREE::board_keyword_for_write( m_url );
+        if( ! keyword.empty() && m_msg.find( keyword ) == std::string::npos ) m_msg += "&" + keyword;
+
+        // クッキーのセット
+        if( ! SKELETON::Loadable::cookies().empty() )
+            DBTREE::board_set_list_cookies_for_write( m_url, SKELETON::Loadable::cookies() );
 
         // subbbs.cgi にポスト先を変更してもう一回ポスト
         m_subbbs = true;
@@ -372,21 +380,3 @@ void Post::receive_finish()
         return;
     }
 }
-
-
-
-//
-// データベースにクッキーとhanaを登録
-//
-void Post::set_cookies_and_hana( const std::list< std::string >& cookies, const std::string& hana )
-{
-    if( ! cookies.empty() ) DBTREE::board_set_list_cookies_for_write( m_url, cookies );
-
-    if( ! hana.empty() ){
-        DBTREE::board_set_hana_for_write( m_url, hana );
-
-        // 手抜き。後で直すこと
-        if( m_msg.find( "hana=" ) == std::string::npos ) m_msg += "&hana=" + hana;
-    }
-}
-
