@@ -17,7 +17,7 @@ namespace CORE
     enum
     {
         PREFDIAG_PASSWD,
-        PREFDIAG_PRIVARY,
+        PREFDIAG_PRIVACY,
         PREFDIAG_BROWSER,
         PREFDIAG_LINKFILTER,
         PREFDIAG_USRCMD,
@@ -40,6 +40,10 @@ namespace CORE
         PREFDIAG_ARTICLE,
         PREFDIAG_IMAGE,
 
+        PREFDIAG_KEY,
+        PREFDIAG_MOUSE,
+        PREFDIAG_BUTTON,
+
         PREFDIAG_ABOUTCONFIG,
 
         PREFDIAG_NONE
