@@ -7,10 +7,6 @@
 #include "cache.h"
 #include "global.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "jdlib/confloader.h"
 #include "jdlib/miscutil.h"
 
@@ -18,12 +14,6 @@
 #include "article/articleadmin.h"
 
 #include <sstream>
-#include <cstring>
-#include <vector>
-
-#ifdef HAVE_SYS_UTSNAME_H
-#include <sys/utsname.h> // uname()
-#endif
 
 bool booting = true;
 bool quitting = false;
@@ -32,10 +22,7 @@ int mode_pane;
 bool mode_online;
 bool mode_login2ch;
 bool mode_loginbe;
-
-std::string distribution_name;
-
-int win_manager;
+bool mode_loginp2;
 
 int win_hpane_main_pos;
 int win_vpane_main_pos;
@@ -152,6 +139,9 @@ std::vector< std::string > delete_list;
 
 std::vector< std::string > live_urls;
 
+int img_fit_mode;
+
+std::string dir_select_favorite;
 
 /////////////////////////////////////
 
@@ -160,8 +150,8 @@ std::vector< std::string > live_urls;
 std::vector< int > parse_items( const std::string& items_str )
 {
     std::vector< int > items;
-    std::list< std::string > list_order = MISC::split_line( items_str );
-    std::list< std::string >::iterator it = list_order.begin();
+    const std::list< std::string > list_order = MISC::split_line( items_str );
+    std::list< std::string >::const_iterator it = list_order.begin();
     for( ; it != list_order.end(); ++it ){
 
         if( *it == ITEM_NAME_BBSLISTVIEW ) items.push_back(ITEM_BBSLISTVIEW );
@@ -189,6 +179,8 @@ std::vector< int > parse_items( const std::string& items_str )
         if( *it == ITEM_NAME_RELOAD ) items.push_back( ITEM_RELOAD );
         if( *it == ITEM_NAME_STOPLOADING ) items.push_back( ITEM_STOPLOADING );
         if( *it == ITEM_NAME_FAVORITE ) items.push_back( ITEM_FAVORITE );
+        if( *it == ITEM_NAME_CHECK_UPDATE_ROOT ) items.push_back( ITEM_CHECK_UPDATE_ROOT );
+        if( *it == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) items.push_back( ITEM_CHECK_UPDATE_OPEN_ROOT );
         if( *it == ITEM_NAME_DELETE ) items.push_back( ITEM_DELETE );
         if( *it == ITEM_NAME_QUIT ) items.push_back( ITEM_QUIT );
         if( *it == ITEM_NAME_PREVVIEW ) items.push_back( ITEM_PREVVIEW );
@@ -204,7 +196,9 @@ std::vector< int > parse_items( const std::string& items_str )
         if( *it == ITEM_NAME_INSERTTEXT ) items.push_back( ITEM_INSERTTEXT );
         if( *it == ITEM_NAME_LOCK_MESSAGE ) items.push_back( ITEM_LOCK_MESSAGE );
         if( *it == ITEM_NAME_PREVIEW ) items.push_back( ITEM_PREVIEW );
+
         if( *it == ITEM_NAME_UNDO ) items.push_back( ITEM_UNDO );
+        if( *it == ITEM_NAME_REDO ) items.push_back( ITEM_REDO );
     }
     items.push_back( ITEM_END );
 
@@ -215,6 +209,9 @@ std::vector< int > parse_items( const std::string& items_str )
 void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const std::string& id_locked,
                      std::list< std::string >& list_urls , std::list< bool >& list_locked )
 {
+    list_urls.clear();
+    list_locked.clear();
+
     std::string str_tmp;
     std::list< std::string > list_tmp;
     std::list< std::string >::iterator it_tmp;
@@ -226,6 +223,8 @@ void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const st
         for( ; it_tmp != list_tmp.end(); ++it_tmp ) if( !(*it_tmp).empty() ) list_urls.push_back( (*it_tmp));
     }
 
+    if( ! list_urls.size() ) return;
+
     str_tmp = cf.get_option( id_locked, "");
     if( ! str_tmp.empty() ){
         list_tmp = MISC::split_line( str_tmp );
@@ -238,153 +237,6 @@ void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const st
 }
 
 
-// ファイル等からディストリ名を取得
-std::string get_distribution_name_from_environment()
-{
-#ifdef _DEBUG
-    std::cout << "SESSION::get_distribution_name_from_environment\n";
-#endif
-
-    std::string tmp;
-    std::string text_data;
-
-    // LSB系 ( Ubuntu ..etc )
-    if( CACHE::load_rawdata( "/etc/lsb-release", text_data ) )
-    {
-        std::list< std::string > lines = MISC::get_lines( text_data );
-        std::list< std::string >::reverse_iterator it = lines.rbegin();
-        while( it != lines.rend() )
-        {
-            std::string lsb_name, lsb_data;
-
-            size_t e;
-            if( ( e = (*it).find( "=" ) ) != std::string::npos )
-            {
-                lsb_name = MISC::remove_spaces( (*it).substr( 0, e ) );
-                lsb_data = MISC::remove_spaces( (*it).substr( e + 1 ) );
-            }
-
-            // 「DISTRIB_DESCRIPTION="Ubuntu 7.10"」などから「Ubuntu 7.10」を取得
-            if( lsb_name == "DISTRIB_DESCRIPTION" && ! lsb_data.empty() )
-            {
-                tmp = MISC::cut_str( lsb_data, "\"", "\"" );
-                break;
-            }
-
-            ++it;
-        }
-    }
-    // KNOPPIX (LSB？)
-    else if( CACHE::load_rawdata( "/etc/knoppix-version", text_data ) )
-    {
-        tmp = "KNOPPIX ";
-        tmp.append( text_data );
-    }
-    // Debian
-    else if( CACHE::load_rawdata( "/etc/debian_version", text_data ) )
-    {
-        tmp = "Debian GNU/Linux ";
-        tmp.append( text_data );
-    }
-    // Solaris系
-    else if( CACHE::load_rawdata( "/etc/release", text_data ) )
-    {
-        std::list< std::string > lines = MISC::get_lines( text_data );
-        std::list< std::string >::iterator it = lines.begin();
-        while( it != lines.end() )
-        {
-            // 名前が含まれている行を取得
-            if( (*it).find( "BeleniX" ) != std::string::npos
-                || (*it).find( "Nexenta" ) != std::string::npos
-                || (*it).find( "SchilliX" ) != std::string::npos
-                || (*it).find( "Solaris" ) != std::string::npos )
-            {
-                tmp = *it;
-                break;
-            }
-
-            ++it;
-        }
-    }
-    // ファイルの中身がそのままディストリ名として扱える物
-    else
-    {
-        // ディストリ名が書かれているファイル
-        std::string dist_files[] =
-        {
-            "/etc/arch-release",
-            "/etc/fedora-release",
-            "/etc/gentoo-release",
-            "/etc/lfs-release",
-            "/etc/mandriva-release",
-            "/etc/momonga-release",
-            "/usr/lib/setup/plamo-version",
-            "/etc/puppyversion",
-            "/etc/redhat-release", // Redhat, CentOS, WhiteBox, PCLinuxOS
-            "/etc/sabayon-release",
-            "/etc/slackware-version",
-            "/etc/SuSE-release",
-            "/etc/turbolinux-release",
-            "/etc/vine-release",
-            "/etc/zenwalk-version"
-        };
-
-        unsigned int i;
-        for( i = 0; i < sizeof( dist_files ) / sizeof( std::string ); ++i )
-        {
-            if( CACHE::load_rawdata( dist_files[i], text_data ) )
-            {
-                tmp = text_data;
-                break;
-            }
-        }
-    }
-
-    // 文字列両端のスペースなどを削除する
-    std::string dist_name = MISC::remove_spaces( tmp );
-
-    // 取得した文字が異常に長い場合は空にする
-    if( dist_name.length() > 50 ) dist_name.clear();
-
-#ifdef HAVE_SYS_UTSNAME_H
-
-    char *sysname = 0, *release = 0, *machine = 0;
-
-    // システムコール uname() 準拠：SVr4, POSIX.1-2001.
-    struct utsname* uts;
-    uts = (struct utsname*)malloc( sizeof( struct utsname ) );
-    if( uname( uts ) != -1 )
-    {
-        sysname = uts->sysname;
-        release = uts->release;
-        machine = uts->machine;
-    }
-
-    // FreeBSD等やディストリ名が取得できなかった場合は"$ uname -rs"と同じ様式
-    if( dist_name.empty() && sysname && release )
-    {
-        dist_name = std::string( sysname ) + " " + std::string( release );
-    }
-
-    // アーキテクチャがx86でない場合
-    if( machine &&
-        ( strlen( machine ) != 4
-          || ! ( machine[0] == 'i'
-               && machine[1] >= '3' && machine[1] <= '6'
-               && machine[2] == '8' && machine[3] == '6' ) ) )
-    {
-        dist_name.append( " (" + std::string( machine ) + ")" );
-    }
-
-    free( uts );
-    uts = NULL;
-
-#endif
-
-    return dist_name;
-}
-
-
 // セッション情報読み込み
 void SESSION::init_session()
 {
@@ -403,6 +255,9 @@ void SESSION::init_session()
     // beログイン
     mode_loginbe = cf.get_option( "mode_loginbe", false );
 
+    // p2ログイン
+    mode_loginp2 = cf.get_option( "mode_loginp2", false );
+
     // paneのモード
     mode_pane = cf.get_option( "mode_pane", 0 );
 
@@ -545,23 +400,9 @@ void SESSION::init_session()
 
     popupmenu_shown = false;
 
-    // WM 判定
-    // TODO: 環境変数で判定できない場合の判定方法を考える
-    win_manager = WM_UNKNON;
-    const std::string str_wm = MISC::getenv_limited( "DESKTOP_SESSION", 5 );
+    img_fit_mode = cf.get_option( "img_fit_mode", IMG_FIT_NORMAL );
 
-    if( str_wm.find( "xfce" ) != std::string::npos ) win_manager = WM_XFCE;
-    else if( str_wm.find( "gnome" ) != std::string::npos ) win_manager = WM_GNOME;
-    else if( str_wm.find( "kde" ) != std::string::npos ) win_manager = WM_KDE;
-
-    if( win_manager == WM_UNKNON ){
-        if( ! MISC::getenv_limited( "GNOME_DESKTOP_SESSION_ID" ).empty() ) win_manager = WM_GNOME;
-        else{
-
-            const std::string str_wm = MISC::getenv_limited( "KDE_FULL_SESSION", 4 );
-            if( str_wm == "true" ) win_manager = WM_KDE;
-        }
-    }
+    dir_select_favorite = cf.get_option( "dir_select_favorite", "" );
 
 #ifdef _DEBUG
     std::cout << "x=" << x_win_main << std::endl
@@ -673,6 +514,7 @@ void SESSION::save_session()
         << "mode_online = " << mode_online << std::endl
         << "mode_login2ch = " << mode_login2ch << std::endl
         << "mode_loginbe = " << mode_loginbe << std::endl
+        << "mode_loginp2 = " << mode_loginp2 << std::endl
         << "x = " << x_win_main << std::endl
         << "y = " << y_win_main << std::endl
         << "width = " << width_win_main << std::endl
@@ -742,7 +584,11 @@ void SESSION::save_session()
 
         << "img_dir_dat_save = " << img_dir_dat_save << std::endl
         << "img_dir_img_save = " << img_dir_img_save << std::endl
-        << "dir_draft = " << dir_draft << std::endl;
+        << "dir_draft = " << dir_draft << std::endl
+
+        << "img_fit_mode = " << img_fit_mode << std::endl
+
+        << "dir_select_favorite = " << dir_select_favorite << std::endl;
 
     CACHE::save_rawdata( CACHE::path_session(), oss.str() );
 
@@ -760,16 +606,6 @@ void SESSION::set_booting( bool boot ){ booting = boot; }
 const bool SESSION::is_quitting(){ return quitting; }
 void SESSION::set_quitting( bool quit ){ quitting = quit; }
 
-// ディストリ名取得
-const std::string& SESSION::get_distribution_name()
-{
-    if( distribution_name.empty() ) distribution_name = get_distribution_name_from_environment();
-    return distribution_name;
-}
-
-// WM 判定
-const int SESSION::get_wm(){ return win_manager; }
-
 const int SESSION::get_mode_pane() { return mode_pane; }
 void SESSION::set_mode_pane( int mode ){ mode_pane = mode; }
 
@@ -777,10 +613,13 @@ const bool SESSION::is_online(){ return mode_online; }
 void SESSION::set_online( bool mode ){ mode_online = mode; }
 
 const bool SESSION::login2ch(){ return mode_login2ch; }
-void SESSION::set_login2ch( bool login ){ mode_login2ch = login; }
+void SESSION::set_login2ch( const bool login ){ mode_login2ch = login; }
 
 const bool SESSION::loginbe(){ return mode_loginbe; }
-void SESSION::set_loginbe( bool login ){ mode_loginbe = login; }
+void SESSION::set_loginbe( const bool login ){ mode_loginbe = login; }
+
+const bool SESSION::loginp2(){ return mode_loginp2; }
+void SESSION::set_loginp2( const bool login ){ mode_loginp2 = login; }
 
 const bool SESSION::show_sidebar(){ return win_show_sidebar; }
 
@@ -1154,3 +993,28 @@ void SESSION::remove_live( const std::string& url )
 #endif
 }
 
+
+// 画像のfitモード
+const int SESSION::get_img_fit_mode()
+{
+    return img_fit_mode;
+}
+
+
+void SESSION::toggle_img_fit_mode()
+{
+    if( img_fit_mode == IMG_FIT_NORMAL ) img_fit_mode = IMG_FIT_WIDTH;
+    else img_fit_mode = IMG_FIT_NORMAL;
+}
+
+
+// お気に入り挿入ダイアログで最後に保存したディレクトリ名
+const std::string& SESSION::get_dir_select_favorite()
+{
+    return dir_select_favorite;
+}
+
+void SESSION::set_dir_select_favorite( const std::string& dir )
+{
+    dir_select_favorite = dir;
+}
