@@ -42,13 +42,11 @@ namespace SESSION
         TOOLBAR_NO
     };
 
-    // WM
+    // 画像のfitモード
     enum
     {
-        WM_GNOME = 0,
-        WM_XFCE,
-        WM_KDE,
-        WM_UNKNON
+        IMG_FIT_NORMAL = 0,  // 縦と横で小さい方をウィンドウに合わせる
+        IMG_FIT_WIDTH        // 常に横をウィンドウに合わせる
     };
 
     void init_session();
@@ -62,10 +60,6 @@ namespace SESSION
     const bool is_quitting();
     void set_quitting( bool quit );
 
-    const std::string& get_distribution_name();
-
-    const int get_wm();
-
     const int get_mode_pane();
     void set_mode_pane( int mode );
     
@@ -357,6 +351,14 @@ namespace SESSION
     const bool is_live( const std::string& url );
     void append_live( const std::string& url );
     void remove_live( const std::string& url );
+
+    // 画像のfitモード
+    const int get_img_fit_mode();
+    void toggle_img_fit_mode();
+
+    // お気に入り挿入ダイアログで最後に保存したディレクトリ名
+    const std::string& get_dir_select_favorite();
+    void set_dir_select_favorite( const std::string& dir );
 }
 
 
