@@ -17,11 +17,12 @@
 #include "history/historymanager.h"
 #include "history/viewhistoryitem.h"
 
+#include "control/controlutil.h"
+#include "control/controlid.h"
+
 #include "command.h"
 #include "session.h"
 #include "global.h"
-#include "controlutil.h"
-#include "controlid.h"
 #include "updatemanager.h"
 
 
@@ -52,8 +53,7 @@ Admin::Admin( const std::string& url )
     m_notebook->sig_tab_menu().connect( sigc::mem_fun( *this, &Admin::slot_tab_menu ) );
 
     // D&D
-    m_notebook->sig_drag_begin().connect( sigc::mem_fun(*this, &Admin::slot_drag_begin ) );
-    m_notebook->sig_drag_end().connect( sigc::mem_fun(*this, &Admin::slot_drag_end ) );
+    m_notebook->sig_drag_data_get().connect( sigc::mem_fun(*this, &Admin::slot_drag_data_get ) );
 
     m_list_command.clear();
 }
@@ -312,11 +312,11 @@ int Admin::get_tab_nums()
 //
 // 含まれているページのURLのリスト取得
 //
-std::list<std::string> Admin::get_URLs()
+const std::list<std::string> Admin::get_URLs()
 {
     std::list<std::string> urls;
     
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -476,7 +476,7 @@ void Admin::exec_command()
     // arg1 にはdatファイルを空白で区切って指定する
     //
     else if( command.command == "open_list" ){
-        open_list( command.arg1 );
+        open_list( command );
     }
     else if( command.command == "switch_view" ){
         switch_view( command.url );
@@ -730,19 +730,25 @@ void Admin::exec_command()
 // 連続してリロードかけるとサーバに負担をかけるので、オフラインで開いて
 // タイミングをずらしながらリロードする
 //
-void Admin::open_list( const std::string& str_list )
+void Admin::open_list( const COMMAND_ARGS& command_list )
 {
+#ifdef _DEBUG
+    std::cout << "Admin::open_list " << m_url << std::endl;
+#endif
+
+    const std::string& str_list = command_list.arg1;
+
     std::list< std::string > list_url = MISC::split_line( str_list );
     if( list_url.empty() ) return;
 
     int waittime = 0;
-    bool online = SESSION::is_online();
+    const bool online = SESSION::is_online();
 
     std::list< std::string >::iterator it = list_url.begin();
     for( ; it != list_url.end(); ++it, waittime += AUTORELOAD_MINSEC ){
 
         // 各admin別の引数をセット
-        COMMAND_ARGS command_arg = get_open_list_args( ( *it ) );
+        COMMAND_ARGS command_arg = get_open_list_args( ( *it ), command_list );
 
         // 共通の引数をセット
         command_arg.command = "open_view";
@@ -751,6 +757,10 @@ void Admin::open_list( const std::string& str_list )
         command_arg.arg2 = "false";  // 既に開いているかチェック
         command_arg.arg3 = "noswitch";  // タブを切り替えない
 
+#ifdef _DEBUG
+        std::cout << "url = " << command_arg.url << std::endl;
+#endif
+
         open_view( command_arg );
 
         // 一番最初のページは普通にオンラインで開く
@@ -827,20 +837,36 @@ void Admin::update_status( View* view, const bool force )
 //
 // ビューを開く
 //
-// command.arg1: "true" なら新しいtabを開く, "right" ならアクティブなtabの右に、"left"なら左に開く
+// command.arg1: 開く位置
+//
+// "false" ならアクティブなタブを置き換える
+// "true" なら一番右側に新しいタブを開く
+// "right" ならアクティブなタブの右に開く
+// "left" ならアクティブな左に開く
+// "page数字" なら指定した位置にタブで開く
+//
 // command.arg2: "true" なら既にurlを開いているかチェックしない
+//
 // command.arg3: モード
-//   arg3 == "auto"なら表示されていればリロードせずに切替え、されていなければ新しいタブで開いてロード(スレ番号ジャンプなどで使用)
-//   arg3 == "noswitch"ならタブを切り替えない(連続して開くときに使用)
-//   arg3 == "lock" なら開いてロックする
+//
+// "auto"なら表示されていればリロードせずに切替える
+// されていなければarg1で指定した場所に新しいタブで開いてロード
+// スレ番号ジャンプなどで使用する
+//
+// "noswitch"ならタブを切り替えない(連続して開くときに使用)
+// "lock" なら開いてからロックする
 //
 // その他のargは各ビュー別の設定
 //
 void Admin::open_view( const COMMAND_ARGS& command )
 {
 #ifdef _DEBUG
-    std::cout << "Admin::open_view : " << command.url << std::endl;
+    std::cout << "Admin::open_view : " << command.url << std::endl
+              << "arg1 = " << command.arg1 << std::endl
+              << "arg2 = " << command.arg2 << std::endl 
+              << "arg3 = " << command.arg3 << std::endl;   
 #endif
+
     SKELETON::View* view;
     SKELETON::View* current_view = get_current_view();
 
@@ -848,9 +874,11 @@ void Admin::open_view( const COMMAND_ARGS& command )
 
     // urlを既に開いていたら表示してリロード
     if( ! ( command.arg2 == "true" ) ){
+
         view = get_view( command.url );
         if( view ){
 
+            // タブの切り替え
             if( ! ( command.arg3 == "noswitch" ) ){
             
                 int page = m_notebook->page_num( *view );
@@ -876,11 +904,11 @@ void Admin::open_view( const COMMAND_ARGS& command )
     view = create_view( command );
     if( !view ) return;
 
-    int page = m_notebook->get_current_page();
-    bool open_tab = (  page == -1
-                       || command.arg1 == "true" || command.arg1 == "right" || command.arg1 == "left"
-                       || command.arg3 == "auto" // オートモードの時もタブで開く
-                       || is_locked( page )
+    const int page = m_notebook->get_current_page();
+    const bool open_tab = (  page == -1
+                             || ( ! command.arg1.empty() && command.arg1 != "false" )
+                             || command.arg3 == "auto" // オートモードの時もタブで開く
+                             || is_locked( page )
         );
 
     // ツールバー表示
@@ -889,14 +917,26 @@ void Admin::open_view( const COMMAND_ARGS& command )
     // タブで表示
     if( open_tab ){
 
-#ifdef _DEBUG
-        std::cout << "append page\n";
-#endif
+        int openpage = -1;
+
         // 現在のページの右に表示
-        if( page != -1 && command.arg1 == "right" ) m_notebook->insert_page( command.url, *view, page+1 );
+        if( command.arg1 == "right" ) openpage = page +1;
 
         // 現在のページの左に表示
-        else if( page != -1 && command.arg1 == "left" ) m_notebook->insert_page( command.url, *view, page );
+        else if( command.arg1 == "left" ) openpage = page;
+
+        // 指定した位置に表示
+        else if( command.arg1.find( "page" ) == 0 ) openpage = atoi( command.arg1.c_str() + 4 );
+
+        // ロックされていたら右に表示
+        else if( command.arg1 != "true" && page != -1 && is_locked( page ) ) openpage = page +1;
+
+#ifdef _DEBUG
+        std::cout << "append page = " << openpage << std::endl;
+#endif
+
+
+        if( page != -1 ) m_notebook->insert_page( command.url, *view, openpage );
 
         // 最後に表示
         else m_notebook->append_page( command.url, *view );
@@ -915,6 +955,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
 
     // 開いてるviewを消してその場所に表示
     else{
+
 #ifdef _DEBUG
         std::cout << "replace page\n";
 #endif
@@ -939,6 +980,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
     // ツールバーの情報更新
     m_notebook->set_current_toolbar( view->get_id_toolbar(), view );
 
+    // タブの切り替え
     if( ! ( command.arg3 == "noswitch" ) ){
         switch_admin();
         set_current_page( m_notebook->page_num( *view ) );
@@ -1262,14 +1304,22 @@ void Admin::update_item( const std::string& url,  const std::string& id )
     std::cout << "Admin::update_item : " << url << " " << id << std::endl;
 #endif
 
-    SKELETON::View* view = get_view( url );
-    if( view ) view->update_item( id );
+    std::list< SKELETON::View* > list_view = get_list_view();
+    std::list< SKELETON::View* >::iterator it = list_view.begin();
+    for( ; it != list_view.end(); ++it ){
+        SKELETON::View* view = ( *it );
+        if( view ) view->update_item( url, id );
+    }
+
 }
 
 
 //
 // ビューに更新終了を知らせる
 //
+// update_view はデータロード時などの更新途中でも呼び出されるが
+// update_finish は最後に一度だけ呼び出される
+//
 void Admin::update_finish( const std::string& url )
 {
 #ifdef _DEBUG
@@ -1484,7 +1534,10 @@ void Admin::toggle_icon( const std::string& url )
         // オートリロードモードでロード待ち
         else if( view->get_autoreload_mode() != AUTORELOAD_NOT ) iconname = "loading_stop";
 
-        // 更新あり   
+        // 更新可能
+        else if( view->is_check_update() ) iconname = "update";
+
+        // 更新済み
         else if( view->is_updated() ){
 
             // タブがアクティブの時は通常アイコンを表示
@@ -1492,9 +1545,6 @@ void Admin::toggle_icon( const std::string& url )
             else iconname = "updated";
         }
 
-        // 更新チェック済み
-        else if( view->is_check_update() ) iconname = "update";
-
         // 古い
         else if( view->is_old() ) iconname = "old";
 
@@ -2105,6 +2155,14 @@ const bool Admin::is_locked( const int page )
     return false;
 }
 
+const bool Admin::is_locked( const std::string& url )
+{
+    SKELETON::View* view = get_view( url );
+    if( view ) return view->is_locked();
+
+    return false;
+}
+
 void Admin::lock( const int page )
 {
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
