@@ -7,12 +7,13 @@
 
 #include "command.h"
 #include "session.h"
+#include "dispatchmanager.h"
 #include "global.h"
 
 using namespace SKELETON;
 
-PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, bool add_cancel, bool add_apply )
-    : Gtk::Dialog(), m_url( url ), m_bt_apply( Gtk::Stock::APPLY )
+PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_cancel, const bool add_apply )
+    : Gtk::Dialog(), m_url( url ), m_bt_ok( NULL ), m_bt_apply( Gtk::Stock::APPLY )
 {
     if( add_apply ){
         m_bt_apply.signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_apply_clicked ) );
@@ -25,14 +26,33 @@ PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, bool add_cancel
         ->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_cancel_clicked ) );
     }
 
-    add_button( Gtk::Stock::OK, Gtk::RESPONSE_OK )
-    ->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_ok_clicked ) );
+    m_bt_ok = add_button( Gtk::Stock::OK, Gtk::RESPONSE_OK );
+    m_bt_ok->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_ok_clicked ) );
 
     if( parent ) set_transient_for( *parent );
     else set_transient_for( *CORE::get_mainwindow() );
 }
 
 
+PrefDiag::~PrefDiag()
+{
+    m_conn_timer.disconnect();
+}
+
+
+//
+// okボタンをフォーカス
+//
+void PrefDiag::grab_ok()
+{
+    if( ! m_bt_ok ) return;
+
+    m_bt_ok->set_flags( Gtk::CAN_DEFAULT );
+    m_bt_ok->grab_default();
+    m_bt_ok->grab_focus();
+}
+
+
 int PrefDiag::run(){
 
     SESSION::set_dialog_shown( true );
@@ -40,7 +60,7 @@ int PrefDiag::run(){
 
     // タイマーセット
     sigc::slot< bool > slot_timeout = sigc::bind( sigc::mem_fun(*this, &PrefDiag::slot_timeout), 0 );
-    sigc::connection conn = Glib::signal_timeout().connect( slot_timeout, TIMER_TIMEOUT );
+    m_conn_timer = Glib::signal_timeout().connect( slot_timeout, TIMER_TIMEOUT );
 
     int ret = Gtk::Dialog::run();
 
@@ -49,3 +69,16 @@ int PrefDiag::run(){
 
     return ret;
 }
+
+
+// タイマーのslot関数
+bool PrefDiag::slot_timeout( int timer_number )
+{
+    // メインループが停止していて dispatcher が働かないため
+    // タイマーから強制的に実行させる
+    CORE::get_dispmanager()->slot_dispatch();
+
+    timeout();
+
+    return true;
+}
