@@ -13,17 +13,23 @@ namespace SKELETON
     {
         std::string m_url;
 
+        Gtk::Button* m_bt_ok;
         Gtk::Button m_bt_apply;
 
+        sigc::connection m_conn_timer;
+
       public:
 
         // parent == NULL のときはメインウィンドウをparentにする
-        PrefDiag( Gtk::Window* parent, const std::string& url, bool add_cancel = true, bool add_apply = false );
+        PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_cancel = true, const bool add_apply = false );
 
-        virtual ~PrefDiag(){}
+        virtual ~PrefDiag();
 
         const std::string& get_url() const { return m_url; }
 
+        // okボタンをフォーカス
+        void grab_ok();
+
         virtual int run();
 
       protected:
@@ -35,8 +41,10 @@ namespace SKELETON
       private:
 
         // タイマーのslot関数
-        // コードが繁雑になるのでcoreとは別にする
-        virtual bool slot_timeout( int timer_number ){ return true; }
+        bool slot_timeout( int timer_number );
+
+        // 各設定ダイアログ別のタイムアウト処理 ( slot_timeout()から呼び出される )
+        virtual void timeout(){}
     };
 }
 
