@@ -6,7 +6,7 @@
 #include <gtkmm.h>
 #include <string>
 
-#include "control.h"
+#include "control/control.h"
 
 namespace SKELETON
 {
@@ -26,6 +26,7 @@ namespace SKELETON
         SIG_RESIZE_POPUP m_sig_resize_popup;
 
         std::string m_url;
+        Gtk::Window* m_parent_win;
 
         // クライアント領域の幅、高さ
         int m_width_client;
@@ -125,7 +126,7 @@ namespace SKELETON
         void reset_keyjump_counter(); 
 
         // 数字入力ジャンプ用に sig_key_press() から呼び出す
-        void release_keyjump_key( int key );
+        const bool release_keyjump_key( int key );
 
         // ポップアップメニュー表示
         void show_popupmenu( const std::string& url, bool use_slot = false );
@@ -152,6 +153,9 @@ namespace SKELETON
 
         virtual const std::string& get_url(){ return m_url; }
 
+        virtual void set_parent_win( Gtk::Window* parent_win ){ m_parent_win = parent_win; }
+        virtual Gtk::Window* get_parent_win(){ return m_parent_win; }
+
         // 移転があったときなどにadminから呼び出される
         void update_url( const std::string& url_old, const std::string& url_new );
 
@@ -175,7 +179,10 @@ namespace SKELETON
         bool is_mouse_on_view();
 
         // 各view個別のコマンド
-        virtual bool set_command( const std::string& command, const std::string& arg = std::string() ){ return true; }
+        virtual const bool set_command( const std::string& command,
+                                        const std::string& arg1 = std::string(),
+                                        const std::string& arg2 = std::string()
+            ){ return true; }
 
         // コピー用のURL
         virtual const std::string url_for_copy(){ return m_url; }
@@ -236,16 +243,17 @@ namespace SKELETON
         virtual void stop(){}
         virtual void show_view(){}
         virtual void redraw_view(){}
+        virtual void redraw_scrollbar(){}
         virtual void relayout(){}
         virtual void update_view(){}
         virtual void update_finish(){}        
         virtual void focus_view(){}
-        virtual void focus_out(){ m_control.MG_reset(); }
+        virtual void focus_out(){}
         virtual void close_view(){}
         virtual void delete_view(){}
         virtual void set_favorite(){}
-        virtual void update_item( const std::string& ){}
-        virtual void operate_view( const int& ){}
+        virtual void update_item( const std::string& url, const std::string& id ){}
+        virtual const bool operate_view( const int ) = 0;
         virtual void goto_top(){}
         virtual void goto_bottom(){}
         virtual void goto_num( int num ){}
