@@ -5,11 +5,15 @@
 
 #include "window.h"
 
+#include "config/globalconf.h"
+
+#include "environment.h"
 #include "global.h"
 #include "session.h"
 #include "dndmanager.h"
 #include "command.h"
 
+#include <gtk/gtkwindow.h>
 
 enum
 {
@@ -45,8 +49,12 @@ using namespace SKELETON;
 // メッセージウィンドウでは m_mginfo が不要なので need_mginfo = false になる
 JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     : Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
+      m_gtkwidget( NULL ),
+      m_gtkwindow( NULL ),
+      m_grand_parent_class( NULL ),
+      m_win_moved( false ),
       m_fold_when_focusout( fold_when_focusout ),
-      m_boot( fold_when_focusout ),
+      m_boot( true ),
       m_enable_fold( m_fold_when_focusout ),
       m_transient( false ),
       m_mode( JDWIN_INIT ),
@@ -62,6 +70,7 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     m_label_stat.set_size_request( 0, -1 );
     m_label_stat.set_alignment( Gtk::ALIGN_LEFT );
     m_label_stat.set_selectable( true );
+    m_label_stat.set_single_line_mode( true );
 
     m_label_stat_ebox.add( m_label_stat );
     m_label_stat_ebox.set_visible_window( false );
@@ -76,6 +85,11 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     m_statbar.show_all_children();
 
     add( m_vbox );
+
+    m_gtkwidget = GTK_WIDGET( gobj() );
+    m_gtkwindow = GTK_WINDOW( gobj() );
+    gpointer parent_class = g_type_class_peek_parent( G_OBJECT_GET_CLASS( gobj() ) );
+    m_grand_parent_class = g_type_class_peek_parent( parent_class );
 }
 
 
@@ -109,7 +123,7 @@ void JDWindow::init_win()
 
         set_skip_taskbar_hint( true );
         resize( get_width_win(), 1 );
-        move( get_x_win(), get_y_win() );
+        move_win( get_x_win(), get_y_win() );
         focus_out();
 
         property_window_position().set_value( Gtk::WIN_POS_NONE );
@@ -121,10 +135,12 @@ void JDWindow::init_win()
     // 通常のウィンドウ
     else{
         resize( get_width_win(), get_height_win() );
-        move( get_x_win(), get_y_win() );
+        move_win( get_x_win(), get_y_win() );
         if( is_maximized_win() ) maximize_win();
         property_window_position().set_value( Gtk::WIN_POS_NONE );
         set_shown_win( true );
+
+        Glib::signal_idle().connect( sigc::mem_fun( *this, &JDWindow::slot_idle ) );
     }
 }
 
@@ -132,20 +148,24 @@ void JDWindow::init_win()
 bool JDWindow::slot_idle()
 {
     // ブート完了
-    if( m_fold_when_focusout && m_boot ){
+    if( m_boot ){
 
 #ifdef _DEBUG
         std::cout << "----------------\nJDWinow::slot_idle boot end mode = " << m_mode << std::endl;
 #endif
         m_boot = false;
+        move_win( get_x_win(), get_y_win() );
 
-        // 遅延させて clock_in()の中でフォーカスをメインウィンドウに戻す
-        if( m_mode == JDWIN_FOLD ){
-            m_mode = JDWIN_UNGRAB;
-            m_counter = 0;
+        if( m_fold_when_focusout ){
+
+            // 遅延させて clock_in()の中でフォーカスをメインウィンドウに戻す
+            if( m_mode == JDWIN_FOLD ){
+                m_mode = JDWIN_UNGRAB;
+                m_counter = 0;
+            }
+
+            CORE::core_set_command( "window_boot_fin" );
         }
-
-        CORE::core_set_command( "window_boot_fin" );
     }
 
     return false;
@@ -203,7 +223,7 @@ void JDWindow::clock_in()
         // メインウィンドウと画像ウィンドウが同時にフォーカスアウトしたら
         // 一時的に transient 指定を外す。メインウィンドウがフォーカスインしたときに
         // Admin::focus_out() で transient 指定を戻す
-        if( SESSION::get_wm() == SESSION::WM_GNOME
+        if( ENVIRONMENT::get_wm() == ENVIRONMENT::WM_GNOME
             && ! SESSION::is_iconified_win_main() // メインウィンドウが最小化しているときに transient を外すとウィンドウが表示されなくなる
             && ! SESSION::is_focus_win_main() && ! is_focus_win() ){
 
@@ -237,6 +257,72 @@ void JDWindow::maximize_win()
 }
 
 
+//
+// ウィンドウ移動
+// 
+void JDWindow::move_win( const int x, const int y )
+{
+    if( ! CONFIG::get_manage_winpos() ) return;
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::move_win "
+              << "x = " << x << " y = " << y << std::endl;
+#endif
+
+    move( x, y );
+    set_x_win( x );
+    set_y_win( y );
+
+    // compiz 環境などでは move() で指定した座標がズレるので補正する
+    m_win_moved = true;
+}
+
+
+//
+// ウィンドウ座標取得
+//
+void JDWindow::set_win_pos()
+{
+    if( ! get_window() ) return;
+
+    int x,y;
+    get_window()->get_root_origin( x, y );
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::set_win_pos "
+              << "x = " << x << " / " << get_x_win() << ", y = " << y << " / " << get_y_win() << std::endl;
+#endif
+
+    // compiz 環境などでは move() で指定した座標がズレるので補正する
+    if( m_win_moved ){
+
+        if( x != get_x_win() || y != get_y_win() ){
+
+            // 補正量がmrgを越えたら補正を諦める
+            const int mrg = 64;
+
+            const int delta_x = x - get_x_win();
+            const int delta_y = y - get_y_win();
+
+            x = get_x_win();
+            y = get_y_win();
+            m_win_moved = false;
+
+            if( abs( delta_x ) <= mrg && abs( delta_y ) <= mrg ){
+
+                move( get_x_win() - delta_x, get_y_win() - delta_y );
+#ifdef _DEBUG
+                std::cout << "!!! moved x = " << get_x_win() << " y = " << get_y_win() << " dx = " << delta_x << " dy = " << delta_y << std::endl;
+#endif
+            }
+        }
+    }
+
+    set_x_win( x );
+    set_y_win( y );
+}
+
+
 // hide 中
 const bool JDWindow::is_hide()
 {
@@ -273,6 +359,10 @@ void JDWindow::pack_remove_end( bool unpack, Widget& child, Gtk::PackOptions opt
 // ステータスバー表示
 void JDWindow::set_status( const std::string& stat )
 {
+    if( stat == m_status ) return;
+
+    m_status = stat;
+
 #if GTKMMVER <= 240
     m_statbar.push( stat );
 #else
@@ -282,6 +372,32 @@ void JDWindow::set_status( const std::string& stat )
 }
 
 
+// 一時的にステータスバーの表示を変える( マウスオーバーでのURL表示用 )
+//
+// 恒久的に変えてしまうと、マウススオ-バー中に ArticleViewBase では
+// ないクラスから表示を変更された場合に本来の表示に戻せなくなる。
+void JDWindow::set_status_temporary( const std::string& stat )
+{
+    if( stat == m_status ) return;
+
+#if GTKMMVER <= 240
+    m_statbar.push( stat );
+#else
+    m_label_stat.set_text( stat );
+#endif
+}
+
+// 一時的に変えたステータスバーの表示を戻す
+void JDWindow::restore_status()
+{
+#if GTKMMVER <= 240
+    m_statbar.push( m_status );
+#else
+    m_label_stat.set_text( m_status );
+#endif
+}
+
+
 // マウスジェスチャ表示
 void JDWindow::set_mginfo( const std::string& mginfo )
 {
@@ -328,7 +444,7 @@ void JDWindow::set_enable_fold( bool enable )
         // XFCE 環境の場合はここでpresent()しておかないとフォーカスが外れる
         if( m_mode == JDWIN_NORMAL && m_enable_fold ){
 
-            if( SESSION::get_wm() == SESSION::WM_KDE ) switch_admin();
+            if( ENVIRONMENT::get_wm() == ENVIRONMENT::WM_KDE ) switch_admin();
             else present();
         }
     }
@@ -356,7 +472,7 @@ void JDWindow::focus_in()
         if( ! is_maximized_win() && get_window() ){
             int x, y;
             get_window()->get_root_origin( x, y );
-            if( x != get_x_win() || y != get_y_win() ) move( get_x_win(), get_y_win() );
+            if( x != get_x_win() || y != get_y_win() ) move_win( get_x_win(), get_y_win() );
         }
 
 
@@ -393,7 +509,7 @@ void JDWindow::focus_out()
 
         // ポップアップメニューを表示しているかD&D中はfocus_outしない
         if( SESSION::is_popupmenu_shown() ) return;
-        if( CORE::get_dnd_manager()->now_dnd() ) return;
+        if( CORE::DND_Now_dnd() ) return;
 
         // 最大化している時は通常状態に戻しておかないと表示されなくなる
         if( is_maximized_win() ) unmaximize();
@@ -473,12 +589,7 @@ bool JDWindow::on_delete_event( GdkEventAny* event )
         else{
 
             // hideする前に座標保存
-            if( ! is_maximized_win() && ! is_iconified_win() && get_window() ){
-                int x, y;
-                get_window()->get_root_origin( x, y );
-                set_x_win( x );
-                set_y_win( y );
-            }
+            if( ! is_maximized_win() && ! is_iconified_win() && get_window() ) set_win_pos();
 
             hide();
             m_mode = JDWIN_HIDE;
@@ -549,18 +660,17 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
     int min_height = 0;
     if( m_scrwin ) min_height = m_vbox.get_height() - m_scrwin->get_height() + mrg;
 
-#ifdef _DEBUG
-    std::cout << "JDWindow::on_configure_event\n"
-              << "mode = " << m_mode
-              << " w = " << width_new << " h = " << height_new
-              << " border = " << border << " title = " << title_height 
-              << " rx = " << rect.get_x() << " ry = " << rect.get_y() 
-              << " rw = " << rect.get_width() << " rh = " << rect.get_height() 
-              << " min_height = " << min_height << "\n------->\n";
-#endif
-
     if( ! m_boot ){
 
+#ifdef _DEBUG
+    std::cout << "JDWindow::on_configure_event"
+              << " boot = " << m_boot
+              << " mode = " << m_mode
+              << " x = " << event->x << " y = " << event->y
+              << " w = " << width_new << " h = " << height_new
+              << " min_height = " << min_height << std::endl;
+#endif
+
         // 最大 -> 通常に戻る時はリサイズをキャンセル
         if( m_mode == JDWIN_UNMAX ) m_mode = JDWIN_NORMAL;
         else if( m_mode == JDWIN_UNMAX_FOLD ) m_mode = JDWIN_FOLD;
@@ -568,12 +678,7 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
         // 最大、最小化しているときは除く
         else if( ! is_maximized_win() && ! is_iconified_win() ){
 
-            if( get_window() ){
-                int x,y;
-                get_window()->get_root_origin( x, y );
-                set_x_win( x );
-                set_y_win( y );
-            }
+            set_win_pos();
 
             // サイズ変更
             if( ( ! m_fold_when_focusout || m_mode == JDWIN_NORMAL || m_mode == JDWIN_FOLD )
@@ -583,15 +688,36 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
                 set_height_win( height_new );
             }
         }
-    }
 
 #ifdef _DEBUG
-    std::cout << " mode = " << m_mode << " show = " << is_shown_win() << std::endl
+    std::cout << "configure fin --> mode = " << m_mode << " show = " << is_shown_win() 
               << " maximized = " << is_maximized_win()
               << " iconified = " << is_iconified_win()
               << " x = " << get_x_win() << " y = " << get_y_win()
               << " w = " << get_width_win() << " height = " << get_height_win() << std::endl;
 #endif     
+    }
 
     return Gtk::Window::on_configure_event( event );
 }
+
+
+// uimなど、漢字変換モードの途中でctrl+qを押すとキーアクセレータが
+// 優先されてJDが終了する問題があった。
+//
+// gedit-window.c の gedit_window_key_press_event を見ると
+// gtk_window_propagate_key_event() を実行した後でキーアクセレータ
+// の処理をするようにしていたのでJDもそうした。
+bool JDWindow::on_key_press_event( GdkEventKey* event )
+{
+    if( gtk_window_propagate_key_event( m_gtkwindow, event ) ) return true;
+
+    if( gtk_window_activate_key( m_gtkwindow, event ) ) return true;
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::on_key_press_event key = " << event->keyval << std::endl;
+    std::cout << m_grand_parent_class << " - " << m_gtkwidget << std::endl;
+#endif
+
+    return GTK_WIDGET_CLASS( m_grand_parent_class )->key_press_event( m_gtkwidget, event );
+}
